(function () {
    'use strict';

    function toString(obj) {
        if (!obj) {
            return obj
        }
        if (typeof obj === 'string') {
            return obj
        }
        return obj + '';
    }


    //helper function to format a string
    function format(str, args) {
        var keys = Object.keys(args), i;
        for (i=0; i<keys.length; i++) {
            str = str.replace(new RegExp("\\{" + keys[i] + "\\}", "gi"), args[keys[i]]);
        }
        return str;
    }

    class ImageUtils {

        /**
         * Convert svg dataurl to canvas element
         * 
         * @private
         */
        async svg2canvas(svgDataURL, width, height) {
            const svgImage = await new Promise((resolve) => {
                var svgImage = new Image();
                svgImage.onload = function() {
                    resolve(svgImage);
                };
                svgImage.src = svgDataURL;
            });
            var canvas = document.createElement('canvas');
            canvas.width = width;
            canvas.height = height;
            const ctx = canvas.getContext('2d');
            ctx.drawImage(svgImage, 0, 0);
            return canvas;
        }
        
        toDataURL(svgNode, width, height, type, encoderOptions, options) {
            var xml = new XMLSerializer().serializeToString(svgNode);
        
            // documentMode is an IE-only property
            // http://msdn.microsoft.com/en-us/library/ie/cc196988(v=vs.85).aspx
            // http://stackoverflow.com/questions/10964966/detect-ie-version-prior-to-v9-in-javascript
            var isIE = document.documentMode;
        
            if (isIE) {
                // This is patch from canvas2svg
                // IE search for a duplicate xmnls because they didn't implement setAttributeNS correctly
                var xmlns = /xmlns="http:\/\/www\.w3\.org\/2000\/svg".+xmlns="http:\/\/www\.w3\.org\/2000\/svg/gi;
                if(xmlns.test(xml)) {
                    xml = xml.replace('xmlns="http://www.w3.org/2000/svg','xmlns:xlink="http://www.w3.org/1999/xlink');
                }
            }

            if (!options) {
                options = {};
            }
        
            var SVGDataURL = "data:image/svg+xml;charset=utf-8," + encodeURIComponent(xml);
            if (type === "image/svg+xml" || !type) {
                if (options.async) {
                    return Promise.resolve(SVGDataURL)
                }
                return SVGDataURL;
            }
            if (type === "image/jpeg" || type === "image/png") {
                if (!options.async) {
                    throw new Error('svgcanvas: options.async must be set to true if type is image/jpeg | image/png')
                }
                return (async () => {
                    const canvas = await this.svg2canvas(SVGDataURL, width, height);
                    const dataUrl = canvas.toDataURL(type, encoderOptions);
                    canvas.remove();
                    return dataUrl;
                })()
            }
            throw new Error('svgcanvas: Unknown type for toDataURL, please use image/jpeg | image/png | image/svg+xml.');
        }

        getImageData(svgNode, width, height, sx, sy, sw, sh, options) {
            if (!options) {
                options = {};
            }
            if (!options.async) {
                throw new Error('svgcanvas: options.async must be set to true for getImageData')
            }
            const svgDataURL = this.toDataURL(svgNode, width, height, 'image/svg+xml');
            return (async () => {
                const canvas = await this.svg2canvas(svgDataURL, width, height);
                const ctx = canvas.getContext('2d');
                const imageData = ctx.getImageData(sx, sy, sw, sh);
                canvas.remove();
                return imageData;
            })()
        }
    }

    const utils = new ImageUtils();

    /*
     *  Implements the .roundRect() method of the CanvasPath mixin
     *  as introduced by https://github.com/whatwg/html/pull/6765
     * 
     * From https://github.com/Kaiido/roundRect
     */
    function roundRect$1(x, y, w, h, radii) {
      if (!([x, y, w, h].every((input) => Number.isFinite(input)))) {
        return;
      }

      radii = parseRadiiArgument(radii);

      let upperLeft, upperRight, lowerRight, lowerLeft;

      if (radii.length === 4) {

        upperLeft = toCornerPoint(radii[0]);
        upperRight = toCornerPoint(radii[1]);
        lowerRight = toCornerPoint(radii[2]);
        lowerLeft = toCornerPoint(radii[3]);

      } else if (radii.length === 3) {

        upperLeft = toCornerPoint(radii[0]);
        upperRight = toCornerPoint(radii[1]);
        lowerLeft = toCornerPoint(radii[1]);
        lowerRight = toCornerPoint(radii[2]);

      } else if (radii.length === 2) {

        upperLeft = toCornerPoint(radii[0]);
        lowerRight = toCornerPoint(radii[0]);
        upperRight = toCornerPoint(radii[1]);
        lowerLeft = toCornerPoint(radii[1]);

      } else if (radii.length === 1) {

        upperLeft = toCornerPoint(radii[0]);
        upperRight = toCornerPoint(radii[0]);
        lowerRight = toCornerPoint(radii[0]);
        lowerLeft = toCornerPoint(radii[0]);

      } else {

        throw new RangeError(`${getErrorMessageHeader(this)} ${radii.length} is not a valid size for radii sequence.`);

      }

      const corners = [upperLeft, upperRight, lowerRight, lowerLeft];
      const negativeCorner = corners.find(({ x, y }) => x < 0 || y < 0);
      negativeCorner?.x < 0 ? negativeCorner.x : negativeCorner?.y;

      if (corners.some(({ x, y }) => !Number.isFinite(x) || !Number.isFinite(y))) {

        return;

      }

      if (negativeCorner) {

        throw new RangeError(`${getErrorMessageHeader(this)} Radius value ${negativeCorner} is negative.`);

      }

      fixOverlappingCorners(corners);

      if (w < 0 && h < 0) {

        this.moveTo(x - upperLeft.x, y);
        this.ellipse(x + w + upperRight.x, y - upperRight.y, upperRight.x, upperRight.y, 0, -Math.PI * 1.5, -Math.PI);
        this.ellipse(x + w + lowerRight.x, y + h + lowerRight.y, lowerRight.x, lowerRight.y, 0, -Math.PI, -Math.PI / 2);
        this.ellipse(x - lowerLeft.x, y + h + lowerLeft.y, lowerLeft.x, lowerLeft.y, 0, -Math.PI / 2, 0);
        this.ellipse(x - upperLeft.x, y - upperLeft.y, upperLeft.x, upperLeft.y, 0, 0, -Math.PI / 2);

      } else if (w < 0) {

        this.moveTo(x - upperLeft.x, y);
        this.ellipse(x + w + upperRight.x, y + upperRight.y, upperRight.x, upperRight.y, 0, -Math.PI / 2, -Math.PI, 1);
        this.ellipse(x + w + lowerRight.x, y + h - lowerRight.y, lowerRight.x, lowerRight.y, 0, -Math.PI, -Math.PI * 1.5, 1);
        this.ellipse(x - lowerLeft.x, y + h - lowerLeft.y, lowerLeft.x, lowerLeft.y, 0, Math.PI / 2, 0, 1);
        this.ellipse(x - upperLeft.x, y + upperLeft.y, upperLeft.x, upperLeft.y, 0, 0, -Math.PI / 2, 1);

      } else if (h < 0) {

        this.moveTo(x + upperLeft.x, y);
        this.ellipse(x + w - upperRight.x, y - upperRight.y, upperRight.x, upperRight.y, 0, Math.PI / 2, 0, 1);
        this.ellipse(x + w - lowerRight.x, y + h + lowerRight.y, lowerRight.x, lowerRight.y, 0, 0, -Math.PI / 2, 1);
        this.ellipse(x + lowerLeft.x, y + h + lowerLeft.y, lowerLeft.x, lowerLeft.y, 0, -Math.PI / 2, -Math.PI, 1);
        this.ellipse(x + upperLeft.x, y - upperLeft.y, upperLeft.x, upperLeft.y, 0, -Math.PI, -Math.PI * 1.5, 1);

      } else {

        this.moveTo(x + upperLeft.x, y);
        this.ellipse(x + w - upperRight.x, y + upperRight.y, upperRight.x, upperRight.y, 0, -Math.PI / 2, 0);
        this.ellipse(x + w - lowerRight.x, y + h - lowerRight.y, lowerRight.x, lowerRight.y, 0, 0, Math.PI / 2);
        this.ellipse(x + lowerLeft.x, y + h - lowerLeft.y, lowerLeft.x, lowerLeft.y, 0, Math.PI / 2, Math.PI);
        this.ellipse(x + upperLeft.x, y + upperLeft.y, upperLeft.x, upperLeft.y, 0, Math.PI, Math.PI * 1.5);

      }

      this.closePath();
      this.moveTo(x, y);

      function toDOMPointInit(value) {

        const { x, y, z, w } = value;
        return { x, y, z, w };

      }

      function parseRadiiArgument(value) {

        // https://webidl.spec.whatwg.org/#es-union
        // with 'optional (unrestricted double or DOMPointInit
        //   or sequence<(unrestricted double or DOMPointInit)>) radii = 0'
        const type = typeof value;

        if (type === "undefined" || value === null) {

          return [0];

        }
        if (type === "function") {

          return [NaN];

        }
        if (type === "object") {

          if (typeof value[Symbol.iterator] === "function") {

            return [...value].map((elem) => {
              // https://webidl.spec.whatwg.org/#es-union
              // with '(unrestricted double or DOMPointInit)'
              const elemType = typeof elem;
              if (elemType === "undefined" || elem === null) {
                return 0;
              }
              if (elemType === "function") {
                return NaN;
              }
              if (elemType === "object") {
                return toDOMPointInit(elem);
              }
              return toUnrestrictedNumber(elem);
            });

          }

          return [toDOMPointInit(value)];

        }

        return [toUnrestrictedNumber(value)];

      }

      function toUnrestrictedNumber(value) {

        return +value;

      }

      function toCornerPoint(value) {

        const asNumber = toUnrestrictedNumber(value);
        if (Number.isFinite(asNumber)) {

          return {
            x: asNumber,
            y: asNumber
          };

        }
        if (Object(value) === value) {

          return {
            x: toUnrestrictedNumber(value.x ?? 0),
            y: toUnrestrictedNumber(value.y ?? 0)
          };

        }

        return {
          x: NaN,
          y: NaN
        };

      }

      function fixOverlappingCorners(corners) {

        const [upperLeft, upperRight, lowerRight, lowerLeft] = corners;
        const factors = [
          Math.abs(w) / (upperLeft.x + upperRight.x),
          Math.abs(h) / (upperRight.y + lowerRight.y),
          Math.abs(w) / (lowerRight.x + lowerLeft.x),
          Math.abs(h) / (upperLeft.y + lowerLeft.y)
        ];
        const minFactor = Math.min(...factors);
        if (minFactor <= 1) {

          for (const radii of corners) {

            radii.x *= minFactor;
            radii.y *= minFactor;

          }

        }

      }

    }

    function getErrorMessageHeader(instance) {

      return `Failed to execute 'roundRect' on '${getConstructorName(instance)}':`;

    }

    function getConstructorName(instance) {

      return Object(instance) === instance &&
        instance instanceof Path2D ? "Path2D" :
        instance instanceof globalThis?.CanvasRenderingContext2D ? "CanvasRenderingContext2D" :
          instance instanceof globalThis?.OffscreenCanvasRenderingContext2D ? "OffscreenCanvasRenderingContext2D" :
            instance?.constructor.name ||
            instance;

    }

    var Path2D$1 = (function () {

      var Path2D;

      Path2D = function (ctx, arg) {
        if (!ctx) {
          console.error("Path2D must be passed the context");
        }
        if (typeof arg === "string") {
          // Initialize from string path.
          this.__pathString = arg;
        } else if (typeof arg === "object") {
          // Initialize by copying another path.
          this.__pathString = arg.__pathString;
        } else {
          // Initialize a new path.
          this.__pathString = "";
        }

        this.ctx = ctx;
        this.__subPaths = []; // Array of path string/transform pairs.
        this.__currentPosition = { x: undefined, y: undefined };
      };

      Path2D.prototype.__matrixTransform = function (x, y) {
        return this.ctx.__matrixTransform(x, y);
      };

      Path2D.prototype.addPath = function (path, transform = undefined) {
        this.__subPaths.push({ path: path, transform: transform });
      };

      Path2D.prototype.appendPath = function (path) {
        this.__pathString = this.__pathString + " " + path;
      };

      /**
       * Closes the current path
       */
      Path2D.prototype.closePath = function () {
        this.appendPath("Z");
      };

      /**
       * Adds the move command to the current path element,
       * if the currentPathElement is not empty create a new path element
       */
      Path2D.prototype.moveTo = function (x, y) {
        // creates a new subpath with the given point
        this.__currentPosition = { x: x, y: y };
        this.appendPath(
          format("M {x} {y}", {
            x: this.__matrixTransform(x, y).x,
            y: this.__matrixTransform(x, y).y,
          })
        );
      };

      /**
       * Adds a line to command
       */
      Path2D.prototype.lineTo = function (x, y) {
        this.__currentPosition = { x: x, y: y };
        if (this.__pathString.indexOf("M") > -1) {
          this.appendPath(
            format("L {x} {y}", {
              x: this.__matrixTransform(x, y).x,
              y: this.__matrixTransform(x, y).y,
            })
          );
        } else {
          this.appendPath(
            format("M {x} {y}", {
              x: this.__matrixTransform(x, y).x,
              y: this.__matrixTransform(x, y).y,
            })
          );
        }
      };

      /**
       *  Adds a rectangle to the path.
       */
      Path2D.prototype.rect = function (x, y, width, height) {
        this.moveTo(x, y);
        this.lineTo(x + width, y);
        this.lineTo(x + width, y + height);
        this.lineTo(x, y + height);
        this.lineTo(x, y);
      };

      /**
       *  Adds a rounded rectangle to the path.
       */
      Path2D.prototype.roundRect = roundRect$1;

      /**
       * Add a bezier command
       */
      Path2D.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        this.__currentPosition = { x: x, y: y };
        this.appendPath(
          format("C {cp1x} {cp1y} {cp2x} {cp2y} {x} {y}", {
            cp1x: this.__matrixTransform(cp1x, cp1y).x,
            cp1y: this.__matrixTransform(cp1x, cp1y).y,
            cp2x: this.__matrixTransform(cp2x, cp2y).x,
            cp2y: this.__matrixTransform(cp2x, cp2y).y,
            x: this.__matrixTransform(x, y).x,
            y: this.__matrixTransform(x, y).y,
          })
        );
      };

      /**
       * Adds a quadratic curve to command
       */
      Path2D.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        this.__currentPosition = { x: x, y: y };
        this.appendPath(
          format("Q {cpx} {cpy} {x} {y}", {
            cpx: this.__matrixTransform(cpx, cpy).x,
            cpy: this.__matrixTransform(cpx, cpy).y,
            x: this.__matrixTransform(x, y).x,
            y: this.__matrixTransform(x, y).y,
          })
        );
      };

      /**
       *  Arc command!
       */
      Path2D.prototype.arc = function (
        x,
        y,
        radius,
        startAngle,
        endAngle,
        counterClockwise
      ) {
        // in canvas no circle is drawn if no angle is provided.
        if (startAngle === endAngle) {
          return;
        }
        startAngle = startAngle % (2 * Math.PI);
        endAngle = endAngle % (2 * Math.PI);
        if (startAngle === endAngle) {
          //circle time! subtract some of the angle so svg is happy (svg elliptical arc can't draw a full circle)
          endAngle =
            (endAngle + 2 * Math.PI - 0.001 * (counterClockwise ? -1 : 1)) %
            (2 * Math.PI);
        }
        var endX = x + radius * Math.cos(endAngle),
          endY = y + radius * Math.sin(endAngle),
          startX = x + radius * Math.cos(startAngle),
          startY = y + radius * Math.sin(startAngle),
          sweepFlag = counterClockwise ? 0 : 1,
          largeArcFlag = 0,
          diff = endAngle - startAngle;

        // https://github.com/gliffy/canvas2svg/issues/4
        if (diff < 0) {
          diff += 2 * Math.PI;
        }

        if (counterClockwise) {
          largeArcFlag = diff > Math.PI ? 0 : 1;
        } else {
          largeArcFlag = diff > Math.PI ? 1 : 0;
        }

        var scaleX = Math.hypot(
          this.ctx.__transformMatrix.a,
          this.ctx.__transformMatrix.b
        );
        var scaleY = Math.hypot(
          this.ctx.__transformMatrix.c,
          this.ctx.__transformMatrix.d
        );

        this.lineTo(startX, startY);
        this.appendPath(
          format(
            "A {rx} {ry} {xAxisRotation} {largeArcFlag} {sweepFlag} {endX} {endY}",
            {
              rx: radius * scaleX,
              ry: radius * scaleY,
              xAxisRotation: 0,
              largeArcFlag: largeArcFlag,
              sweepFlag: sweepFlag,
              endX: this.__matrixTransform(endX, endY).x,
              endY: this.__matrixTransform(endX, endY).y,
            }
          )
        );

        this.__currentPosition = { x: endX, y: endY };
      };

      /**
       * Adds the arcTo to the current path. Based on Webkit implementation from
       * https://github.com/WebKit/webkit/blob/main/Source/WebCore/platform/graphics/cairo/PathCairo.cpp
       *
       * @see http://www.w3.org/TR/2015/WD-2dcontext-20150514/#dom-context-2d-arcto
       */
      Path2D.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        // Let the point (x0, y0) be the last point in the subpath.
        var x0 = this.__currentPosition && this.__currentPosition.x;
        var y0 = this.__currentPosition && this.__currentPosition.y;

        // First ensure there is a subpath for (x1, y1).
        if (typeof x0 == "undefined" || typeof y0 == "undefined") {
          return;
        }

        // Negative values for radius must cause the implementation to throw an IndexSizeError exception.
        if (radius < 0) {
          throw new Error(
            "IndexSizeError: The radius provided (" + radius + ") is negative."
          );
        }

        // If the point (x0, y0) is equal to the point (x1, y1),
        // or if the point (x1, y1) is equal to the point (x2, y2),
        // or if the radius radius is zero,
        // then the method must add the point (x1, y1) to the subpath,
        // and connect that point to the previous point (x0, y0) by a straight line.
        if ((x0 === x1 && y0 === y1) || (x1 === x2 && y1 === y2) || radius === 0) {
          this.lineTo(x1, y1);
          return;
        }

        const p1p0 = [x0 - x1, y0 - y1];
        const p1p2 = [x2 - x1, y2 - y1];
        const p1p0_length = Math.hypot(p1p0[0], p1p0[1]);
        const p1p2_length = Math.hypot(p1p2[0], p1p2[1]);
        const cos_phi = (p1p0[0] * p1p2[0] + p1p0[1] * p1p2[1]) / (p1p0_length * p1p2_length);
        // all points on a line logic
        if (cos_phi == -1) {
          this.lineTo(x1, y1);
          return;
        }
        if (cos_phi == 1) {
          // add infinite far away point
          const max_length = 65535;
          const factor_max = max_length / p1p0_length;
          const ep = [xp0 + factor_max * p1p0[0], y0 + factor_max * p1p0[1]];
          this.lineTo(ep[0], ep[1]);
          return;
        }

        const tangent = radius / Math.tan(Math.acos(cos_phi) / 2);
        const factor_p1p0 = tangent / p1p0_length;
        const t_p1p0 = [x1 + factor_p1p0 * p1p0[0], y1 + factor_p1p0 * p1p0[1]];

        let orth_p1p0 = [p1p0[1], -p1p0[0]];
        const orth_p1p0_length = Math.hypot(orth_p1p0[0], orth_p1p0[1]);
        const factor_ra = radius / orth_p1p0_length;

        // angle between orth_p1p0 and p1p2 to get the right vector orthographic to p1p0
        const cos_alpha = (orth_p1p0[0] * p1p2[0] + orth_p1p0[1] * p1p2[1]) / (orth_p1p0_length * p1p2_length);
        if (cos_alpha < 0) {
          orth_p1p0 = [-orth_p1p0[0], -orth_p1p0[1]];
        }

        const p = [t_p1p0[0] + factor_ra * orth_p1p0[0], t_p1p0[1] + factor_ra * orth_p1p0[1]];

        // calculate angles for addArc
        orth_p1p0 = [-orth_p1p0[0], -orth_p1p0[1]];
        let sa = Math.acos(orth_p1p0[0] / orth_p1p0_length);
        if (orth_p1p0[1] < 0) {
          sa = 2 * Math.PI - sa;
        }

        // anticlockwise logic
        let anticlockwise = false;

        const factor_p1p2 = tangent / p1p2_length;
        const t_p1p2 = [x1 + factor_p1p2 * p1p2[0], y1 + factor_p1p2 * p1p2[1]];
        const orth_p1p2 = [t_p1p2[0] - p[0], t_p1p2[1] - p[1]];
        const orth_p1p2_length = Math.hypot(orth_p1p2[0], orth_p1p2[1]);
        let ea = Math.acos(orth_p1p2[0] / orth_p1p2_length);
        if (orth_p1p2[1] < 0) {
          ea = 2 * Math.PI - ea;
        }
        if (sa > ea && sa - ea < Math.PI)
          anticlockwise = true;
        if (sa < ea && ea - sa > Math.PI)
          anticlockwise = true;

        this.lineTo(t_p1p0[0], t_p1p0[1]);
        this.arc(p[0], p[1], radius, sa, ea, anticlockwise);
      };

      /**
       *  Ellipse command!
       */
      Path2D.prototype.ellipse = function (
        x,
        y,
        radiusX,
        radiusY,
        rotation,
        startAngle,
        endAngle,
        counterClockwise
      ) {
        if (startAngle === endAngle) {
          return;
        }

        var transformedCenter = this.__matrixTransform(x, y);
        x = transformedCenter.x;
        y = transformedCenter.y;
        var scale = this.ctx.__getTransformScale();
        radiusX = radiusX * scale.x;
        radiusY = radiusY * scale.y;
        rotation = rotation + this.ctx.__getTransformRotation();

        startAngle = startAngle % (2 * Math.PI);
        endAngle = endAngle % (2 * Math.PI);
        if (startAngle === endAngle) {
          endAngle =
            (endAngle + 2 * Math.PI - 0.001 * (counterClockwise ? -1 : 1)) %
            (2 * Math.PI);
        }
        var endX =
          x +
          Math.cos(-rotation) * radiusX * Math.cos(endAngle) +
          Math.sin(-rotation) * radiusY * Math.sin(endAngle),
          endY =
            y -
            Math.sin(-rotation) * radiusX * Math.cos(endAngle) +
            Math.cos(-rotation) * radiusY * Math.sin(endAngle),
          startX =
            x +
            Math.cos(-rotation) * radiusX * Math.cos(startAngle) +
            Math.sin(-rotation) * radiusY * Math.sin(startAngle),
          startY =
            y -
            Math.sin(-rotation) * radiusX * Math.cos(startAngle) +
            Math.cos(-rotation) * radiusY * Math.sin(startAngle),
          sweepFlag = counterClockwise ? 0 : 1,
          largeArcFlag = 0,
          diff = endAngle - startAngle;

        if (diff < 0) {
          diff += 2 * Math.PI;
        }

        if (counterClockwise) {
          largeArcFlag = diff > Math.PI ? 0 : 1;
        } else {
          largeArcFlag = diff > Math.PI ? 1 : 0;
        }

        // Transform is already applied, so temporarily remove since lineTo
        // will apply it again.
        var currentTransform = this.ctx.__transformMatrix;
        this.ctx.resetTransform();
        this.lineTo(startX, startY);
        this.ctx.__transformMatrix = currentTransform;

        this.appendPath(
          format(
            "A {rx} {ry} {xAxisRotation} {largeArcFlag} {sweepFlag} {endX} {endY}",
            {
              rx: radiusX,
              ry: radiusY,
              xAxisRotation: rotation * (180 / Math.PI),
              largeArcFlag: largeArcFlag,
              sweepFlag: sweepFlag,
              endX: endX,
              endY: endY,
            }
          )
        );

        this.__currentPosition = { x: endX, y: endY };
      };

      return Path2D;
    })();

    /*!!
     *  SVGCanvas v2.0.3
     *  Draw on SVG using Canvas's 2D Context API.
     *
     *  Licensed under the MIT license:
     *  http://www.opensource.org/licenses/mit-license.php
     *
     *  Author:
     *  Kerry Liu
     *  Zeno Zeng
     *
     *  Copyright (c) 2014 Gliffy Inc.
     *  Copyright (c) 2021 Zeno Zeng
     */


    var Context = (function () {

      var STYLES, Context, CanvasGradient, CanvasPattern, namedEntities;

      //helper function that generates a random string
      function randomString(holder) {
        var chars, randomstring, i;
        if (!holder) {
          throw new Error(
            "cannot create a random attribute name for an undefined object"
          );
        }
        chars = "ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz";
        randomstring = "";
        do {
          randomstring = "";
          for (i = 0; i < 12; i++) {
            randomstring += chars[Math.floor(Math.random() * chars.length)];
          }
        } while (holder[randomstring]);
        return randomstring;
      }

      //helper function to map named to numbered entities
      function createNamedToNumberedLookup(items, radix) {
        var i,
          entity,
          lookup = {},
          base10;
        items = items.split(",");
        radix = radix || 10;
        // Map from named to numbered entities.
        for (i = 0; i < items.length; i += 2) {
          entity = "&" + items[i + 1] + ";";
          base10 = parseInt(items[i], radix);
          lookup[entity] = "&#" + base10 + ";";
        }
        //FF and IE need to create a regex from hex values ie &nbsp; == \xa0
        lookup["\\xa0"] = "&#160;";
        return lookup;
      }

      //helper function to map canvas-textAlign to svg-textAnchor
      function getTextAnchor(textAlign) {
        //TODO: support rtl languages
        var mapping = {
          left: "start",
          right: "end",
          center: "middle",
          start: "start",
          end: "end",
        };
        return mapping[textAlign] || mapping.start;
      }

      //helper function to map canvas-textBaseline to svg-dominantBaseline
      function getDominantBaseline(textBaseline) {
        //INFO: not supported in all browsers
        var mapping = {
          alphabetic: "alphabetic",
          hanging: "hanging",
          top: "text-before-edge",
          bottom: "text-after-edge",
          middle: "central",
        };
        return mapping[textBaseline] || mapping.alphabetic;
      }

      // Unpack entities lookup where the numbers are in radix 32 to reduce the size
      // entity mapping courtesy of tinymce
      namedEntities = createNamedToNumberedLookup(
        "50,nbsp,51,iexcl,52,cent,53,pound,54,curren,55,yen,56,brvbar,57,sect,58,uml,59,copy," +
        "5a,ordf,5b,laquo,5c,not,5d,shy,5e,reg,5f,macr,5g,deg,5h,plusmn,5i,sup2,5j,sup3,5k,acute," +
        "5l,micro,5m,para,5n,middot,5o,cedil,5p,sup1,5q,ordm,5r,raquo,5s,frac14,5t,frac12,5u,frac34," +
        "5v,iquest,60,Agrave,61,Aacute,62,Acirc,63,Atilde,64,Auml,65,Aring,66,AElig,67,Ccedil," +
        "68,Egrave,69,Eacute,6a,Ecirc,6b,Euml,6c,Igrave,6d,Iacute,6e,Icirc,6f,Iuml,6g,ETH,6h,Ntilde," +
        "6i,Ograve,6j,Oacute,6k,Ocirc,6l,Otilde,6m,Ouml,6n,times,6o,Oslash,6p,Ugrave,6q,Uacute," +
        "6r,Ucirc,6s,Uuml,6t,Yacute,6u,THORN,6v,szlig,70,agrave,71,aacute,72,acirc,73,atilde,74,auml," +
        "75,aring,76,aelig,77,ccedil,78,egrave,79,eacute,7a,ecirc,7b,euml,7c,igrave,7d,iacute,7e,icirc," +
        "7f,iuml,7g,eth,7h,ntilde,7i,ograve,7j,oacute,7k,ocirc,7l,otilde,7m,ouml,7n,divide,7o,oslash," +
        "7p,ugrave,7q,uacute,7r,ucirc,7s,uuml,7t,yacute,7u,thorn,7v,yuml,ci,fnof,sh,Alpha,si,Beta," +
        "sj,Gamma,sk,Delta,sl,Epsilon,sm,Zeta,sn,Eta,so,Theta,sp,Iota,sq,Kappa,sr,Lambda,ss,Mu," +
        "st,Nu,su,Xi,sv,Omicron,t0,Pi,t1,Rho,t3,Sigma,t4,Tau,t5,Upsilon,t6,Phi,t7,Chi,t8,Psi," +
        "t9,Omega,th,alpha,ti,beta,tj,gamma,tk,delta,tl,epsilon,tm,zeta,tn,eta,to,theta,tp,iota," +
        "tq,kappa,tr,lambda,ts,mu,tt,nu,tu,xi,tv,omicron,u0,pi,u1,rho,u2,sigmaf,u3,sigma,u4,tau," +
        "u5,upsilon,u6,phi,u7,chi,u8,psi,u9,omega,uh,thetasym,ui,upsih,um,piv,812,bull,816,hellip," +
        "81i,prime,81j,Prime,81u,oline,824,frasl,88o,weierp,88h,image,88s,real,892,trade,89l,alefsym," +
        "8cg,larr,8ch,uarr,8ci,rarr,8cj,darr,8ck,harr,8dl,crarr,8eg,lArr,8eh,uArr,8ei,rArr,8ej,dArr," +
        "8ek,hArr,8g0,forall,8g2,part,8g3,exist,8g5,empty,8g7,nabla,8g8,isin,8g9,notin,8gb,ni,8gf,prod," +
        "8gh,sum,8gi,minus,8gn,lowast,8gq,radic,8gt,prop,8gu,infin,8h0,ang,8h7,and,8h8,or,8h9,cap,8ha,cup," +
        "8hb,int,8hk,there4,8hs,sim,8i5,cong,8i8,asymp,8j0,ne,8j1,equiv,8j4,le,8j5,ge,8k2,sub,8k3,sup,8k4," +
        "nsub,8k6,sube,8k7,supe,8kl,oplus,8kn,otimes,8l5,perp,8m5,sdot,8o8,lceil,8o9,rceil,8oa,lfloor,8ob," +
        "rfloor,8p9,lang,8pa,rang,9ea,loz,9j0,spades,9j3,clubs,9j5,hearts,9j6,diams,ai,OElig,aj,oelig,b0," +
        "Scaron,b1,scaron,bo,Yuml,m6,circ,ms,tilde,802,ensp,803,emsp,809,thinsp,80c,zwnj,80d,zwj,80e,lrm," +
        "80f,rlm,80j,ndash,80k,mdash,80o,lsquo,80p,rsquo,80q,sbquo,80s,ldquo,80t,rdquo,80u,bdquo,810,dagger," +
        "811,Dagger,81g,permil,81p,lsaquo,81q,rsaquo,85c,euro",
        32
      );

      //Some basic mappings for attributes and default values.
      STYLES = {
        strokeStyle: {
          svgAttr: "stroke", //corresponding svg attribute
          canvas: "#000000", //canvas default
          svg: "none", //svg default
          apply: "stroke", //apply on stroke() or fill()
        },
        fillStyle: {
          svgAttr: "fill",
          canvas: "#000000",
          svg: null, //svg default is black, but we need to special case this to handle canvas stroke without fill
          apply: "fill",
        },
        lineCap: {
          svgAttr: "stroke-linecap",
          canvas: "butt",
          svg: "butt",
          apply: "stroke",
        },
        lineJoin: {
          svgAttr: "stroke-linejoin",
          canvas: "miter",
          svg: "miter",
          apply: "stroke",
        },
        miterLimit: {
          svgAttr: "stroke-miterlimit",
          canvas: 10,
          svg: 4,
          apply: "stroke",
        },
        lineWidth: {
          svgAttr: "stroke-width",
          canvas: 1,
          svg: 1,
          apply: "stroke",
        },
        globalAlpha: {
          svgAttr: "opacity",
          canvas: 1,
          svg: 1,
          apply: "fill stroke",
        },
        font: {
          //font converts to multiple svg attributes, there is custom logic for this
          canvas: "10px sans-serif",
        },
        shadowColor: {
          canvas: "#000000",
        },
        shadowOffsetX: {
          canvas: 0,
        },
        shadowOffsetY: {
          canvas: 0,
        },
        shadowBlur: {
          canvas: 0,
        },
        textAlign: {
          canvas: "start",
        },
        textBaseline: {
          canvas: "alphabetic",
        },
        lineDash: {
          svgAttr: "stroke-dasharray",
          canvas: [],
          svg: null,
          apply: "stroke",
        },
      };

      /**
       *
       * @param gradientNode - reference to the gradient
       * @constructor
       */
      CanvasGradient = function (gradientNode, ctx) {
        this.__root = gradientNode;
        this.__ctx = ctx;
      };

      /**
       * Adds a color stop to the gradient root
       */
      CanvasGradient.prototype.addColorStop = function (offset, color) {
        var stop = this.__ctx.__createElement("stop"),
          regex,
          matches;
        stop.setAttribute("offset", offset);
        if (toString(color).indexOf("rgba") !== -1) {
          //separate alpha value, since webkit can't handle it
          regex =
            /rgba\(\s*(\d*\.?\d+)\s*,\s*(\d*\.?\d+)\s*,\s*(\d*\.?\d+)\s*,\s*(\d?\.?\d*)\s*\)/gi;
          matches = regex.exec(color);
          stop.setAttribute(
            "stop-color",
            format("rgb({r},{g},{b})", {
              r: matches[1],
              g: matches[2],
              b: matches[3],
            })
          );
          stop.setAttribute("stop-opacity", matches[4]);
        } else {
          stop.setAttribute("stop-color", toString(color));
        }
        this.__root.appendChild(stop);
      };

      CanvasPattern = function (pattern, ctx) {
        this.__root = pattern;
        this.__ctx = ctx;
      };

      /**
       * The mock canvas context
       * @param o - options include:
       * ctx - existing Context2D to wrap around
       * width - width of your canvas (defaults to 500)
       * height - height of your canvas (defaults to 500)
       * enableMirroring - enables canvas mirroring (get image data) (defaults to false)
       * document - the document object (defaults to the current document)
       */
      Context = function (o) {
        var defaultOptions = { width: 500, height: 500, enableMirroring: false },
          options;

        // keep support for this way of calling Context: new Context(width, height)
        if (arguments.length > 1) {
          options = defaultOptions;
          options.width = arguments[0];
          options.height = arguments[1];
        } else if (!o) {
          options = defaultOptions;
        } else {
          options = o;
        }

        if (!(this instanceof Context)) {
          //did someone call this without new?
          return new Context(options);
        }

        //setup options
        this.width = options.width || defaultOptions.width;
        this.height = options.height || defaultOptions.height;
        this.enableMirroring =
          options.enableMirroring !== undefined
            ? options.enableMirroring
            : defaultOptions.enableMirroring;

        this.canvas = this; ///point back to this instance!
        this.__document = options.document || document;

        // allow passing in an existing context to wrap around
        // if a context is passed in, we know a canvas already exist
        if (options.ctx) {
          this.__ctx = options.ctx;
        } else {
          this.__canvas = this.__document.createElement("canvas");
          this.__ctx = this.__canvas.getContext("2d");
        }

        this.__setDefaultStyles();
        this.__styleStack = [this.__getStyleState()];
        this.__groupStack = [];

        //the root svg element
        this.__root = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          "svg"
        );
        this.__root.setAttribute("version", 1.1);
        this.__root.setAttribute("xmlns", "http://www.w3.org/2000/svg");
        this.__root.setAttributeNS(
          "http://www.w3.org/2000/xmlns/",
          "xmlns:xlink",
          "http://www.w3.org/1999/xlink"
        );
        this.__root.setAttribute("width", this.width);
        this.__root.setAttribute("height", this.height);

        //make sure we don't generate the same ids in defs
        this.__ids = {};

        //defs tag
        this.__defs = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          "defs"
        );
        this.__root.appendChild(this.__defs);

        //also add a group child. the svg element can't use the transform attribute
        this.__currentElement = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          "g"
        );
        this.__root.appendChild(this.__currentElement);

        // init transformation matrix
        this.resetTransform();

        this.__options = options;
        this.__id = Math.random().toString(16).substring(2, 8);
        this.__debug(`new`, o);
      };

      /**
       * Log
       *
       * @private
       */
      Context.prototype.__debug = function (...data) {
        if (!this.__options.debug) {
          return;
        }
        console.debug(`svgcanvas#${this.__id}:`, ...data);
      };

      /**
       * Creates the specified svg element
       * @private
       */
      Context.prototype.__createElement = function (
        elementName,
        properties,
        resetFill
      ) {
        if (typeof properties === "undefined") {
          properties = {};
        }

        var element = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          elementName
        ),
          keys = Object.keys(properties),
          i,
          key;
        if (resetFill) {
          //if fill or stroke is not specified, the svg element should not display. By default SVG's fill is black.
          element.setAttribute("fill", "none");
          element.setAttribute("stroke", "none");
        }
        for (i = 0; i < keys.length; i++) {
          key = keys[i];
          element.setAttribute(key, properties[key]);
        }
        return element;
      };

      /**
       * Applies default canvas styles to the context
       * @private
       */
      Context.prototype.__setDefaultStyles = function () {
        //default 2d canvas context properties see:http://www.w3.org/TR/2dcontext/
        var keys = Object.keys(STYLES),
          i,
          key;
        for (i = 0; i < keys.length; i++) {
          key = keys[i];
          this[key] = STYLES[key].canvas;
        }
      };

      /**
       * Applies styles on restore
       * @param styleState
       * @private
       */
      Context.prototype.__applyStyleState = function (styleState) {
        var keys = Object.keys(styleState),
          i,
          key;
        for (i = 0; i < keys.length; i++) {
          key = keys[i];
          this[key] = styleState[key];
        }
      };

      /**
       * Gets the current style state
       * @return {Object}
       * @private
       */
      Context.prototype.__getStyleState = function () {
        var i,
          styleState = {},
          keys = Object.keys(STYLES),
          key;
        for (i = 0; i < keys.length; i++) {
          key = keys[i];
          styleState[key] = this[key];
        }
        return styleState;
      };

      /**
       * @see https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/transform
       */
      Context.prototype.__applyTransformation = function (element, matrix) {
        const { a, b, c, d, e, f } = matrix || this.getTransform();
        element.setAttribute("transform", `matrix(${a} ${b} ${c} ${d} ${e} ${f})`);
      };

      /**
       * Apples the current styles to the current SVG element. On "ctx.fill" or "ctx.stroke"
       * @param type
       * @private
       */
      Context.prototype.__applyStyleToElement = function (element, type) {
        var currentElement = element;
        var currentStyleGroup = this.__currentElementsToStyle;
        if (currentStyleGroup) {
          currentElement.setAttribute(type, "");
          currentElement = currentStyleGroup.element;
          currentStyleGroup.children.forEach(function (node) {
            node.setAttribute(type, "");
          });
        }

        var keys = Object.keys(STYLES),
          i,
          style,
          value,
          regex,
          matches,
          id,
          nodeIndex,
          node;
        for (i = 0; i < keys.length; i++) {
          style = STYLES[keys[i]];
          value = this[keys[i]];
          if (style.apply) {
            //is this a gradient or pattern?
            if (value instanceof CanvasPattern) {
              //pattern
              if (value.__ctx) {
                //copy over defs
                for (
                  nodeIndex = 0;
                  nodeIndex < value.__ctx.__defs.childNodes.length;
                  nodeIndex++
                ) {
                  node = value.__ctx.__defs.childNodes[nodeIndex];
                  id = node.getAttribute("id");
                  this.__ids[id] = id;
                  this.__defs.appendChild(node);
                }
              }
              currentElement.setAttribute(
                style.apply,
                format("url(#{id})", { id: value.__root.getAttribute("id") })
              );
            } else if (value instanceof CanvasGradient) {
              //gradient
              currentElement.setAttribute(
                style.apply,
                format("url(#{id})", { id: value.__root.getAttribute("id") })
              );
            } else if (style.apply.indexOf(type) !== -1 && style.svg !== value) {
              if (
                (style.svgAttr === "stroke" || style.svgAttr === "fill") &&
                value.indexOf("rgba") !== -1
              ) {
                //separate alpha value, since illustrator can't handle it
                regex =
                  /rgba\(\s*(\d*\.?\d+)\s*,\s*(\d*\.?\d+)\s*,\s*(\d*\.?\d+)\s*,\s*(\d?\.?\d*)\s*\)/gi;
                matches = regex.exec(value);
                currentElement.setAttribute(
                  style.svgAttr,
                  format("rgb({r},{g},{b})", {
                    r: matches[1],
                    g: matches[2],
                    b: matches[3],
                  })
                );
                //should take globalAlpha here
                var opacity = matches[4];
                var globalAlpha = this.globalAlpha;
                if (globalAlpha != null) {
                  opacity *= globalAlpha;
                }
                currentElement.setAttribute(style.svgAttr + "-opacity", opacity);
              } else {
                var attr = style.svgAttr;
                if (keys[i] === "globalAlpha") {
                  attr = type + "-" + style.svgAttr;
                  if (currentElement.getAttribute(attr)) {
                    //fill-opacity or stroke-opacity has already been set by stroke or fill.
                    continue;
                  }
                } else if (keys[i] === "lineWidth") {
                  var scale = this.__getTransformScale();
                  value = value * Math.max(scale.x, scale.y);
                }
                //otherwise only update attribute if right type, and not svg default
                currentElement.setAttribute(attr, value);
              }
            }
          }
        }
      };

      /**
       * Will return the closest group or svg node. May return the current element.
       * @private
       */
      Context.prototype.__closestGroupOrSvg = function (node) {
        node = node || this.__currentElement;
        if (node.nodeName === "g" || node.nodeName === "svg") {
          return node;
        } else {
          return this.__closestGroupOrSvg(node.parentNode);
        }
      };

      /**
       * Returns the serialized value of the svg so far
       * @param fixNamedEntities - Standalone SVG doesn't support named entities, which document.createTextNode encodes.
       *                           If true, we attempt to find all named entities and encode it as a numeric entity.
       * @return serialized svg
       */
      Context.prototype.getSerializedSvg = function (fixNamedEntities) {
        var serialized = new XMLSerializer().serializeToString(this.__root),
          keys,
          i,
          key,
          value,
          regexp,
          xmlns;

        //IE search for a duplicate xmnls because they didn't implement setAttributeNS correctly
        xmlns =
          /xmlns="http:\/\/www\.w3\.org\/2000\/svg".+xmlns="http:\/\/www\.w3\.org\/2000\/svg/gi;
        if (xmlns.test(serialized)) {
          serialized = serialized.replace(
            'xmlns="http://www.w3.org/2000/svg',
            'xmlns:xlink="http://www.w3.org/1999/xlink'
          );
        }

        if (fixNamedEntities) {
          keys = Object.keys(namedEntities);
          //loop over each named entity and replace with the proper equivalent.
          for (i = 0; i < keys.length; i++) {
            key = keys[i];
            value = namedEntities[key];
            regexp = new RegExp(key, "gi");
            if (regexp.test(serialized)) {
              serialized = serialized.replace(regexp, value);
            }
          }
        }

        return serialized;
      };

      Context.prototype.createPath = function (arg) {
        return new Path2D$1(this, arg);
      };

      /**
       * Returns the root svg
       * @return
       */
      Context.prototype.getSvg = function () {
        return this.__root;
      };

      /**
       * Will generate a group tag.
       */
      Context.prototype.save = function () {
        var group = this.__createElement("g");
        var parent = this.__closestGroupOrSvg();
        this.__groupStack.push(parent);
        parent.appendChild(group);
        this.__currentElement = group;
        const style = this.__getStyleState();

        this.__debug("save style", style);
        this.__styleStack.push(style);
        if (!this.__transformMatrixStack) {
          this.__transformMatrixStack = [];
        }
        this.__transformMatrixStack.push(this.getTransform());
      };

      /**
       * Sets current element to parent, or just root if already root
       */
      Context.prototype.restore = function () {
        this.__currentElement = this.__groupStack.pop();
        this.__currentElementsToStyle = null;
        //Clearing canvas will make the poped group invalid, currentElement is set to the root group node.
        if (!this.__currentElement) {
          this.__currentElement = this.__root.childNodes[1];
        }
        var state = this.__styleStack.pop();
        this.__debug("restore style", state);
        this.__applyStyleState(state);
        if (this.__transformMatrixStack && this.__transformMatrixStack.length > 0) {
          this.setTransform(this.__transformMatrixStack.pop());
        }
      };

      Context.prototype.__createPathElement = function () {
        var path = this.__createElement("path", {}, true);
        var parent = this.__closestGroupOrSvg();
        parent.appendChild(path);
        return path;
      };

      /**
       * Create a new Path Element
       */
      Context.prototype.beginPath = function () {
        // Note that there is only one current default path, it is not part of the drawing state.
        // See also: https://html.spec.whatwg.org/multipage/scripting.html#current-default-path
        this.__currentDefaultPath = new Path2D$1(this);
        this.__currentPosition = {};
      };

      Context.prototype.closePath = function () {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.closePath();
      };

      Context.prototype.moveTo = function (x, y) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.moveTo(x, y);
      };

      Context.prototype.lineTo = function (x, y) {
        if (!this.__currentDefaultPath) {
          this.moveTo(x, y);
        }
        this.__currentDefaultPath.lineTo(x, y);
      };

      Context.prototype.rect = function (x, y, width, height) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.rect(x, y, width, height);
      };

      Context.prototype.roundRect = function (x, y, width, height, radii) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.roundRect(x, y, width, height, radii);
      };

      Context.prototype.bezierCurveTo = function (cp1x, cp1y, cp2x, cp2y, x, y) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.bezierCurveTo(cp1x, cp1y, cp2x, cp2y, x, y);
      };

      Context.prototype.quadraticCurveTo = function (cpx, cpy, x, y) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.quadraticCurveTo(cpx, cpy, x, y);
      };

      Context.prototype.arc = function (
        x,
        y,
        radius,
        startAngle,
        endAngle,
        counterClockwise
      ) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.arc(
          x,
          y,
          radius,
          startAngle,
          endAngle,
          counterClockwise
        );
      };

      Context.prototype.arcTo = function (x1, y1, x2, y2, radius) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.arcTo(x1, y1, x2, y2, radius);
      };

      Context.prototype.ellipse = function (
        x,
        y,
        radiusX,
        radiusY,
        rotation,
        startAngle,
        endAngle,
        counterClockwise
      ) {
        if (!this.__currentDefaultPath) {
          this.beginPath();
        }
        this.__currentDefaultPath.ellipse(
          x,
          y,
          radiusX,
          radiusY,
          rotation,
          startAngle,
          endAngle,
          counterClockwise
        );
      };

      /**
       * Sets the stroke property on the current element
       */
      Context.prototype.stroke = function (path2d) {
        this.__strokeOrFill(path2d, "stroke");
      };

      /**
       * Sets fill properties on the current element
       */
      Context.prototype.fill = function (path2d) {
        this.__strokeOrFill(path2d, "fill");
      };

      Context.prototype.__strokeOrFill = function (path2d, action) {
        var path;

        if (path2d) {
          path = path2d;
        } else {
          if (!this.__currentDefaultPath) {
            this.beginPath();
          }
          path = this.__currentDefaultPath;
        }

        if (path.__pathString.length > 0) {
          var pathElement = this.__createPathElement();
          this.__applyStyleToElement(pathElement, action);
          pathElement.setAttribute("paint-order", "fill stroke markers");
          pathElement.setAttribute("d", path.__pathString);
          if (path2d) {
            this.__applyTransformation(pathElement);
          }
        }

        if (path2d) {
          path2d.__subPaths.forEach((subPath) => {
            var pathElement = this.__createPathElement();
            this.__applyStyleToElement(pathElement, action);
            pathElement.setAttribute("paint-order", "fill stroke markers");
            pathElement.setAttribute("d", subPath.path.__pathString);
            if (subPath.transform) {
              this.__applyTransformation(pathElement, this.getTransform().multiply(subPath.transform));
            }
          });
        }
      };

      /**
       * adds a rectangle element
       */
      Context.prototype.fillRect = function (x, y, width, height) {
        let { a, b, c, d, e, f } = this.getTransform();
        if (
          JSON.stringify([a, b, c, d, e, f]) === JSON.stringify([1, 0, 0, 1, 0, 0])
        ) {
          //clear entire canvas
          if (
            x === 0 &&
            y === 0 &&
            width === this.width &&
            height === this.height
          ) {
            this.__clearCanvas();
          }
        }
        var rect, parent;
        rect = this.__createElement(
          "rect",
          {
            x: x,
            y: y,
            width: width,
            height: height,
          },
          true
        );
        parent = this.__closestGroupOrSvg();
        parent.appendChild(rect);
        this.__currentElement = rect;
        this.__applyTransformation(rect);
        this.__applyStyleToElement(this.__currentElement, "fill");
      };

      /**
       * Draws a rectangle with no fill
       * @param x
       * @param y
       * @param width
       * @param height
       */
      Context.prototype.strokeRect = function (x, y, width, height) {
        var rect, parent;
        rect = this.__createElement(
          "rect",
          {
            x: x,
            y: y,
            width: width,
            height: height,
          },
          true
        );
        parent = this.__closestGroupOrSvg();
        parent.appendChild(rect);
        this.__currentElement = rect;
        this.__applyTransformation(rect);
        this.__applyStyleToElement(this.__currentElement, "stroke");
      };

      /**
       * Clear entire canvas:
       * 1. save current transforms
       * 2. remove all the childNodes of the root g element
       */
      Context.prototype.__clearCanvas = function () {
        var rootGroup = this.__root.childNodes[1];
        this.__root.removeChild(rootGroup);
        this.__currentElement = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          "g"
        );
        this.__root.appendChild(this.__currentElement);
        //reset __groupStack as all the child group nodes are all removed.
        this.__groupStack = [];
      };

      /**
       * "Clears" a canvas by just drawing a white rectangle in the current group.
       */
      Context.prototype.clearRect = function (x, y, width, height) {
        let { a, b, c, d, e, f } = this.getTransform();
        if (
          JSON.stringify([a, b, c, d, e, f]) === JSON.stringify([1, 0, 0, 1, 0, 0])
        ) {
          //clear entire canvas
          if (
            x === 0 &&
            y === 0 &&
            width === this.width &&
            height === this.height
          ) {
            this.__clearCanvas();
            return;
          }
        }
        var rect,
          parent = this.__closestGroupOrSvg();
        rect = this.__createElement(
          "rect",
          {
            x: x,
            y: y,
            width: width,
            height: height,
            fill: "#FFFFFF",
          },
          true
        );
        this.__applyTransformation(rect);
        parent.appendChild(rect);
      };

      /**
       * Adds a linear gradient to a defs tag.
       * Returns a canvas gradient object that has a reference to it's parent def
       */
      Context.prototype.createLinearGradient = function (x1, y1, x2, y2) {
        var grad = this.__createElement(
          "linearGradient",
          {
            id: randomString(this.__ids),
            x1: x1 + "px",
            x2: x2 + "px",
            y1: y1 + "px",
            y2: y2 + "px",
            gradientUnits: "userSpaceOnUse",
          },
          false
        );
        this.__defs.appendChild(grad);
        return new CanvasGradient(grad, this);
      };

      /**
       * Adds a radial gradient to a defs tag.
       * Returns a canvas gradient object that has a reference to it's parent def
       */
      Context.prototype.createRadialGradient = function (x0, y0, r0, x1, y1, r1) {
        var grad = this.__createElement(
          "radialGradient",
          {
            id: randomString(this.__ids),
            cx: x1 + "px",
            cy: y1 + "px",
            r: r1 + "px",
            fx: x0 + "px",
            fy: y0 + "px",
            gradientUnits: "userSpaceOnUse",
          },
          false
        );
        this.__defs.appendChild(grad);
        return new CanvasGradient(grad, this);
      };

      /**
       * Fills or strokes text
       * @param text
       * @param x
       * @param y
       * @param action - stroke or fill
       * @private
       */
      Context.prototype.__applyText = function (text, x, y, action) {
        var el = document.createElement("span");
        el.setAttribute("style", "font:" + this.font);

        var style = el.style, // CSSStyleDeclaration object
          parent = this.__closestGroupOrSvg(),
          textElement = this.__createElement(
            "text",
            {
              "font-family": style.fontFamily,
              "font-size": style.fontSize,
              "font-style": style.fontStyle,
              "font-weight": style.fontWeight,

              // canvas doesn't support underline natively, but we do :)
              "text-decoration": this.__fontUnderline,
              x: x,
              y: y,
              "text-anchor": getTextAnchor(this.textAlign),
              "dominant-baseline": getDominantBaseline(this.textBaseline),
            },
            true
          );

        textElement.appendChild(this.__document.createTextNode(text));
        this.__currentElement = textElement;
        this.__applyTransformation(textElement);
        this.__applyStyleToElement(this.__currentElement, action);

        if (this.__fontHref) {
          var a = this.__createElement("a");
          // canvas doesn't natively support linking, but we do :)
          a.setAttributeNS(
            "http://www.w3.org/1999/xlink",
            "xlink:href",
            this.__fontHref
          );
          a.appendChild(textElement);
          textElement = a;
        }

        parent.appendChild(textElement);
      };

      /**
       * Creates a text element
       * @param text
       * @param x
       * @param y
       */
      Context.prototype.fillText = function (text, x, y) {
        this.__applyText(text, x, y, "fill");
      };

      /**
       * Strokes text
       * @param text
       * @param x
       * @param y
       */
      Context.prototype.strokeText = function (text, x, y) {
        this.__applyText(text, x, y, "stroke");
      };

      /**
       * No need to implement this for svg.
       * @param text
       * @return {TextMetrics}
       */
      Context.prototype.measureText = function (text) {
        this.__ctx.font = this.font;
        return this.__ctx.measureText(text);
      };

      /**
       * Generates a ClipPath from the clip command.
       */
      Context.prototype.clip = function (fillRule) {
        var group = this.__closestGroupOrSvg(),
          clipPath = this.__createElement("clipPath"),
          id = randomString(this.__ids);

        var pathElement = this.__createPathElement();
        pathElement.setAttribute("d", this.__currentDefaultPath.__pathString);
        // this.__applyTransformation(pathElement);

        clipPath.setAttribute("id", id);

        if (typeof fillRule === "string") {
          clipPath.setAttribute("clip-rule", fillRule);
        }

        clipPath.appendChild(pathElement);

        this.__defs.appendChild(clipPath);

        //set the clip path to this group
        group.setAttribute("clip-path", format("url(#{id})", { id: id }));

        this.__currentElement = group;
      };

      /**
       * Draws a canvas, image or mock context to this canvas.
       * Note that all svg dom manipulation uses node.childNodes rather than node.children for IE support.
       * http://www.whatwg.org/specs/web-apps/current-work/multipage/the-canvas-element.html#dom-context-2d-drawimage
       */
      Context.prototype.drawImage = function () {
        //convert arguments to a real array
        var args = Array.prototype.slice.call(arguments),
          image = args[0],
          dx,
          dy,
          dw,
          dh,
          sx = 0,
          sy = 0,
          sw,
          sh,
          parent,
          svg,
          defs,
          group,
          svgImage,
          canvas,
          context,
          id;

        if (args.length === 3) {
          dx = args[1];
          dy = args[2];
          sw = image.width;
          sh = image.height;
          dw = sw;
          dh = sh;
        } else if (args.length === 5) {
          dx = args[1];
          dy = args[2];
          dw = args[3];
          dh = args[4];
          sw = image.width;
          sh = image.height;
        } else if (args.length === 9) {
          sx = args[1];
          sy = args[2];
          sw = args[3];
          sh = args[4];
          dx = args[5];
          dy = args[6];
          dw = args[7];
          dh = args[8];
        } else {
          throw new Error(
            "Invalid number of arguments passed to drawImage: " + arguments.length
          );
        }

        parent = this.__closestGroupOrSvg();
        this.__currentElement;
        const matrix = this.getTransform().translate(dx, dy);
        if (image instanceof Context) {
          //canvas2svg mock canvas context. In the future we may want to clone nodes instead.
          //also I'm currently ignoring dw, dh, sw, sh, sx, sy for a mock context.
          svg = image.getSvg().cloneNode(true);
          if (svg.childNodes && svg.childNodes.length > 1) {
            defs = svg.childNodes[0];
            while (defs.childNodes.length) {
              id = defs.childNodes[0].getAttribute("id");
              this.__ids[id] = id;
              this.__defs.appendChild(defs.childNodes[0]);
            }
            group = svg.childNodes[1];
            if (group) {
              this.__applyTransformation(group, matrix);
              parent.appendChild(group);
            }
          }
        } else if (image.nodeName === "CANVAS" || image.nodeName === "IMG") {
          //canvas or image
          svgImage = this.__createElement("image");
          svgImage.setAttribute("width", dw);
          svgImage.setAttribute("height", dh);
          svgImage.setAttribute("preserveAspectRatio", "none");

          // Crop the image using a temporary canvas and convert to a bitmap
          canvas = this.__document.createElement("canvas");
          canvas.width = dw;
          canvas.height = dh;
          context = canvas.getContext("2d");
          context.drawImage(image, sx, sy, sw, sh, 0, 0, dw, dh);
          image = canvas;

          this.__applyTransformation(svgImage, matrix);
          svgImage.setAttributeNS(
            "http://www.w3.org/1999/xlink",
            "xlink:href",
            image.nodeName === "CANVAS"
              ? image.toDataURL()
              : image.getAttribute("src")
          );
          parent.appendChild(svgImage);
        }
      };

      /**
       * Generates a pattern tag
       */
      Context.prototype.createPattern = function (image, repetition) {
        var pattern = this.__document.createElementNS(
          "http://www.w3.org/2000/svg",
          "pattern"
        ),
          id = randomString(this.__ids),
          img;
        pattern.setAttribute("id", id);
        pattern.setAttribute("width", image.width);
        pattern.setAttribute("height", image.height);
        // We want the pattern sizing to be absolute, and not relative
        // https://developer.mozilla.org/en-US/docs/Web/SVG/Tutorial/Patterns
        // https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/patternUnits
        pattern.setAttribute("patternUnits", "userSpaceOnUse");

        if (image.nodeName === "CANVAS" || image.nodeName === "IMG") {
          img = this.__document.createElementNS(
            "http://www.w3.org/2000/svg",
            "image"
          );
          img.setAttribute("width", image.width);
          img.setAttribute("height", image.height);
          img.setAttributeNS(
            "http://www.w3.org/1999/xlink",
            "xlink:href",
            image.nodeName === "CANVAS"
              ? image.toDataURL()
              : image.getAttribute("src")
          );
          pattern.appendChild(img);
          this.__defs.appendChild(pattern);
        } else if (image instanceof Context) {
          pattern.appendChild(image.__root.childNodes[1]);
          this.__defs.appendChild(pattern);
        }
        return new CanvasPattern(pattern, this);
      };

      Context.prototype.setLineDash = function (dashArray) {
        if (dashArray && dashArray.length > 0) {
          this.lineDash = dashArray.join(",");
        } else {
          this.lineDash = null;
        }
      };

      Context.prototype.isPointInStroke = function (path2d, x, y) {
        if (this.__ctx) {
          return this.__ctx.isPointInStroke(path2d, x, y);
        }

        // TODO: method stub
        return false;
      };

      /**
       * SetTransform changes the current transformation matrix to
       * the matrix given by the arguments as described below.
       *
       * @see https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/setTransform
       */
      Context.prototype.setTransform = function (a, b, c, d, e, f) {
        if (a instanceof DOMMatrix) {
          this.__transformMatrix = new DOMMatrix([a.a, a.b, a.c, a.d, a.e, a.f]);
        } else {
          this.__transformMatrix = new DOMMatrix([a, b, c, d, e, f]);
        }
      };

      /**
       * GetTransform Returns a copy of the current transformation matrix,
       * as a newly created DOMMAtrix Object
       *
       * @returns A DOMMatrix Object
       */
      Context.prototype.getTransform = function () {
        let { a, b, c, d, e, f } = this.__transformMatrix;
        return new DOMMatrix([a, b, c, d, e, f]);
      };

      /**
       * ResetTransform resets the current transformation matrix to the identity matrix
       *
       * @see https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/resetTransform
       */
      Context.prototype.resetTransform = function () {
        this.setTransform(1, 0, 0, 1, 0, 0);
      };

      /**
       * Add the scaling transformation described by the arguments to the current transformation matrix.
       *
       * @param x The x argument represents the scale factor in the horizontal direction
       * @param y The y argument represents the scale factor in the vertical direction.
       * @see https://html.spec.whatwg.org/multipage/canvas.html#dom-context-2d-scale
       */
      Context.prototype.scale = function (x, y) {
        if (y === undefined) {
          y = x;
        }
        // If either of the arguments are infinite or NaN, then return.
        if (isNaN(x) || isNaN(y) || !isFinite(x) || !isFinite(y)) {
          return;
        }
        let matrix = this.getTransform().scale(x, y);
        this.setTransform(matrix);
      };

      /**
       * Rotate adds a rotation to the transformation matrix.
       *
       * @param angle The rotation angle, clockwise in radians. You can use degree * Math.PI / 180 to calculate a radian from a degree.
       * @see https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/rotate
       * @see https://www.w3.org/TR/css-transforms-1
       */
      Context.prototype.rotate = function (angle) {
        let matrix = this.getTransform().multiply(
          new DOMMatrix([
            Math.cos(angle),
            Math.sin(angle),
            -Math.sin(angle),
            Math.cos(angle),
            0,
            0,
          ])
        );
        this.setTransform(matrix);
      };

      /**
       * Translate adds a translation transformation to the current matrix.
       *
       * @param x Distance to move in the horizontal direction. Positive values are to the right, and negative to the left.
       * @param y Distance to move in the vertical direction. Positive values are down, and negative are up.
       * @see https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/translate
       */
      Context.prototype.translate = function (x, y) {
        const matrix = this.getTransform().translate(x, y);
        this.setTransform(matrix);
      };

      /**
       * Transform multiplies the current transformation with the matrix described by the arguments of this method.
       * This lets you scale, rotate, translate (move), and skew the context.
       *
       * @see https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/transform
       */
      Context.prototype.transform = function (a, b, c, d, e, f) {
        const matrix = this.getTransform().multiply(
          new DOMMatrix([a, b, c, d, e, f])
        );
        this.setTransform(matrix);
      };

      Context.prototype.__matrixTransform = function (x, y) {
        return new DOMPoint(x, y).matrixTransform(this.__transformMatrix);
      };

      /**
       *
       * @returns The scale component of the transform matrix as {x,y}.
       */
      Context.prototype.__getTransformScale = function () {
        return {
          x: Math.hypot(this.__transformMatrix.a, this.__transformMatrix.b),
          y: Math.hypot(this.__transformMatrix.c, this.__transformMatrix.d),
        };
      };

      /**
       *
       * @returns The rotation component of the transform matrix in radians.
       */
      Context.prototype.__getTransformRotation = function () {
        return Math.atan2(this.__transformMatrix.b, this.__transformMatrix.a);
      };

      /**
       *
       * @param {*} sx The x-axis coordinate of the top-left corner of the rectangle from which the ImageData will be extracted.
       * @param {*} sy The y-axis coordinate of the top-left corner of the rectangle from which the ImageData will be extracted.
       * @param {*} sw The width of the rectangle from which the ImageData will be extracted. Positive values are to the right, and negative to the left.
       * @param {*} sh The height of the rectangle from which the ImageData will be extracted. Positive values are down, and negative are up.
       * @param {Boolean} options.async Will return a Promise<ImageData> if true, must be set to true
       * @returns An ImageData object containing the image data for the rectangle of the canvas specified. The coordinates of the rectangle's top-left corner are (sx, sy), while the coordinates of the bottom corner are (sx + sw, sy + sh).
       */
      Context.prototype.getImageData = function (sx, sy, sw, sh, options) {
        return utils.getImageData(
          this.getSvg(),
          this.width,
          this.height,
          sx,
          sy,
          sw,
          sh,
          options
        );
      };

      /**
       * Not yet implemented
       */
      Context.prototype.drawFocusRing = function () { };
      Context.prototype.createImageData = function () { };
      Context.prototype.putImageData = function () { };
      Context.prototype.globalCompositeOperation = function () { };

      return Context;
    })();

    function SVGCanvasElement(options) {

        this.ctx = new Context(options);
        this.svg = this.ctx.__root;

        // sync attributes to svg
        var svg = this.svg;
        var _this = this;

        var wrapper = document.createElement('div');
        wrapper.style.display = 'inline-block';
        wrapper.appendChild(svg);
        this.wrapper = wrapper;

        Object.defineProperty(this, 'className', {
            get: function() {
                return wrapper.getAttribute('class') || '';
            },
            set: function(val) {
                return wrapper.setAttribute('class', val);
            }
        });

        Object.defineProperty(this, 'tagName', {
            get: function() {
                return "CANVAS";
            },
            set: function() {} // no-op
        });

        ["width", "height"].forEach(function(prop) {
            Object.defineProperty(_this, prop, {
                get: function() {
                    return svg.getAttribute(prop) | 0;
                },
                set: function(val) {
                    if (isNaN(val) || (typeof val === "undefined")) {
                        return;
                    }
                    _this.ctx[prop] = val;
                    svg.setAttribute(prop, val);
                    return wrapper[prop] = val;
                }
            });
        });

        ["style", "id"].forEach(function(prop) {
            Object.defineProperty(_this, prop, {
                get: function() {
                    return wrapper[prop];
                },
                set: function(val) {
                    if (typeof val !== "undefined") {
                        return wrapper[prop] = val;
                    }
                }
            });
        });

        ["getBoundingClientRect"].forEach(function(fn) {
            _this[fn] = function() {
                return svg[fn]();
            };
        });
    }

    SVGCanvasElement.prototype.getContext = function(type) {
        if (type !== '2d') {
            throw new Error('Unsupported type of context for SVGCanvas');
        }

        return this.ctx;
    };

    // you should always use URL.revokeObjectURL after your work done
    SVGCanvasElement.prototype.toObjectURL = function() {
        var data = new XMLSerializer().serializeToString(this.svg);
        var svg = new Blob([data], {type: 'image/svg+xml;charset=utf-8'});
        return URL.createObjectURL(svg);
    };

    /**
     * toDataURL returns a data URI containing a representation of the image in the format specified by the type parameter.
     * 
     * @param {String} type A DOMString indicating the image format. The default type is image/svg+xml; this image format will be also used if the specified type is not supported.
     * @param {Number} encoderOptions A Number between 0 and 1 indicating the image quality to be used when creating images using file formats that support lossy compression (such as image/jpeg or image/webp). A user agent will use its default quality value if this option is not specified, or if the number is outside the allowed range.
     * @param {Boolean} options.async Will return a Promise<String> if true, must be set to true if type is not image/svg+xml
     */
    SVGCanvasElement.prototype.toDataURL = function(type, encoderOptions, options) {
        return utils.toDataURL(this.svg, this.width, this.height, type, encoderOptions, options)
    };

    SVGCanvasElement.prototype.addEventListener = function() {
        return this.svg.addEventListener.apply(this.svg, arguments);
    };

    // will return wrapper element: <div><svg></svg></div>
    SVGCanvasElement.prototype.getElement = function() {
        return this.wrapper;
    };

    SVGCanvasElement.prototype.getAttribute = function(prop) {
        return this.wrapper.getAttribute(prop);
    };

    SVGCanvasElement.prototype.setAttribute = function(prop, val) {
        this.wrapper.setAttribute(prop, val);
    };

    function arc(ctx) {

        // Draw shapes
        for (let i = 0; i < 4; i++) {
            for (let j = 0; j < 3; j++) {
                ctx.beginPath();
                var x = 25 + j * 50;               // x coordinate
                var y = 25 + i * 50;               // y coordinate
                var radius = 20;                    // Arc radius
                var startAngle = 0;                     // Starting point on circle
                var endAngle = Math.PI + (Math.PI * j) / 2; // End point on circle
                var clockwise = i % 2 == 0 ? false : true; // clockwise or anticlockwise

                ctx.arc(x, y, radius, startAngle, endAngle, clockwise);

                if (i > 1) {
                    ctx.fill();
                } else {
                    ctx.stroke();
                }
            }
        }
        
    }

    function arcTo$1(ctx) {
        ctx.beginPath();
        ctx.moveTo(150, 20);
        ctx.arcTo(150, 100, 250, 20, 20);
        ctx.stroke();

        ctx.beginPath();
        ctx.arc(450, 100, 20, 180/180*Math.PI, 45/180*Math.PI, true);
        ctx.stroke();

        ctx.fillStyle = 'blue';
        // base point
        ctx.fillRect(150, 20, 2, 2);

        ctx.fillStyle = 'red';
        // control point one
        ctx.fillRect(150, 100, 2, 2);
        // control point two
        ctx.fillRect(250, 20, 2, 2);

        ctx.beginPath();
        ctx.moveTo(150, 200);
        ctx.arcTo(250, 200, 250, 250, 20);
        ctx.stroke();

        ctx.beginPath();
        ctx.moveTo(150, 400);
        ctx.arcTo(50, 400, 20, 450, 20);
        ctx.stroke();
    }

    function arcTo(ctx) {
        ctx.beginPath();
        ctx.moveTo(100, 225);             // P0
        ctx.arcTo(300, 25, 500, 225, 75); // P1, P2 and the radius
        ctx.lineTo(500, 225);             // P2
        ctx.stroke();


        const path = [[50, 50], [50, 150], [100, 150], [100, 150], [200, 150], [200, 50], [300, 50],  [300, 150]];
        ctx.beginPath();
        let fromPoint = path[0];
        ctx.moveTo(fromPoint[0], fromPoint[1]);            
        for (let i = 1; i < path.length; i++) {
            const point = path[i];
            ctx.arcTo(fromPoint[0], fromPoint[1], point[0], point[1], 20); // P1, P2 and the radius
            fromPoint = point;
        }
        ctx.lineTo(300, 100);
        ctx.stroke();
    }

    function arcToScaled(ctx) {
      ctx.scale(2, 0.5);
      ctx.beginPath();
      ctx.moveTo(100, 50);
      ctx.arcTo(150, 50, 150, 100, 50);
      ctx.arcTo(150, 150, 100, 150, 50);
      ctx.arcTo(50, 150, 50, 100, 50);
      ctx.arcTo(50, 50, 100, 50, 50);

      // Reset the scale before we stroke since SVG stroke is not scaled.
      ctx.setTransform(1, 0, 0, 1, 0, 0);
      ctx.stroke();
    }

    function emptyArc(ctx) {

        // Draw shapes
        for (let i = 0; i < 4; i++) {
            for (let j = 0; j < 3; j++) {
                ctx.beginPath();
                ctx.arc(100, 100, 100, Math.PI, Math.PI);
                ctx.fill();
            }
        }
        
    }

    function ellipse(ctx) {
        // Draw shapes
        for (let i = 0; i < 4; i++) {
            for (let j = 0; j < 3; j++) {
                ctx.beginPath();
                var x = 25 + j * 50;               // x coordinate
                var y = 25 + i * 50;               // y coordinate
                var radiusX = 20;                  // Arc radius
                var radiusY = 10;                  // Arc radius
                var rotation = Math.PI + (Math.PI * (i+j)) / 8;
                var startAngle = 0;                     // Starting point on circle
                var endAngle = Math.PI + (Math.PI * j) / 2; // End point on circle
                var clockwise = i % 2 == 0 ? false : true; // clockwise or anticlockwise

                ctx.ellipse(x, y, radiusX, radiusY, rotation, startAngle, endAngle, clockwise);

                if (i > 1) {
                    ctx.fill();
                } else {
                    ctx.stroke();
                }
            }
        }
      
    }

    function ellipse2(ctx) {
        // Draw a cylinder using ellipses and lines.
        var w = 100, h = 100, rx = 50, ry = 10;
        var scaleX = 1.5, scaleY = 1.2;

        ctx.rotate(Math.PI / 10);
        ctx.scale(scaleX, scaleY);
        ctx.translate(200, 25);

        ctx.beginPath();
        ctx.moveTo(-100 / 2, -100 / 2 + ry);
        // upper arc top
        ctx.ellipse(0, -100 / 2 + ry, rx, ry, Math.PI, 0, Math.PI, 0);
        ctx.moveTo(-100 / 2, -100 / 2 + ry);
        // upper arc bottom
        ctx.ellipse(0, -100 / 2 + ry, rx, ry, Math.PI, 0, Math.PI, 1);
        ctx.moveTo(-100 / 2, -100 / 2 + ry);
        // left line
        ctx.lineTo(-100 / 2, 100 / 2 - ry);
        // lower arc
        ctx.ellipse(0, h / 2 - ry, rx, ry, Math.PI, 0, Math.PI, 1);
        // right line
        ctx.lineTo(w / 2, -100 / 2 + ry);
        ctx.moveTo(-100 / 2, -100 / 2 + ry);
        ctx.closePath();

        // Remove scale before stroking because the SVG conversion is not correctly
        // scaling the stroke as well. Without this the pixel differences are too
        // high.
        ctx.resetTransform();
        ctx.stroke();
    }

    function fillStyle(ctx) {
        for (var i = 0; i < 6; i++) {
            for (var j = 0; j < 6; j++) {
                ctx.fillStyle = 'rgb(' + Math.floor(255 - 42.5 * i) + ',' +
                    Math.floor(255 - 42.5 * j) + ',0)';
                ctx.fillRect(j * 25, i * 25, 25, 25);
            }
        }
    }

    function globalAlpha(ctx) {
        ctx.fillStyle = '#FD0';
        ctx.fillRect(0,0,75,75);
        ctx.fillStyle = '#6C0';
        ctx.fillRect(75,0,75,75);
        ctx.fillStyle = '#09F';
        ctx.fillRect(0,75,75,75);
        ctx.fillStyle = '#F30';
        ctx.fillRect(75,75,75,75);
        ctx.fillStyle = '#FFF';

        // set transparency value
        ctx.globalAlpha = 0.2;

        // Draw semi transparent circles
        for (let i=0;i<7;i++){
            ctx.beginPath();
            ctx.arc(75,75,10+10*i,0,Math.PI*2,true);
            ctx.fill();
        }

        ctx.globalAlpha = 1.0;
    }

    function gradient(ctx) {
        ctx.save();
        ctx.strokeStyle='rgba(0,0,0,0)';
        ctx.lineCap='butt';
        ctx.lineJoin='miter';
        ctx.miterLimit=10.0;
        ctx.font='10px sans-serif';
        ctx.save();
        var radialGradient_1389130830351 = ctx.createRadialGradient(6E1,6E1,0.0,6E1,6E1,5E1);
        radialGradient_1389130830351.addColorStop(0E0,'red');
        radialGradient_1389130830351.addColorStop(1E0,'blue');
        ctx.fillStyle=radialGradient_1389130830351;
        ctx.font='10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.5E1,1E1);
        ctx.lineTo(9.5E1,1E1);
        ctx.quadraticCurveTo(1.1E2,1E1,1.1E2,2.5E1);
        ctx.lineTo(1.1E2,9.5E1);
        ctx.quadraticCurveTo(1.1E2,1.1E2,9.5E1,1.1E2);
        ctx.lineTo(2.5E1,1.1E2);
        ctx.quadraticCurveTo(1E1,1.1E2,1E1,9.5E1);
        ctx.lineTo(1E1,2.5E1);
        ctx.quadraticCurveTo(1E1,1E1,2.5E1,1E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.save();
        var radialGradient_1389130830351 = ctx.createRadialGradient(3.5E1,1.45E2,0.0,3.5E1,1.45E2,2.5E1);
        radialGradient_1389130830351.addColorStop(0E0,'red');
        radialGradient_1389130830351.addColorStop(1E0,'blue');
        ctx.fillStyle=radialGradient_1389130830351;
        ctx.font='10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.5E1,1.2E2);
        ctx.lineTo(9.5E1,1.2E2);
        ctx.quadraticCurveTo(1.1E2,1.2E2,1.1E2,1.35E2);
        ctx.lineTo(1.1E2,2.05E2);
        ctx.quadraticCurveTo(1.1E2,2.2E2,9.5E1,2.2E2);
        ctx.lineTo(2.5E1,2.2E2);
        ctx.quadraticCurveTo(1E1,2.2E2,1E1,2.05E2);
        ctx.lineTo(1E1,1.35E2);
        ctx.quadraticCurveTo(1E1,1.2E2,2.5E1,1.2E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
    }

    function image(ctx) {
      // Create an image based on a URL
      var img = new Image();
      img.src =
        "https://dl.dropboxusercontent.com/s/m76annmw0nzz5fx/Unknown.jpg?dl=1";
      img.crossOrigin = "anonymous";
      img.onload = function () {
        ctx.drawImage(img, 20, 20, 30, 30);
      };

      // Create an image based on a foreignObject block.
      var img2 = new Image();
      img2.src =
        "data:image/svg+xml;charset=utf-8,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%22164%22%20height%3D%2260%22%20data-reactroot%3D%22%22%3E%3Cstyle%3E%0A%20%20%20%20%20%20%3Aroot%20%7B%0A%20%20%20%20%20%20%20%20--theme-link-text%3A%20rgb(0%2C%20115%2C%20207)%3B%0A%20%20%20%20%20%20%20%20--theme-primary-border%3A%20rgb(205%2C%20205%2C%20205)%3B%0A%20%20%20%20%20%20%20%20--theme-light-border%3A%20rgb(241%2C%20241%2C%20241)%3B%0A%20%20%20%20%20%20%20%20--aha-yellow-400%3A%20rgb(255%2C%20228%2C%20142)%3B%0A%20%20%20%20%20%20%20%20--aha-gray-700%3A%20rgb(150%2C%20153%2C%20153)%3B%0A%20%20%20%20%20%20%0A%20%20%20%20%20%20%20%20--aha-orange-600%3A%20rgb(249%2C%20147%2C%2025)%3B%0A%20%20%20%20%20%20%20%20--aha-orange-800%3A%20rgb(199%2C%20109%2C%200)%3B%0A%20%20%20%20%20%20%20%20--aha-red-600%3A%20rgb(235%2C%20121%2C%2087)%3B%0A%20%20%20%20%20%20%20%20--aha-blue-500%3A%20rgb(0%2C%20115%2C%20207)%3B%0A%20%20%20%20%20%20%20%20--theme-green-text%3A%20rgb(79%2C%20143%2C%2014)%3B%0A%20%20%20%20%20%20%7D%0A%20%20%20%20%20%20%3C!--%20--%3E._editorContainer_19k9u_1%20%7B%0A%20%20display%3A%20block%3B%0A%7D%0A%0A._editor_19k9u_1%20%7B%0A%20%20display%3A%20flex%3B%0A%20%20flex-direction%3A%20column%3B%0A%20%20width%3A%20min-content%3B%0A%20%20overflow%3A%20hidden%3B%0A%20%20white-space%3A%20pre-wrap%3B%0A%20%20overflow-wrap%3A%20break-word%3B%0A%0A%20%20%2F*%20Default%20font%20*%2F%0A%20%20font-family%3A%20sans-serif%3B%0A%20%20font-size%3A%2014px%3B%0A%20%20line-height%3A%201.4%3B%0A%7D%0A._editor_19k9u_1._autoGrow_19k9u_18%2C%0A._editor_19k9u_1._autoGrow_19k9u_18%20.aha-editor-body%20%7B%0A%20%20white-space%3A%20pre%20!important%3B%0A%7D%0A._editor_19k9u_1._editing_19k9u_22%20%7B%0A%20%20overflow%3A%20visible%3B%0A%7D%0A%0A._editor_19k9u_1%20._content_19k9u_26%20%7B%0A%20%20margin%3A%20auto%3B%0A%20%20width%3A%20100%25%3B%0A%7D%0A%0A._editor_19k9u_1%20.aha-editor__pre-container%20%7B%0A%20%20position%3A%20relative%3B%0A%7D%0A%0A._editor_19k9u_1%20.aha-editor-context-toolbar-btn%20%7B%0A%20%20position%3A%20absolute%3B%0A%20%20right%3A%20-5px%3B%0A%20%20top%3A%203px%3B%0A%20%20z-index%3A%209999%3B%0A%20%20height%3A%2016px%3B%0A%7D%0A%0A._editor_19k9u_1%0A%20%20.aha-editor-context-toolbar-btn%3Ahover%0A%20%20.aha-editor-toolbar-btn%20%7B%0A%20%20background-color%3A%20var(--theme-editor-button-hovered)%20!important%3B%0A%20%20color%3A%20var(--aha-gray-900)%20!important%3B%0A%20%20cursor%3A%20pointer%3B%0A%7D%0A%0A._editor_19k9u_1%20.aha-editor-context-toolbar-btn%20button%20%7B%0A%20%20border%3A%20none%3B%0A%20%20border-radius%3A%204px%3B%0A%20%20padding%3A%200%3B%0A%20%20background-color%3A%20var(--theme-tertiary-background)%3B%0A%7D%0A%0A._editor_19k9u_1%20.aha-editor-context-toolbar-btn%20i%20%7B%0A%20%20margin-right%3A%205px%3B%0A%7D%0A%0A%2F*%0A%20*%20Text%20styles.%0A%20*%2F%0A._editor_19k9u_1%20p%2C%0A._editor_19k9u_1%20pre%20%7B%0A%20%20margin%3A%200%3B%0A%7D%0A%0A._editor_19k9u_1%20.align-left%20%7B%0A%20%20text-align%3A%20left%3B%0A%7D%0A%0A._editor_19k9u_1%20.align-center%20%7B%0A%20%20text-align%3A%20center%3B%0A%7D%0A%0A._editor_19k9u_1%20.align-right%20%7B%0A%20%20text-align%3A%20right%3B%0A%7D%0A%0A._editor_19k9u_1%20.align-justify%20%7B%0A%20%20text-align%3A%20justify%3B%0A%7D%0A%0A._editor_19k9u_1%20.inline-highlight%20%7B%0A%20%20background-color%3A%20var(--aha-yellow-400)%3B%0A%7D%0A%0A._editor_19k9u_1%20a%20%7B%0A%20%20word-wrap%3A%20break-word%3B%0A%7D%0A%0A._editor_19k9u_1%20code%20%7B%0A%20%20font-size%3A%20inherit%3B%0A%7D%0A%0A._editor_19k9u_1%20ul%2C%0A._editor_19k9u_1%20ol%20%7B%0A%20%20padding%3A%200%3B%0A%20%20list-style-position%3A%20inside%3B%0A%7D%0A._editor_19k9u_1%20ul%20%7B%0A%20%20margin%3A%200%200%200%201em%3B%0A%7D%0A._editor_19k9u_1%20ol%20%7B%0A%20%20margin%3A%200%200%200%202em%3B%20%2F*%20More%20space%20for%202%20digit%20numbers%20*%2F%0A%7D%0A._editor_19k9u_1%20ul%20p%2C%0A._editor_19k9u_1%20ol%20p%20%7B%0A%20%20text-align%3A%20left%20!important%3B%0A%7D%0A%0A._editor_19k9u_1%20ul%20%7B%0A%20%20list-style-type%3A%20disc%3B%0A%7D%0A%0A._editor_19k9u_1%20ul.checklist%20%7B%0A%20%20list-style-type%3A%20none%3B%0A%7D%0A%0A._editor_19k9u_1%20li.checklist-item--checked%2C%0A._editor_19k9u_1%20li.checklist-item--unchecked%20%7B%0A%20%20list-style-type%3A%20none%3B%0A%7D%0A%0A._editor_19k9u_1%20li%20%7B%0A%20%20box-sizing%3A%20border-box%3B%0A%20%20line-height%3A%201.4%3B%20%2F*%20Must%20be%20same%20as%20%26lt%3Bp%26gt%3B%20line-height.%20*%2F%0A%20%20list-style-position%3A%20outside%3B%0A%20%20font-style%3A%20normal%3B%0A%20%20font-weight%3A%20normal%3B%0A%20%20padding%3A%200%3B%0A%20%20margin%3A%200%3B%0A%7D%0A%0A._editor_19k9u_1%20li.checkbox%20%7B%0A%20%20padding-left%3A%200%3B%0A%20%20min-height%3A%20auto%3B%0A%7D%0A%0A._editor_19k9u_1%20li.checkbox%20input%5Btype%3D%26%23x27%3Bcheckbox%26%23x27%3B%5D%20%7B%0A%20%20margin%3A%203px%200%200%20-18px%3B%0A%20%20position%3A%20absolute%3B%0A%20%20margin-top%3A%200%3B%0A%20%20margin-left%3A%20-15px%3B%0A%7D%0A%0A._editor_19k9u_1%20li%20.checklist-item__indicator%20%7B%0A%20%20margin%3A%200%3B%0A%20%20position%3A%20absolute%3B%0A%20%20margin-left%3A%20-1.5ch%3B%0A%7D%0A%0A._editor_19k9u_1%20code%20%7B%0A%20%20white-space%3A%20inherit%3B%0A%7D%0A%0A._editor_19k9u_1%20table%20%7B%0A%20%20width%3A%20100%25%3B%0A%20%20word-wrap%3A%20break-word%3B%0A%20%20table-layout%3A%20fixed%3B%0A%7D%0A%0A._editor_19k9u_1%20td%20%7B%0A%20%20position%3A%20relative%3B%0A%20%20border%3A%201px%20solid%20var(--theme-primary-border)%3B%0A%20%20padding%3A%208px%3B%0A%20%20vertical-align%3A%20top%3B%0A%7D%0A%0A._editor_19k9u_1%20blockquote%20%7B%0A%20%20padding%3A%203px%200%203px%2010px%3B%0A%20%20border-left%3A%204px%20solid%20var(--theme-light-border)%3B%0A%7D%0A%0A._editor_19k9u_1%20a%20%7B%0A%20%20color%3A%20var(--theme-link-text)%3B%0A%20%20text-decoration%3A%20underline%3B%0A%7D%0A%0A._editor_19k9u_1%20code%20%7B%0A%20%20padding%3A%202px%204px%3B%0A%20%20color%3A%20%23d14%3B%0A%20%20background-color%3A%20%23f7f7f9%3B%0A%20%20border%3A%201px%20solid%20%23e1e1e8%3B%0A%20%20border-radius%3A%203px%3B%0A%7D%0A%0A._editor_19k9u_1%20pre%20%7B%0A%20%20padding%3A%202px%204px%3B%0A%20%20margin%3A%200%3B%0A%20%20display%3A%20block%3B%0A%20%20background-color%3A%20%23f7f7f9%3B%0A%20%20border%3A%201px%20solid%20%23e1e1e8%3B%0A%20%20border-radius%3A%203px%3B%0A%20%20word-break%3A%20break-all%3B%0A%20%20white-space%3A%20break-spaces%3B%0A%7D%0A._editor_19k9u_1%20pre%20code%20%7B%0A%20%20padding%3A%200%3B%0A%20%20color%3A%20inherit%3B%0A%20%20background-color%3A%20transparent%3B%0A%20%20border%3A%200%3B%0A%7D%0A%0A%2F*%20prism.js%20styles%20*%2F%0A._editor_19k9u_1%20.token.comment%2C%0A._editor_19k9u_1%20.token.prolog%2C%0A._editor_19k9u_1%20.token.doctype%2C%0A._editor_19k9u_1%20.token.cdata%20%7B%0A%20%20color%3A%20slategray%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.punctuation%20%7B%0A%20%20color%3A%20%23999%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.namespace%20%7B%0A%20%20opacity%3A%200.7%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.property%2C%0A._editor_19k9u_1%20.token.tag%2C%0A._editor_19k9u_1%20token.boolean%2C%0A._editor_19k9u_1%20.token.number%2C%0A._editor_19k9u_1%20.token.constant%2C%0A._editor_19k9u_1%20.token.symbol%2C%0A._editor_19k9u_1%20.token.deleted%20%7B%0A%20%20color%3A%20%23905%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.selector%2C%0A._editor_19k9u_1%20.token.attr-name%2C%0A._editor_19k9u_1%20.token.string%2C%0A._editor_19k9u_1%20.token.char%2C%0A._editor_19k9u_1%20.token.builtin%2C%0A._editor_19k9u_1%20.token.inserted%20%7B%0A%20%20color%3A%20var(--theme-green-text)%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.operator%2C%0A._editor_19k9u_1%20.token.entity%2C%0A._editor_19k9u_1%20.token.url%2C%0A._editor_19k9u_1%20.language-css%20.token.string%2C%0A._editor_19k9u_1%20.style%20.token.string%20%7B%0A%20%20color%3A%20var(--aha-orange-800)%3B%0A%20%20%2F*%20This%20background%20color%20was%20intended%20by%20the%20author%20of%20this%20theme.%20*%2F%0A%20%20background%3A%20hsla(0%2C%200%25%2C%20100%25%2C%200.5)%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.atrule%2C%0A._editor_19k9u_1%20.token.attr-value%2C%0A._editor_19k9u_1%20.token.keyword%20%7B%0A%20%20color%3A%20var(--aha-blue-500)%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.function%2C%0A._editor_19k9u_1%20.token.class-name%20%7B%0A%20%20color%3A%20var(--aha-red-600)%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.regex%2C%0A._editor_19k9u_1%20.token.important%2C%0A._editor_19k9u_1%20.token.variable%20%7B%0A%20%20color%3A%20var(--aha-orange-600)%3B%0A%7D%0A%0A._editor_19k9u_1%20.token.important%2C%0A._editor_19k9u_1%20.token.bold%20%7B%0A%20%20font-weight%3A%20bold%3B%0A%7D%0A._editor_19k9u_1%20.token.italic%20%7B%0A%20%20font-style%3A%20italic%3B%0A%7D%0A%0A._editor_19k9u_1%20.frameText%20%7B%0A%20%20color%3A%20var(--aha-gray-700)%3B%0A%7D%0A%3C%2Fstyle%3E%3CforeignObject%20width%3D%22100%25%22%20height%3D%22100%25%22%3E%3Cdiv%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxhtml%22%20style%3D%22min-height%3A30px%3Bwidth%3A82px%3Bfont-size%3A14px%3Bbox-sizing%3Aborder-box%3Bpadding%3A5px%205px%205px%205px%3Btransform-origin%3Atop%20left%3Btransform%3Ascale(2)%22%20class%3D%22_editor_19k9u_1%20_autoGrow_19k9u_18%22%3E%3Cdiv%20class%3D%22_content_19k9u_26%22%3E%3Cp%20style%3D%22text-align%3Acenter%22%3EHello%20World%3C%2Fp%3E%3C%2Fdiv%3E%3C%2Fdiv%3E%3C%2FforeignObject%3E%3C%2Fsvg%3E";
      img2.onload = function () {
        ctx.drawImage(img2, 20, 100, 60, 30);
      };
    }

    function linecap(ctx) {
        var lineCap = ['butt','round','square'];

        // Draw guides
        ctx.strokeStyle = '#09f';
        ctx.beginPath();
        ctx.moveTo(10,10);
        ctx.lineTo(140,10);
        ctx.moveTo(10,140);
        ctx.lineTo(140,140);
        ctx.stroke();

        // Draw lines
        ctx.strokeStyle = 'black';
        for (let i=0;i<lineCap.length;i++){
            ctx.lineWidth = 15;
            ctx.lineCap = lineCap[i];
            ctx.beginPath();
            ctx.moveTo(25+i*50,10);
            ctx.lineTo(25+i*50,140);
            ctx.stroke();
        }
    }

    function linewidth(ctx) {
        for (var i = 0; i < 10; i++){
            ctx.lineWidth = 1+i;
            ctx.beginPath();
            ctx.moveTo(5+i*14,5);
            ctx.lineTo(5+i*14,140);
            ctx.stroke();
        }
    }

    function scaledLine(ctx) {
      ctx.scale(1.5, 1.5);
      for (var i = 0; i < 10; i++){
          ctx.lineWidth = 1+i;
          ctx.beginPath();
          ctx.moveTo(5+i*14,5);
          ctx.lineTo(5+i*14,140);
          ctx.stroke();
      }
    }

    function rgba(ctx) {
        // Draw background
        ctx.fillStyle = 'rgb(255,221,0)';
        ctx.fillRect(0,0,150,37.5);
        ctx.fillStyle = 'rgb(102,204,0)';
        ctx.fillRect(0,37.5,150,37.5);
        ctx.fillStyle = 'rgb(0,153,255)';
        ctx.fillRect(0,75,150,37.5);
        ctx.fillStyle = 'rgb(255,51,0)';
        ctx.fillRect(0,112.5,150,37.5);

        // Draw semi transparent rectangles
        for (var i=0;i<10;i++){
            ctx.fillStyle = 'rgba(255,255,255,'+(i+1)/10+')';
            for (var j=0;j<4;j++){
                ctx.fillRect(5+i*14,5+j*37.5,14,27.5);
            }
        }
    }

    // Example from https://developer.mozilla.org/en-US/docs/Web/API/CanvasRenderingContext2D/rotate
    function rotate(ctx) {
        ctx.fillStyle = 'gray';
        ctx.fillRect(80, 60, 140, 30);

        // Matrix transformation
        ctx.translate(150, 75);
        ctx.rotate(Math.PI / 2);
        ctx.translate(-150, -75);

        // Rotated rectangle
        ctx.fillStyle = 'red';
        ctx.fillRect(80, 60, 140, 30);

        ctx.resetTransform();
    }

    function saveAndRestore(ctx) {
        ctx.fillRect(0, 0, 150, 150);   // Draw a rectangle with default settings
        ctx.save();                  // Save the default state

        ctx.fillStyle = '#09F';      // Make changes to the settings
        ctx.fillRect(15, 15, 120, 120); // Draw a rectangle with new settings

        ctx.save();                  // Save the current state
        ctx.fillStyle = '#FFF';      // Make changes to the settings
        ctx.globalAlpha = 0.5;
        ctx.fillRect(30, 30, 90, 90);   // Draw a rectangle with new settings

        ctx.restore();               // Restore previous state
        ctx.fillRect(45, 45, 60, 60);   // Draw a rectangle with restored settings

        ctx.restore();               // Restore original state
        ctx.fillRect(60, 60, 30, 30);   // Draw a rectangle with restored settings
    }

    function setLineDash(ctx) {
        ctx.save();
        ctx.lineWidth = 4;
        for (var i = 0; i < 10; i++){
            ctx.setLineDash([(i+1)*5,10]);
            ctx.beginPath();
            ctx.moveTo(5+i*14,5);
            ctx.lineTo(5+i*14,140);
            ctx.stroke();
        }
        ctx.restore();
    }

    function text(ctx) {
        ctx.font = "normal 120px Arial";
        ctx.fillStyle = "#000000";
        ctx.fillText("Hello", 0, 200);
    }

    function tiger(ctx) {
        ctx.save();
        ctx.strokeStyle = 'rgba(0,0,0,0)';
        ctx.lineCap = 'butt';
        ctx.lineJoin = 'miter';
        ctx.miterLimit = 10.0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.font = '10px sans-serif';
        ctx.translate(2E2, 2E2);
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-122.304), 8.4285E1);
        ctx.bezierCurveTo((-122.304), 8.4285E1, (-122.203), 8.6179E1, (-123.027), 8.616E1);
        ctx.bezierCurveTo((-123.851), 8.6141E1, (-140.305), 3.8066E1, (-160.833), 4.0309E1);
        ctx.bezierCurveTo((-160.833), 4.0309E1, (-143.05), 3.2956E1, (-122.304), 8.4285E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-118.774), 8.1262E1);
        ctx.bezierCurveTo((-118.774), 8.1262E1, (-119.323), 8.3078E1, (-120.092), 8.2779E1);
        ctx.bezierCurveTo((-120.86), 8.2481E1, (-119.977), 3.1675E1, (-140.043), 2.6801E1);
        ctx.bezierCurveTo((-140.043), 2.6801E1, (-120.82), 2.5937E1, (-118.774), 8.1262E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-91.284), 1.2359E2);
        ctx.bezierCurveTo((-91.284), 1.2359E2, (-89.648), 1.2455E2, (-90.118), 1.25227E2);
        ctx.bezierCurveTo((-90.589), 1.25904E2, (-139.763), 1.13102E2, (-149.218), 1.31459E2);
        ctx.bezierCurveTo((-149.218), 1.31459E2, (-145.539), 1.12572E2, (-91.284), 1.2359E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-94.093), 1.33801E2);
        ctx.bezierCurveTo((-94.093), 1.33801E2, (-92.237), 1.34197E2, (-92.471), 1.34988E2);
        ctx.bezierCurveTo((-92.704), 1.35779E2, (-143.407), 1.39121E2, (-146.597), 1.59522E2);
        ctx.bezierCurveTo((-146.597), 1.59522E2, (-149.055), 1.40437E2, (-94.093), 1.33801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-98.304), 1.28276E2);
        ctx.bezierCurveTo((-98.304), 1.28276E2, (-96.526), 1.28939E2, (-96.872), 1.29687E2);
        ctx.bezierCurveTo((-97.218), 1.30435E2, (-147.866), 1.26346E2, (-153.998), 1.46064E2);
        ctx.bezierCurveTo((-153.998), 1.46064E2, (-153.646), 1.26825E2, (-98.304), 1.28276E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-109.009), 1.10072E2);
        ctx.bezierCurveTo((-109.009), 1.10072E2, (-107.701), 1.11446E2, (-108.34), 1.11967E2);
        ctx.bezierCurveTo((-108.979), 1.12488E2, (-152.722), 8.6634E1, (-166.869), 1.01676E2);
        ctx.bezierCurveTo((-166.869), 1.01676E2, (-158.128), 8.4533E1, (-109.009), 1.10072E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-116.554), 1.14263E2);
        ctx.bezierCurveTo((-116.554), 1.14263E2, (-115.098), 1.1548E2, (-115.674), 1.16071E2);
        ctx.bezierCurveTo((-116.25), 1.16661E2, (-162.638), 9.5922E1, (-174.992), 1.12469E2);
        ctx.bezierCurveTo((-174.992), 1.12469E2, (-168.247), 9.4447E1, (-116.554), 1.14263E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-119.154), 1.18335E2);
        ctx.bezierCurveTo((-119.154), 1.18335E2, (-117.546), 1.19343E2, (-118.036), 1.20006E2);
        ctx.bezierCurveTo((-118.526), 1.20669E2, (-167.308), 1.06446E2, (-177.291), 1.24522E2);
        ctx.bezierCurveTo((-177.291), 1.24522E2, (-173.066), 1.05749E2, (-119.154), 1.18335E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-108.42), 1.18949E2);
        ctx.bezierCurveTo((-108.42), 1.18949E2, (-107.298), 1.2048E2, (-107.999), 1.20915E2);
        ctx.bezierCurveTo((-108.7), 1.2135E2, (-148.769), 9.0102E1, (-164.727), 1.03207E2);
        ctx.bezierCurveTo((-164.727), 1.03207E2, (-153.862), 8.7326E1, (-108.42), 1.18949E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-128.2), 9E1);
        ctx.bezierCurveTo((-128.2), 9E1, (-127.6), 9.18E1, (-128.4), 9.2E1);
        ctx.bezierCurveTo((-129.2), 9.22E1, (-157.8), 5.02E1, (-177.001), 5.78E1);
        ctx.bezierCurveTo((-177.001), 5.78E1, (-161.8), 4.6E1, (-128.2), 9E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-127.505), 9.6979E1);
        ctx.bezierCurveTo((-127.505), 9.6979E1, (-126.53), 9.8608E1, (-127.269), 9.8975E1);
        ctx.bezierCurveTo((-128.007), 9.9343E1, (-164.992), 6.4499E1, (-182.101), 7.6061E1);
        ctx.bezierCurveTo((-182.101), 7.6061E1, (-169.804), 6.1261E1, (-127.505), 9.6979E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1.72E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-127.62), 1.01349E2);
        ctx.bezierCurveTo((-127.62), 1.01349E2, (-126.498), 1.0288E2, (-127.199), 1.03315E2);
        ctx.bezierCurveTo((-127.9), 1.03749E2, (-167.969), 7.2502E1, (-183.927), 8.5607E1);
        ctx.bezierCurveTo((-183.927), 8.5607E1, (-173.062), 6.9726E1, (-127.62), 1.01349E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-129.83), 1.03065E2);
        ctx.bezierCurveTo((-129.327), 1.09113E2, (-128.339), 1.15682E2, (-126.6), 1.18801E2);
        ctx.bezierCurveTo((-126.6), 1.18801E2, (-130.2), 1.31201E2, (-121.4), 1.44401E2);
        ctx.bezierCurveTo((-121.4), 1.44401E2, (-121.8), 1.51601E2, (-120.2), 1.54801E2);
        ctx.bezierCurveTo((-120.2), 1.54801E2, (-116.2), 1.63201E2, (-111.4), 1.64001E2);
        ctx.bezierCurveTo((-107.516), 1.64648E2, (-98.793), 1.67717E2, (-88.932), 1.69121E2);
        ctx.bezierCurveTo((-88.932), 1.69121E2, (-71.8), 1.83201E2, (-75), 1.96001E2);
        ctx.bezierCurveTo((-75), 1.96001E2, (-75.4), 2.12401E2, (-79), 2.14001E2);
        ctx.bezierCurveTo((-79), 2.14001E2, (-67.4), 2.02801E2, (-77), 2.19601E2);
        ctx.lineTo((-81.4), 2.38401E2);
        ctx.bezierCurveTo((-81.4), 2.38401E2, (-55.8), 2.16801E2, (-71.4), 2.35201E2);
        ctx.lineTo((-81.4), 2.61201E2);
        ctx.bezierCurveTo((-81.4), 2.61201E2, (-61.8), 2.42801E2, (-69), 2.51201E2);
        ctx.lineTo((-72.2), 2.60001E2);
        ctx.bezierCurveTo((-72.2), 2.60001E2, (-29), 2.32801E2, (-59.8), 2.62401E2);
        ctx.bezierCurveTo((-59.8), 2.62401E2, (-51.8), 2.58801E2, (-47.4), 2.61601E2);
        ctx.bezierCurveTo((-47.4), 2.61601E2, (-40.6), 2.60401E2, (-41.4), 2.62001E2);
        ctx.bezierCurveTo((-41.4), 2.62001E2, (-62.2), 2.72401E2, (-65.8), 2.90801E2);
        ctx.bezierCurveTo((-65.8), 2.90801E2, (-57.4), 2.80801E2, (-60.6), 2.91601E2);
        ctx.lineTo((-60.2), 3.03201E2);
        ctx.bezierCurveTo((-60.2), 3.03201E2, (-56.2), 2.81601E2, (-56.6), 3.19201E2);
        ctx.bezierCurveTo((-56.6), 3.19201E2, (-37.4), 3.01201E2, (-49), 3.22001E2);
        ctx.lineTo((-49), 3.38801E2);
        ctx.bezierCurveTo((-49), 3.38801E2, (-33.8), 3.22401E2, (-40.2), 3.35201E2);
        ctx.bezierCurveTo((-40.2), 3.35201E2, (-30.2), 3.26401E2, (-34.2), 3.41601E2);
        ctx.bezierCurveTo((-34.2), 3.41601E2, (-35), 3.52001E2, (-30.6), 3.40801E2);
        ctx.bezierCurveTo((-30.6), 3.40801E2, (-14.6), 3.10201E2, (-20.6), 3.36401E2);
        ctx.bezierCurveTo((-20.6), 3.36401E2, (-21.4), 3.55601E2, (-16.6), 3.40801E2);
        ctx.bezierCurveTo((-16.6), 3.40801E2, (-16.2), 3.51201E2, (-7), 3.58401E2);
        ctx.bezierCurveTo((-7), 3.58401E2, (-8.2), 3.07601E2, 4.6E0, 3.43601E2);
        ctx.lineTo(8.6E0, 3.60001E2);
        ctx.bezierCurveTo(8.6E0, 3.60001E2, 1.14E1, 3.50801E2, 1.1E1, 3.45601E2);
        ctx.bezierCurveTo(1.1E1, 3.45601E2, 2.58E1, 3.29201E2, 1.9E1, 3.53601E2);
        ctx.bezierCurveTo(1.9E1, 3.53601E2, 3.42E1, 3.30801E2, 3.1E1, 3.44001E2);
        ctx.bezierCurveTo(3.1E1, 3.44001E2, 2.34E1, 3.60001E2, 2.5E1, 3.64801E2);
        ctx.bezierCurveTo(2.5E1, 3.64801E2, 4.18E1, 3.30001E2, 4.3E1, 3.28401E2);
        ctx.bezierCurveTo(4.3E1, 3.28401E2, 4.1E1, 3.70802E2, 5.18E1, 3.34801E2);
        ctx.bezierCurveTo(5.18E1, 3.34801E2, 5.74E1, 3.46801E2, 5.46E1, 3.51201E2);
        ctx.bezierCurveTo(5.46E1, 3.51201E2, 6.26E1, 3.43201E2, 6.18E1, 3.40001E2);
        ctx.bezierCurveTo(6.18E1, 3.40001E2, 6.64E1, 3.31801E2, 6.92E1, 3.45401E2);
        ctx.bezierCurveTo(6.92E1, 3.45401E2, 7.1E1, 3.54801E2, 7.26E1, 3.51601E2);
        ctx.bezierCurveTo(7.26E1, 3.51601E2, 7.66E1, 3.75602E2, 7.78E1, 3.52801E2);
        ctx.bezierCurveTo(7.78E1, 3.52801E2, 7.94E1, 3.39201E2, 7.22E1, 3.27601E2);
        ctx.bezierCurveTo(7.22E1, 3.27601E2, 7.3E1, 3.24401E2, 7.02E1, 3.20401E2);
        ctx.bezierCurveTo(7.02E1, 3.20401E2, 8.38E1, 3.42001E2, 7.66E1, 3.13201E2);
        ctx.bezierCurveTo(7.66E1, 3.13201E2, 8.7801E1, 3.21201E2, 8.9001E1, 3.21201E2);
        ctx.bezierCurveTo(8.9001E1, 3.21201E2, 7.54E1, 2.98001E2, 8.42E1, 3.02801E2);
        ctx.bezierCurveTo(8.42E1, 3.02801E2, 7.9E1, 2.92401E2, 9.7001E1, 3.04401E2);
        ctx.bezierCurveTo(9.7001E1, 3.04401E2, 8.1E1, 2.88401E2, 9.8601E1, 2.98001E2);
        ctx.bezierCurveTo(9.8601E1, 2.98001E2, 1.06601E2, 3.04401E2, 9.9001E1, 2.94401E2);
        ctx.bezierCurveTo(9.9001E1, 2.94401E2, 8.46E1, 2.78401E2, 1.06601E2, 2.96401E2);
        ctx.bezierCurveTo(1.06601E2, 2.96401E2, 1.18201E2, 3.12801E2, 1.19001E2, 3.15601E2);
        ctx.bezierCurveTo(1.19001E2, 3.15601E2, 1.09001E2, 2.86401E2, 1.04601E2, 2.83601E2);
        ctx.bezierCurveTo(1.04601E2, 2.83601E2, 1.13001E2, 2.47201E2, 1.54201E2, 2.62801E2);
        ctx.bezierCurveTo(1.54201E2, 2.62801E2, 1.61001E2, 2.80001E2, 1.65401E2, 2.61601E2);
        ctx.bezierCurveTo(1.65401E2, 2.61601E2, 1.78201E2, 2.55201E2, 1.89401E2, 2.82801E2);
        ctx.bezierCurveTo(1.89401E2, 2.82801E2, 1.93401E2, 2.69201E2, 1.92601E2, 2.66401E2);
        ctx.bezierCurveTo(1.92601E2, 2.66401E2, 1.99401E2, 2.67601E2, 1.98601E2, 2.66401E2);
        ctx.bezierCurveTo(1.98601E2, 2.66401E2, 2.11801E2, 2.70801E2, 2.13001E2, 2.70001E2);
        ctx.bezierCurveTo(2.13001E2, 2.70001E2, 2.19801E2, 2.76801E2, 2.20201E2, 2.73201E2);
        ctx.bezierCurveTo(2.20201E2, 2.73201E2, 2.29401E2, 2.76001E2, 2.27401E2, 2.72401E2);
        ctx.bezierCurveTo(2.27401E2, 2.72401E2, 2.36201E2, 2.88001E2, 2.36601E2, 2.91601E2);
        ctx.lineTo(2.39001E2, 2.77601E2);
        ctx.lineTo(2.41001E2, 2.80401E2);
        ctx.bezierCurveTo(2.41001E2, 2.80401E2, 2.42601E2, 2.72801E2, 2.41801E2, 2.71601E2);
        ctx.bezierCurveTo(2.41001E2, 2.70401E2, 2.61801E2, 2.78401E2, 2.66601E2, 2.99201E2);
        ctx.lineTo(2.68601E2, 3.07601E2);
        ctx.bezierCurveTo(2.68601E2, 3.07601E2, 2.74601E2, 2.92801E2, 2.73001E2, 2.88801E2);
        ctx.bezierCurveTo(2.73001E2, 2.88801E2, 2.78201E2, 2.89601E2, 2.78601E2, 2.94001E2);
        ctx.bezierCurveTo(2.78601E2, 2.94001E2, 2.82601E2, 2.70801E2, 2.77801E2, 2.64801E2);
        ctx.bezierCurveTo(2.77801E2, 2.64801E2, 2.82201E2, 2.64001E2, 2.83401E2, 2.67601E2);
        ctx.lineTo(2.83401E2, 2.60401E2);
        ctx.bezierCurveTo(2.83401E2, 2.60401E2, 2.90601E2, 2.61201E2, 2.90601E2, 2.58801E2);
        ctx.bezierCurveTo(2.90601E2, 2.58801E2, 2.95001E2, 2.54801E2, 2.97001E2, 2.59601E2);
        ctx.bezierCurveTo(2.97001E2, 2.59601E2, 2.84601E2, 2.24401E2, 3.03001E2, 2.43601E2);
        ctx.bezierCurveTo(3.03001E2, 2.43601E2, 3.10201E2, 2.54401E2, 3.06601E2, 2.35601E2);
        ctx.bezierCurveTo(3.03001E2, 2.16801E2, 2.99001E2, 2.15201E2, 3.03801E2, 2.14801E2);
        ctx.bezierCurveTo(3.03801E2, 2.14801E2, 3.04601E2, 2.11201E2, 3.02601E2, 2.09601E2);
        ctx.bezierCurveTo(3.00601E2, 2.08001E2, 3.03801E2, 2.09601E2, 3.03801E2, 2.09601E2);
        ctx.bezierCurveTo(3.03801E2, 2.09601E2, 3.08601E2, 2.13601E2, 3.03401E2, 1.91601E2);
        ctx.bezierCurveTo(3.03401E2, 1.91601E2, 3.09801E2, 1.93201E2, 2.97801E2, 1.64001E2);
        ctx.bezierCurveTo(2.97801E2, 1.64001E2, 3.00601E2, 1.61601E2, 2.96601E2, 1.53201E2);
        ctx.bezierCurveTo(2.96601E2, 1.53201E2, 3.04601E2, 1.57601E2, 3.07401E2, 1.56001E2);
        ctx.bezierCurveTo(3.07401E2, 1.56001E2, 3.07001E2, 1.54401E2, 3.03801E2, 1.50401E2);
        ctx.bezierCurveTo(3.03801E2, 1.50401E2, 2.82201E2, 9.56E1, 3.02601E2, 1.17601E2);
        ctx.bezierCurveTo(3.02601E2, 1.17601E2, 3.14451E2, 1.31151E2, 3.08051E2, 1.08351E2);
        ctx.bezierCurveTo(3.08051E2, 1.08351E2, 2.9894E2, 8.4341E1, 2.99717E2, 8.0045E1);
        ctx.lineTo((-129.83), 1.03065E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.99717E2, 8.0245E1);
        ctx.bezierCurveTo(3.00345E2, 8.0426E1, 3.02551E2, 8.155E1, 3.03801E2, 8.32E1);
        ctx.bezierCurveTo(3.03801E2, 8.32E1, 3.10601E2, 9.4E1, 3.05401E2, 7.56E1);
        ctx.bezierCurveTo(3.05401E2, 7.56E1, 2.96201E2, 4.68E1, 3.05001E2, 5.8E1);
        ctx.bezierCurveTo(3.05001E2, 5.8E1, 3.11001E2, 6.52E1, 3.07801E2, 5.16E1);
        ctx.bezierCurveTo(3.03936E2, 3.5173E1, 3.01401E2, 2.88E1, 3.01401E2, 2.88E1);
        ctx.bezierCurveTo(3.01401E2, 2.88E1, 3.13001E2, 3.36E1, 2.86201E2, (-6));
        ctx.lineTo(2.95001E2, (-2.4));
        ctx.bezierCurveTo(2.95001E2, (-2.4), 2.75401E2, (-42), 2.53801E2, (-47.2));
        ctx.lineTo(2.45801E2, (-53.2));
        ctx.bezierCurveTo(2.45801E2, (-53.2), 2.84201E2, (-91.2), 2.71401E2, (-128));
        ctx.bezierCurveTo(2.71401E2, (-128), 2.64601E2, (-133.2), 2.55001E2, (-124));
        ctx.bezierCurveTo(2.55001E2, (-124), 2.48601E2, (-119.2), 2.42601E2, (-120.8));
        ctx.bezierCurveTo(2.42601E2, (-120.8), 2.11801E2, (-119.6), 2.09801E2, (-119.6));
        ctx.bezierCurveTo(2.07801E2, (-119.6), 1.73001E2, (-156.8), 1.07401E2, (-139.2));
        ctx.bezierCurveTo(1.07401E2, (-139.2), 1.02201E2, (-137.2), 9.7801E1, (-138.4));
        ctx.bezierCurveTo(9.7801E1, (-138.4), 7.94E1, (-154.4), 3.06E1, (-131.6));
        ctx.bezierCurveTo(3.06E1, (-131.6), 2.06E1, (-129.6), 1.9E1, (-129.6));
        ctx.bezierCurveTo(1.74E1, (-129.6), 1.46E1, (-129.6), 6.6E0, (-123.2));
        ctx.bezierCurveTo((-1.4), (-116.8), (-1.8), (-116), (-3.8), (-114.4));
        ctx.bezierCurveTo((-3.8), (-114.4), (-20.2), (-103.2), (-25), (-102.4));
        ctx.bezierCurveTo((-25), (-102.4), (-36.6), (-96), (-41), (-86));
        ctx.lineTo((-44.6), (-84.8));
        ctx.bezierCurveTo((-44.6), (-84.8), (-46.2), (-77.6), (-46.6), (-76.4));
        ctx.bezierCurveTo((-46.6), (-76.4), (-51.4), (-72.8), (-52.2), (-67.2));
        ctx.bezierCurveTo((-52.2), (-67.2), (-61), (-61.2), (-60.6), (-56.8));
        ctx.bezierCurveTo((-60.6), (-56.8), (-62.2), (-51.6), (-63), (-46.8));
        ctx.bezierCurveTo((-63), (-46.8), (-70.2), (-42), (-69.4), (-39.2));
        ctx.bezierCurveTo((-69.4), (-39.2), (-77), (-25.2), (-75.8), (-18.4));
        ctx.bezierCurveTo((-75.8), (-18.4), (-82.2), (-18.8), (-85), (-16.4));
        ctx.bezierCurveTo((-85), (-16.4), (-85.8), (-11.6), (-87.4), (-11.2));
        ctx.bezierCurveTo((-87.4), (-11.2), (-90.2), (-10), (-87.8), (-6));
        ctx.bezierCurveTo((-87.8), (-6), (-89.4), (-3.2), (-89.8), (-1.6));
        ctx.bezierCurveTo((-89.8), (-1.6), (-89), 1.2E0, (-93.4), 6.8E0);
        ctx.bezierCurveTo((-93.4), 6.8E0, (-99.8), 2.56E1, (-97.8), 3.08E1);
        ctx.bezierCurveTo((-97.8), 3.08E1, (-97.4), 3.56E1, (-100.2), 3.72E1);
        ctx.bezierCurveTo((-100.2), 3.72E1, (-103.8), 3.68E1, (-95.4), 4.88E1);
        ctx.bezierCurveTo((-95.4), 4.88E1, (-94.6), 5E1, (-97.8), 5.24E1);
        ctx.bezierCurveTo((-97.8), 5.24E1, (-115), 5.6E1, (-117.4), 7.24E1);
        ctx.bezierCurveTo((-117.4), 7.24E1, (-131), 8.72E1, (-131), 9.24E1);
        ctx.bezierCurveTo((-131), 9.4705E1, (-130.729), 9.7852E1, (-130.03), 1.02465E2);
        ctx.bezierCurveTo((-130.03), 1.02465E2, (-130.6), 1.10801E2, (-103), 1.11601E2);
        ctx.bezierCurveTo((-75.4), 1.12401E2, 2.99717E2, 8.0245E1, 2.99717E2, 8.0245E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-115.6), 1.026E2);
        ctx.bezierCurveTo((-140.6), 6.32E1, (-126.2), 1.19601E2, (-126.2), 1.19601E2);
        ctx.bezierCurveTo((-117.4), 1.54001E2, 1.22E1, 1.16401E2, 1.22E1, 1.16401E2);
        ctx.bezierCurveTo(1.22E1, 1.16401E2, 1.81001E2, 8.6E1, 1.92201E2, 8.2E1);
        ctx.bezierCurveTo(2.03401E2, 7.8E1, 2.98601E2, 8.44E1, 2.98601E2, 8.44E1);
        ctx.lineTo(2.93001E2, 6.76E1);
        ctx.bezierCurveTo(2.28201E2, 2.12E1, 2.09001E2, 4.44E1, 1.95401E2, 4.04E1);
        ctx.bezierCurveTo(1.81801E2, 3.64E1, 1.84201E2, 4.6E1, 1.81001E2, 4.68E1);
        ctx.bezierCurveTo(1.77801E2, 4.76E1, 1.38601E2, 2.28E1, 1.32201E2, 2.36E1);
        ctx.bezierCurveTo(1.25801E2, 2.44E1, 1.00459E2, 6.49E-1, 1.15401E2, 3.24E1);
        ctx.bezierCurveTo(1.31401E2, 6.64E1, 5.7E1, 7.16E1, 4.02E1, 6.04E1);
        ctx.bezierCurveTo(2.34E1, 4.92E1, 4.74E1, 7.88E1, 4.74E1, 7.88E1);
        ctx.bezierCurveTo(6.58E1, 9.88E1, 3.14E1, 8.2E1, 3.14E1, 8.2E1);
        ctx.bezierCurveTo((-3), 6.92E1, (-27), 9.48E1, (-30.2), 9.56E1);
        ctx.bezierCurveTo((-33.4), 9.64E1, (-38.2), 9.96E1, (-39), 9.32E1);
        ctx.bezierCurveTo((-39.8), 8.68E1, (-47.31), 7.0099E1, (-79), 9.64E1);
        ctx.bezierCurveTo((-99), 1.13001E2, (-112.8), 9.1E1, (-112.8), 9.1E1);
        ctx.lineTo((-115.6), 1.026E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#e87f3a';
        ctx.fillStyle = 'rgba(232,127,58,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#e87f3a';
        ctx.fillStyle = 'rgba(232,127,58,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.3351E2, 2.5346E1);
        ctx.bezierCurveTo(1.2711E2, 2.6146E1, 1.01743E2, 2.407E0, 1.1671E2, 3.4146E1);
        ctx.bezierCurveTo(1.3331E2, 6.9346E1, 5.831E1, 7.3346E1, 4.151E1, 6.2146E1);
        ctx.bezierCurveTo(2.4709E1, 5.0946E1, 4.871E1, 8.0546E1, 4.871E1, 8.0546E1);
        ctx.bezierCurveTo(6.711E1, 1.00546E2, 3.2709E1, 8.3746E1, 3.2709E1, 8.3746E1);
        ctx.bezierCurveTo((-1.691), 7.0946E1, (-25.691), 9.6546E1, (-28.891), 9.7346E1);
        ctx.bezierCurveTo((-32.091), 9.8146E1, (-36.891), 1.01346E2, (-37.691), 9.4946E1);
        ctx.bezierCurveTo((-38.491), 8.8546E1, (-45.87), 7.2012E1, (-77.691), 9.8146E1);
        ctx.bezierCurveTo((-98.927), 1.15492E2, (-112.418), 9.4037E1, (-112.418), 9.4037E1);
        ctx.lineTo((-115.618), 1.04146E2);
        ctx.bezierCurveTo((-140.618), 6.4346E1, (-125.546), 1.22655E2, (-125.546), 1.22655E2);
        ctx.bezierCurveTo((-116.745), 1.57056E2, 1.3509E1, 1.18146E2, 1.3509E1, 1.18146E2);
        ctx.bezierCurveTo(1.3509E1, 1.18146E2, 1.8231E2, 8.7746E1, 1.9351E2, 8.3746E1);
        ctx.bezierCurveTo(2.0471E2, 7.9746E1, 2.99038E2, 8.6073E1, 2.99038E2, 8.6073E1);
        ctx.lineTo(2.9351E2, 6.8764E1);
        ctx.bezierCurveTo(2.2871E2, 2.2364E1, 2.1031E2, 4.6146E1, 1.9671E2, 4.2146E1);
        ctx.bezierCurveTo(1.8311E2, 3.8146E1, 1.8551E2, 4.7746E1, 1.8231E2, 4.8546E1);
        ctx.bezierCurveTo(1.7911E2, 4.9346E1, 1.3991E2, 2.4546E1, 1.3351E2, 2.5346E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ea8c4d';
        ctx.fillStyle = 'rgba(234,140,77,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ea8c4d';
        ctx.fillStyle = 'rgba(234,140,77,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.34819E2, 2.7091E1);
        ctx.bezierCurveTo(1.28419E2, 2.7891E1, 1.03685E2, 3.862E0, 1.18019E2, 3.5891E1);
        ctx.bezierCurveTo(1.34219E2, 7.2092E1, 5.9619E1, 7.5092E1, 4.2819E1, 6.3892E1);
        ctx.bezierCurveTo(2.6019E1, 5.2692E1, 5.0019E1, 8.2292E1, 5.0019E1, 8.2292E1);
        ctx.bezierCurveTo(6.8419E1, 1.02292E2, 3.4019E1, 8.5492E1, 3.4019E1, 8.5492E1);
        ctx.bezierCurveTo((-0.381), 7.2692E1, (-24.382), 9.8292E1, (-27.582), 9.9092E1);
        ctx.bezierCurveTo((-30.782), 9.9892E1, (-35.582), 1.03092E2, (-36.382), 9.6692E1);
        ctx.bezierCurveTo((-37.182), 9.0292E1, (-44.43), 7.3925E1, (-76.382), 9.9892E1);
        ctx.bezierCurveTo((-98.855), 1.17983E2, (-112.036), 9.7074E1, (-112.036), 9.7074E1);
        ctx.lineTo((-115.636), 1.05692E2);
        ctx.bezierCurveTo((-139.436), 6.6692E1, (-124.891), 1.2571E2, (-124.891), 1.2571E2);
        ctx.bezierCurveTo((-116.091), 1.6011E2, 1.4819E1, 1.19892E2, 1.4819E1, 1.19892E2);
        ctx.bezierCurveTo(1.4819E1, 1.19892E2, 1.83619E2, 8.9492E1, 1.94819E2, 8.5492E1);
        ctx.bezierCurveTo(2.06019E2, 8.1492E1, 2.99474E2, 8.7746E1, 2.99474E2, 8.7746E1);
        ctx.lineTo(2.9402E2, 6.9928E1);
        ctx.bezierCurveTo(2.29219E2, 2.3528E1, 2.11619E2, 4.7891E1, 1.98019E2, 4.3891E1);
        ctx.bezierCurveTo(1.84419E2, 3.9891E1, 1.86819E2, 4.9491E1, 1.83619E2, 5.0292E1);
        ctx.bezierCurveTo(1.80419E2, 5.1092E1, 1.41219E2, 2.6291E1, 1.34819E2, 2.7091E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ec9961';
        ctx.fillStyle = 'rgba(236,153,97,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ec9961';
        ctx.fillStyle = 'rgba(236,153,97,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.36128E2, 2.8837E1);
        ctx.bezierCurveTo(1.29728E2, 2.9637E1, 1.04999E2, 5.605E0, 1.19328E2, 3.7637E1);
        ctx.bezierCurveTo(1.36128E2, 7.5193E1, 6.0394E1, 7.6482E1, 4.4128E1, 6.5637E1);
        ctx.bezierCurveTo(2.7328E1, 5.4437E1, 5.1328E1, 8.4037E1, 5.1328E1, 8.4037E1);
        ctx.bezierCurveTo(6.9728E1, 1.04037E2, 3.5328E1, 8.7237E1, 3.5328E1, 8.7237E1);
        ctx.bezierCurveTo(9.28E-1, 7.4437E1, (-23.072), 1.00037E2, (-26.272), 1.00837E2);
        ctx.bezierCurveTo((-29.472), 1.01637E2, (-34.272), 1.04837E2, (-35.072), 9.8437E1);
        ctx.bezierCurveTo((-35.872), 9.2037E1, (-42.989), 7.5839E1, (-75.073), 1.01637E2);
        ctx.bezierCurveTo((-98.782), 1.20474E2, (-111.655), 1.0011E2, (-111.655), 1.0011E2);
        ctx.lineTo((-115.655), 1.07237E2);
        ctx.bezierCurveTo((-137.455), 7.0437E1, (-124.236), 1.28765E2, (-124.236), 1.28765E2);
        ctx.bezierCurveTo((-115.436), 1.63165E2, 1.6128E1, 1.21637E2, 1.6128E1, 1.21637E2);
        ctx.bezierCurveTo(1.6128E1, 1.21637E2, 1.84928E2, 9.1237E1, 1.96129E2, 8.7237E1);
        ctx.bezierCurveTo(2.07329E2, 8.3237E1, 2.99911E2, 8.9419E1, 2.99911E2, 8.9419E1);
        ctx.lineTo(2.94529E2, 7.1092E1);
        ctx.bezierCurveTo(2.29729E2, 2.4691E1, 2.12929E2, 4.9637E1, 1.99329E2, 4.5637E1);
        ctx.bezierCurveTo(1.85728E2, 4.1637E1, 1.88128E2, 5.1237E1, 1.84928E2, 5.2037E1);
        ctx.bezierCurveTo(1.81728E2, 5.2837E1, 1.42528E2, 2.8037E1, 1.36128E2, 2.8837E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#eea575';
        ctx.fillStyle = 'rgba(238,165,117,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#eea575';
        ctx.fillStyle = 'rgba(238,165,117,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.37438E2, 3.0583E1);
        ctx.bezierCurveTo(1.31037E2, 3.1383E1, 1.06814E2, 7.129E0, 1.20637E2, 3.9383E1);
        ctx.bezierCurveTo(1.37438E2, 7.8583E1, 6.2237E1, 7.8583E1, 4.5437E1, 6.7383E1);
        ctx.bezierCurveTo(2.8637E1, 5.6183E1, 5.2637E1, 8.5783E1, 5.2637E1, 8.5783E1);
        ctx.bezierCurveTo(7.1037E1, 1.05783E2, 3.6637E1, 8.8983E1, 3.6637E1, 8.8983E1);
        ctx.bezierCurveTo(2.237E0, 7.6183E1, (-21.763), 1.01783E2, (-24.963), 1.02583E2);
        ctx.bezierCurveTo((-28.163), 1.03383E2, (-32.963), 1.06583E2, (-33.763), 1.00183E2);
        ctx.bezierCurveTo((-34.563), 9.3783E1, (-41.548), 7.7752E1, (-73.763), 1.03383E2);
        ctx.bezierCurveTo((-98.709), 1.22965E2, (-111.273), 1.03146E2, (-111.273), 1.03146E2);
        ctx.lineTo((-115.673), 1.08783E2);
        ctx.bezierCurveTo((-135.473), 7.3982E1, (-123.582), 1.31819E2, (-123.582), 1.31819E2);
        ctx.bezierCurveTo((-114.782), 1.6622E2, 1.7437E1, 1.23383E2, 1.7437E1, 1.23383E2);
        ctx.bezierCurveTo(1.7437E1, 1.23383E2, 1.86238E2, 9.2983E1, 1.97438E2, 8.8983E1);
        ctx.bezierCurveTo(2.08638E2, 8.4983E1, 3.00347E2, 9.1092E1, 3.00347E2, 9.1092E1);
        ctx.lineTo(2.95038E2, 7.2255E1);
        ctx.bezierCurveTo(2.30238E2, 2.5855E1, 2.14238E2, 5.1383E1, 2.00638E2, 4.7383E1);
        ctx.bezierCurveTo(1.87038E2, 4.3383E1, 1.89438E2, 5.2983E1, 1.86238E2, 5.3783E1);
        ctx.bezierCurveTo(1.83038E2, 5.4583E1, 1.43838E2, 2.9783E1, 1.37438E2, 3.0583E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f1b288';
        ctx.fillStyle = 'rgba(241,178,136,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f1b288';
        ctx.fillStyle = 'rgba(241,178,136,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.38747E2, 3.2328E1);
        ctx.bezierCurveTo(1.32347E2, 3.3128E1, 1.06383E2, 9.677E0, 1.21947E2, 4.1128E1);
        ctx.bezierCurveTo(1.41147E2, 7.9928E1, 6.3546E1, 8.0328E1, 4.6746E1, 6.9128E1);
        ctx.bezierCurveTo(2.9946E1, 5.7928E1, 5.3946E1, 8.7528E1, 5.3946E1, 8.7528E1);
        ctx.bezierCurveTo(7.2346E1, 1.07528E2, 3.7946E1, 9.0728E1, 3.7946E1, 9.0728E1);
        ctx.bezierCurveTo(3.546E0, 7.7928E1, (-20.454), 1.03528E2, (-23.654), 1.04328E2);
        ctx.bezierCurveTo((-26.854), 1.05128E2, (-31.654), 1.08328E2, (-32.454), 1.01928E2);
        ctx.bezierCurveTo((-33.254), 9.5528E1, (-40.108), 7.9665E1, (-72.454), 1.05128E2);
        ctx.bezierCurveTo((-98.636), 1.25456E2, (-110.891), 1.06183E2, (-110.891), 1.06183E2);
        ctx.lineTo((-115.691), 1.10328E2);
        ctx.bezierCurveTo((-133.691), 7.7128E1, (-122.927), 1.34874E2, (-122.927), 1.34874E2);
        ctx.bezierCurveTo((-114.127), 1.69274E2, 1.8746E1, 1.25128E2, 1.8746E1, 1.25128E2);
        ctx.bezierCurveTo(1.8746E1, 1.25128E2, 1.87547E2, 9.4728E1, 1.98747E2, 9.0728E1);
        ctx.bezierCurveTo(2.09947E2, 8.6728E1, 3.00783E2, 9.2764E1, 3.00783E2, 9.2764E1);
        ctx.lineTo(2.95547E2, 7.3419E1);
        ctx.bezierCurveTo(2.30747E2, 2.7019E1, 2.15547E2, 5.3128E1, 2.01947E2, 4.9128E1);
        ctx.bezierCurveTo(1.88347E2, 4.5128E1, 1.90747E2, 5.4728E1, 1.87547E2, 5.5528E1);
        ctx.bezierCurveTo(1.84347E2, 5.6328E1, 1.45147E2, 3.1528E1, 1.38747E2, 3.2328E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f3bf9c';
        ctx.fillStyle = 'rgba(243,191,156,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f3bf9c';
        ctx.fillStyle = 'rgba(243,191,156,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.40056E2, 3.4073E1);
        ctx.bezierCurveTo(1.33655E2, 3.4873E1, 1.07313E2, 1.1613E1, 1.23255E2, 4.2873E1);
        ctx.bezierCurveTo(1.43656E2, 8.2874E1, 6.4855E1, 8.2074E1, 4.8055E1, 7.0874E1);
        ctx.bezierCurveTo(3.1255E1, 5.9674E1, 5.5255E1, 8.9274E1, 5.5255E1, 8.9274E1);
        ctx.bezierCurveTo(7.3655E1, 1.09274E2, 3.9255E1, 9.2474E1, 3.9255E1, 9.2474E1);
        ctx.bezierCurveTo(4.855E0, 7.9674E1, (-19.145), 1.05274E2, (-22.345), 1.06074E2);
        ctx.bezierCurveTo((-25.545), 1.06874E2, (-30.345), 1.10074E2, (-31.145), 1.03674E2);
        ctx.bezierCurveTo((-31.945), 9.7274E1, (-38.668), 8.1578E1, (-71.145), 1.06874E2);
        ctx.bezierCurveTo((-98.564), 1.27947E2, (-110.509), 1.09219E2, (-110.509), 1.09219E2);
        ctx.lineTo((-115.709), 1.11874E2);
        ctx.bezierCurveTo((-131.709), 8.1674E1, (-122.273), 1.37929E2, (-122.273), 1.37929E2);
        ctx.bezierCurveTo((-113.473), 1.72329E2, 2.0055E1, 1.26874E2, 2.0055E1, 1.26874E2);
        ctx.bezierCurveTo(2.0055E1, 1.26874E2, 1.88856E2, 9.6474E1, 2.00056E2, 9.2474E1);
        ctx.bezierCurveTo(2.11256E2, 8.8474E1, 3.0122E2, 9.4437E1, 3.0122E2, 9.4437E1);
        ctx.lineTo(2.96056E2, 7.4583E1);
        ctx.bezierCurveTo(2.31256E2, 2.8183E1, 2.16856E2, 5.4874E1, 2.03256E2, 5.0874E1);
        ctx.bezierCurveTo(1.89656E2, 4.6873E1, 1.92056E2, 5.6474E1, 1.88856E2, 5.7274E1);
        ctx.bezierCurveTo(1.85656E2, 5.8074E1, 1.46456E2, 3.3273E1, 1.40056E2, 3.4073E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f5ccb0';
        ctx.fillStyle = 'rgba(245,204,176,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f5ccb0';
        ctx.fillStyle = 'rgba(245,204,176,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.41365E2, 3.5819E1);
        ctx.bezierCurveTo(1.34965E2, 3.6619E1, 1.07523E2, 1.3944E1, 1.24565E2, 4.4619E1);
        ctx.bezierCurveTo(1.46565E2, 8.4219E1, 6.6164E1, 8.3819E1, 4.9364E1, 7.2619E1);
        ctx.bezierCurveTo(3.2564E1, 6.1419E1, 5.6564E1, 9.1019E1, 5.6564E1, 9.1019E1);
        ctx.bezierCurveTo(7.4964E1, 1.11019E2, 4.0564E1, 9.4219E1, 4.0564E1, 9.4219E1);
        ctx.bezierCurveTo(6.164E0, 8.1419E1, (-17.836), 1.07019E2, (-21.036), 1.07819E2);
        ctx.bezierCurveTo((-24.236), 1.08619E2, (-29.036), 1.11819E2, (-29.836), 1.05419E2);
        ctx.bezierCurveTo((-30.636), 9.9019E1, (-37.227), 8.3492E1, (-69.836), 1.08619E2);
        ctx.bezierCurveTo((-98.491), 1.30438E2, (-110.127), 1.12256E2, (-110.127), 1.12256E2);
        ctx.lineTo((-115.727), 1.13419E2);
        ctx.bezierCurveTo((-130.128), 8.5019E1, (-121.618), 1.40983E2, (-121.618), 1.40983E2);
        ctx.bezierCurveTo((-112.818), 1.75384E2, 2.1364E1, 1.28619E2, 2.1364E1, 1.28619E2);
        ctx.bezierCurveTo(2.1364E1, 1.28619E2, 1.90165E2, 9.8219E1, 2.01365E2, 9.4219E1);
        ctx.bezierCurveTo(2.12565E2, 9.0219E1, 3.01656E2, 9.611E1, 3.01656E2, 9.611E1);
        ctx.lineTo(2.96565E2, 7.5746E1);
        ctx.bezierCurveTo(2.31765E2, 2.9346E1, 2.18165E2, 5.6619E1, 2.04565E2, 5.2619E1);
        ctx.bezierCurveTo(1.90965E2, 4.8619E1, 1.93365E2, 5.8219E1, 1.90165E2, 5.9019E1);
        ctx.bezierCurveTo(1.86965E2, 5.9819E1, 1.47765E2, 3.5019E1, 1.41365E2, 3.5819E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f8d8c4';
        ctx.fillStyle = 'rgba(248,216,196,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f8d8c4';
        ctx.fillStyle = 'rgba(248,216,196,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.42674E2, 3.7565E1);
        ctx.bezierCurveTo(1.36274E2, 3.8365E1, 1.08832E2, 1.5689E1, 1.25874E2, 4.6365E1);
        ctx.bezierCurveTo(1.47874E2, 8.5965E1, 6.7474E1, 8.5565E1, 5.0674E1, 7.4365E1);
        ctx.bezierCurveTo(3.3874E1, 6.3165E1, 5.7874E1, 9.2765E1, 5.7874E1, 9.2765E1);
        ctx.bezierCurveTo(7.6274E1, 1.12765E2, 4.1874E1, 9.5965E1, 4.1874E1, 9.5965E1);
        ctx.bezierCurveTo(7.473E0, 8.3165E1, (-16.527), 1.08765E2, (-19.727), 1.09565E2);
        ctx.bezierCurveTo((-22.927), 1.10365E2, (-27.727), 1.13565E2, (-28.527), 1.07165E2);
        ctx.bezierCurveTo((-29.327), 1.00765E2, (-35.786), 8.5405E1, (-68.527), 1.10365E2);
        ctx.bezierCurveTo((-98.418), 1.32929E2, (-109.745), 1.15293E2, (-109.745), 1.15293E2);
        ctx.lineTo((-115.745), 1.14965E2);
        ctx.bezierCurveTo((-129.346), 8.8564E1, (-120.963), 1.44038E2, (-120.963), 1.44038E2);
        ctx.bezierCurveTo((-112.163), 1.78438E2, 2.2673E1, 1.30365E2, 2.2673E1, 1.30365E2);
        ctx.bezierCurveTo(2.2673E1, 1.30365E2, 1.91474E2, 9.9965E1, 2.02674E2, 9.5965E1);
        ctx.bezierCurveTo(2.13874E2, 9.1965E1, 3.02093E2, 9.7783E1, 3.02093E2, 9.7783E1);
        ctx.lineTo(2.97075E2, 7.691E1);
        ctx.bezierCurveTo(2.32274E2, 3.051E1, 2.19474E2, 5.8365E1, 2.05874E2, 5.4365E1);
        ctx.bezierCurveTo(1.92274E2, 5.0365E1, 1.94674E2, 5.9965E1, 1.91474E2, 6.0765E1);
        ctx.bezierCurveTo(1.88274E2, 6.1565E1, 1.49074E2, 3.6765E1, 1.42674E2, 3.7565E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#fae5d7';
        ctx.fillStyle = 'rgba(250,229,215,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#fae5d7';
        ctx.fillStyle = 'rgba(250,229,215,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.43983E2, 3.931E1);
        ctx.bezierCurveTo(1.37583E2, 4.011E1, 1.10529E2, 1.7223E1, 1.27183E2, 4.811E1);
        ctx.bezierCurveTo(1.49183E2, 8.891E1, 6.8783E1, 8.731E1, 5.1983E1, 7.611E1);
        ctx.bezierCurveTo(3.5183E1, 6.491E1, 5.9183E1, 9.451E1, 5.9183E1, 9.451E1);
        ctx.bezierCurveTo(7.7583E1, 1.1451E2, 4.3183E1, 9.771E1, 4.3183E1, 9.771E1);
        ctx.bezierCurveTo(8.783E0, 8.491E1, (-15.217), 1.1051E2, (-18.417), 1.1131E2);
        ctx.bezierCurveTo((-21.618), 1.1211E2, (-26.418), 1.1531E2, (-27.218), 1.0891E2);
        ctx.bezierCurveTo((-28.018), 1.0251E2, (-34.346), 8.7318E1, (-67.218), 1.1211E2);
        ctx.bezierCurveTo((-98.345), 1.3542E2, (-109.363), 1.18329E2, (-109.363), 1.18329E2);
        ctx.lineTo((-115.764), 1.1651E2);
        ctx.bezierCurveTo((-128.764), 9.251E1, (-120.309), 1.47093E2, (-120.309), 1.47093E2);
        ctx.bezierCurveTo((-111.509), 1.81493E2, 2.3983E1, 1.3211E2, 2.3983E1, 1.3211E2);
        ctx.bezierCurveTo(2.3983E1, 1.3211E2, 1.92783E2, 1.0171E2, 2.03983E2, 9.771E1);
        ctx.bezierCurveTo(2.15183E2, 9.371E1, 3.02529E2, 9.9456E1, 3.02529E2, 9.9456E1);
        ctx.lineTo(2.97583E2, 7.8074E1);
        ctx.bezierCurveTo(2.32783E2, 3.1673E1, 2.20783E2, 6.011E1, 2.07183E2, 5.611E1);
        ctx.bezierCurveTo(1.93583E2, 5.211E1, 1.95983E2, 6.171E1, 1.92783E2, 6.251E1);
        ctx.bezierCurveTo(1.89583E2, 6.331E1, 1.50383E2, 3.851E1, 1.43983E2, 3.931E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#fcf2eb';
        ctx.fillStyle = 'rgba(252,242,235,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#fcf2eb';
        ctx.fillStyle = 'rgba(252,242,235,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.45292E2, 4.1055E1);
        ctx.bezierCurveTo(1.38892E2, 4.1855E1, 1.12917E2, 1.8411E1, 1.28492E2, 4.9855E1);
        ctx.bezierCurveTo(1.49692E2, 9.2656E1, 7.0092E1, 8.9056E1, 5.3292E1, 7.7856E1);
        ctx.bezierCurveTo(3.6492E1, 6.6656E1, 6.0492E1, 9.6256E1, 6.0492E1, 9.6256E1);
        ctx.bezierCurveTo(7.8892E1, 1.16256E2, 4.4492E1, 9.9456E1, 4.4492E1, 9.9456E1);
        ctx.bezierCurveTo(1.0092E1, 8.6656E1, (-13.908), 1.12256E2, (-17.108), 1.13056E2);
        ctx.bezierCurveTo((-20.308), 1.13856E2, (-25.108), 1.17056E2, (-25.908), 1.10656E2);
        ctx.bezierCurveTo((-26.708), 1.04256E2, (-32.905), 8.9232E1, (-65.908), 1.13856E2);
        ctx.bezierCurveTo((-98.273), 1.37911E2, (-108.982), 1.21365E2, (-108.982), 1.21365E2);
        ctx.lineTo((-115.782), 1.18056E2);
        ctx.bezierCurveTo((-128.582), 9.4856E1, (-119.654), 1.50147E2, (-119.654), 1.50147E2);
        ctx.bezierCurveTo((-110.854), 1.84547E2, 2.5292E1, 1.33856E2, 2.5292E1, 1.33856E2);
        ctx.bezierCurveTo(2.5292E1, 1.33856E2, 1.94093E2, 1.03456E2, 2.05293E2, 9.9456E1);
        ctx.bezierCurveTo(2.16493E2, 9.5456E1, 3.02965E2, 1.01128E2, 3.02965E2, 1.01128E2);
        ctx.lineTo(2.98093E2, 7.9237E1);
        ctx.bezierCurveTo(2.33292E2, 3.2837E1, 2.22093E2, 6.1856E1, 2.08493E2, 5.7856E1);
        ctx.bezierCurveTo(1.94893E2, 5.3855E1, 1.97293E2, 6.3456E1, 1.94093E2, 6.4256E1);
        ctx.bezierCurveTo(1.90892E2, 6.5056E1, 1.51692E2, 4.0255E1, 1.45292E2, 4.1055E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-115.8), 1.19601E2);
        ctx.bezierCurveTo((-128.6), 9.76E1, (-119), 1.53201E2, (-119), 1.53201E2);
        ctx.bezierCurveTo((-110.2), 1.87601E2, 2.66E1, 1.35601E2, 2.66E1, 1.35601E2);
        ctx.bezierCurveTo(2.66E1, 1.35601E2, 1.95401E2, 1.052E2, 2.06601E2, 1.012E2);
        ctx.bezierCurveTo(2.17801E2, 9.72E1, 3.03401E2, 1.028E2, 3.03401E2, 1.028E2);
        ctx.lineTo(2.98601E2, 8.04E1);
        ctx.bezierCurveTo(2.33801E2, 3.4E1, 2.23401E2, 6.36E1, 2.09801E2, 5.96E1);
        ctx.bezierCurveTo(1.96201E2, 5.56E1, 1.98601E2, 6.52E1, 1.95401E2, 6.6E1);
        ctx.bezierCurveTo(1.92201E2, 6.68E1, 1.53001E2, 4.2E1, 1.46601E2, 4.28E1);
        ctx.bezierCurveTo(1.40201E2, 4.36E1, 1.14981E2, 1.9793E1, 1.29801E2, 5.16E1);
        ctx.bezierCurveTo(1.52028E2, 9.9307E1, 6.9041E1, 8.9227E1, 5.46E1, 7.96E1);
        ctx.bezierCurveTo(3.78E1, 6.84E1, 6.18E1, 9.8E1, 6.18E1, 9.8E1);
        ctx.bezierCurveTo(8.02E1, 1.18001E2, 4.58E1, 1.012E2, 4.58E1, 1.012E2);
        ctx.bezierCurveTo(1.14E1, 8.84E1, (-12.6), 1.14001E2, (-15.8), 1.14801E2);
        ctx.bezierCurveTo((-19), 1.15601E2, (-23.8), 1.18801E2, (-24.6), 1.12401E2);
        ctx.bezierCurveTo((-25.4), 1.06E2, (-31.465), 9.1144E1, (-64.6), 1.15601E2);
        ctx.bezierCurveTo((-98.2), 1.40401E2, (-108.6), 1.24401E2, (-108.6), 1.24401E2);
        ctx.lineTo((-115.8), 1.19601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-74.2), 1.49601E2);
        ctx.bezierCurveTo((-74.2), 1.49601E2, (-81.4), 1.61201E2, (-60.6), 1.74401E2);
        ctx.bezierCurveTo((-60.6), 1.74401E2, (-59.2), 1.75801E2, (-77.2), 1.71601E2);
        ctx.bezierCurveTo((-77.2), 1.71601E2, (-83.4), 1.69601E2, (-85), 1.59201E2);
        ctx.bezierCurveTo((-85), 1.59201E2, (-89.8), 1.54801E2, (-94.6), 1.49201E2);
        ctx.bezierCurveTo((-99.4), 1.43601E2, (-74.2), 1.49601E2, (-74.2), 1.49601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(6.58E1, 1.02E2);
        ctx.bezierCurveTo(6.58E1, 1.02E2, 8.3498E1, 1.28821E2, 8.29E1, 1.33601E2);
        ctx.bezierCurveTo(8.16E1, 1.44001E2, 8.14E1, 1.53601E2, 8.46E1, 1.57601E2);
        ctx.bezierCurveTo(8.7801E1, 1.61601E2, 9.6601E1, 1.94801E2, 9.6601E1, 1.94801E2);
        ctx.bezierCurveTo(9.6601E1, 1.94801E2, 9.6201E1, 1.96001E2, 1.08601E2, 1.58001E2);
        ctx.bezierCurveTo(1.08601E2, 1.58001E2, 1.20201E2, 1.42001E2, 1.00201E2, 1.23601E2);
        ctx.bezierCurveTo(1.00201E2, 1.23601E2, 6.5E1, 9.48E1, 6.58E1, 1.02E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-54.2), 1.76401E2);
        ctx.bezierCurveTo((-54.2), 1.76401E2, (-43), 1.83601E2, (-57.4), 2.14801E2);
        ctx.lineTo((-51), 2.12401E2);
        ctx.bezierCurveTo((-51), 2.12401E2, (-51.8), 2.23601E2, (-55), 2.26001E2);
        ctx.lineTo((-47.8), 2.22801E2);
        ctx.bezierCurveTo((-47.8), 2.22801E2, (-43), 2.30801E2, (-47), 2.35601E2);
        ctx.bezierCurveTo((-47), 2.35601E2, (-30.2), 2.43601E2, (-31), 2.50001E2);
        ctx.bezierCurveTo((-31), 2.50001E2, (-24.6), 2.42001E2, (-28.6), 2.35601E2);
        ctx.bezierCurveTo((-32.6), 2.29201E2, (-39.8), 2.33201E2, (-39), 2.14801E2);
        ctx.lineTo((-47.8), 2.18001E2);
        ctx.bezierCurveTo((-47.8), 2.18001E2, (-42.2), 2.09201E2, (-42.2), 2.02801E2);
        ctx.lineTo((-50.2), 2.05201E2);
        ctx.bezierCurveTo((-50.2), 2.05201E2, (-34.731), 1.78623E2, (-45.4), 1.77201E2);
        ctx.bezierCurveTo((-51.4), 1.76401E2, (-54.2), 1.76401E2, (-54.2), 1.76401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-21.8), 1.93201E2);
        ctx.bezierCurveTo((-21.8), 1.93201E2, (-19), 1.88801E2, (-21.8), 1.89601E2);
        ctx.bezierCurveTo((-24.6), 1.90401E2, (-55.8), 2.05201E2, (-61.8), 2.14801E2);
        ctx.bezierCurveTo((-61.8), 2.14801E2, (-27.4), 1.90401E2, (-21.8), 1.93201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-11.4), 2.01201E2);
        ctx.bezierCurveTo((-11.4), 2.01201E2, (-8.6), 1.96801E2, (-11.4), 1.97601E2);
        ctx.bezierCurveTo((-14.2), 1.98401E2, (-45.4), 2.13201E2, (-51.4), 2.22801E2);
        ctx.bezierCurveTo((-51.4), 2.22801E2, (-17), 1.98401E2, (-11.4), 2.01201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.8E0, 1.86001E2);
        ctx.bezierCurveTo(1.8E0, 1.86001E2, 4.6E0, 1.81601E2, 1.8E0, 1.82401E2);
        ctx.bezierCurveTo((-1), 1.83201E2, (-32.2), 1.98001E2, (-38.2), 2.07601E2);
        ctx.bezierCurveTo((-38.2), 2.07601E2, (-3.8), 1.83201E2, 1.8E0, 1.86001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-21.4), 2.29601E2);
        ctx.bezierCurveTo((-21.4), 2.29601E2, (-21.4), 2.23601E2, (-24.2), 2.24401E2);
        ctx.bezierCurveTo((-27), 2.25201E2, (-63), 2.42801E2, (-69), 2.52401E2);
        ctx.bezierCurveTo((-69), 2.52401E2, (-27), 2.26801E2, (-21.4), 2.29601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-20.2), 2.18801E2);
        ctx.bezierCurveTo((-20.2), 2.18801E2, (-19), 2.14001E2, (-21.8), 2.14801E2);
        ctx.bezierCurveTo((-23.8), 2.14801E2, (-50.2), 2.26401E2, (-56.2), 2.36001E2);
        ctx.bezierCurveTo((-56.2), 2.36001E2, (-26.6), 2.14401E2, (-20.2), 2.18801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-34.6), 2.66401E2);
        ctx.lineTo((-44.6), 2.74001E2);
        ctx.bezierCurveTo((-44.6), 2.74001E2, (-34.2), 2.66401E2, (-30.6), 2.67601E2);
        ctx.bezierCurveTo((-30.6), 2.67601E2, (-37.4), 2.78801E2, (-38.2), 2.84001E2);
        ctx.bezierCurveTo((-38.2), 2.84001E2, (-27.8), 2.71201E2, (-22.2), 2.71601E2);
        ctx.bezierCurveTo((-22.2), 2.71601E2, (-14.6), 2.72001E2, (-14.6), 2.82801E2);
        ctx.bezierCurveTo((-14.6), 2.82801E2, (-9), 2.72401E2, (-5.8), 2.72801E2);
        ctx.bezierCurveTo((-5.8), 2.72801E2, (-4.6), 2.79201E2, (-5.8), 2.86001E2);
        ctx.bezierCurveTo((-5.8), 2.86001E2, (-1.8), 2.78401E2, 2.2E0, 2.80001E2);
        ctx.bezierCurveTo(2.2E0, 2.80001E2, 8.6E0, 2.78001E2, 7.8E0, 2.89601E2);
        ctx.bezierCurveTo(7.8E0, 2.89601E2, 7.8E0, 3.00001E2, 7E0, 3.02801E2);
        ctx.bezierCurveTo(7E0, 3.02801E2, 1.26E1, 2.76401E2, 1.5E1, 2.76001E2);
        ctx.bezierCurveTo(1.5E1, 2.76001E2, 2.3E1, 2.74801E2, 2.78E1, 2.83601E2);
        ctx.bezierCurveTo(2.78E1, 2.83601E2, 2.38E1, 2.76001E2, 2.86E1, 2.78001E2);
        ctx.bezierCurveTo(2.86E1, 2.78001E2, 3.94E1, 2.79601E2, 4.26E1, 2.86401E2);
        ctx.bezierCurveTo(4.26E1, 2.86401E2, 3.58E1, 2.74401E2, 4.14E1, 2.77601E2);
        ctx.bezierCurveTo(4.14E1, 2.77601E2, 4.82E1, 2.77601E2, 4.94E1, 2.84001E2);
        ctx.bezierCurveTo(4.94E1, 2.84001E2, 5.78E1, 3.05201E2, 5.98E1, 3.06801E2);
        ctx.bezierCurveTo(5.98E1, 3.06801E2, 5.22E1, 2.85201E2, 5.38E1, 2.85201E2);
        ctx.bezierCurveTo(5.38E1, 2.85201E2, 5.18E1, 2.73201E2, 5.7E1, 2.88001E2);
        ctx.bezierCurveTo(5.7E1, 2.88001E2, 5.38E1, 2.74001E2, 5.94E1, 2.74801E2);
        ctx.bezierCurveTo(6.5E1, 2.75601E2, 6.94E1, 2.85601E2, 7.78E1, 2.83201E2);
        ctx.bezierCurveTo(7.78E1, 2.83201E2, 8.7401E1, 2.88801E2, 8.9401E1, 2.19601E2);
        ctx.lineTo((-34.6), 2.66401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-29.8), 1.73601E2);
        ctx.bezierCurveTo((-29.8), 1.73601E2, (-15), 1.67601E2, 2.5E1, 1.73601E2);
        ctx.bezierCurveTo(2.5E1, 1.73601E2, 3.22E1, 1.74001E2, 3.9E1, 1.65201E2);
        ctx.bezierCurveTo(4.58E1, 1.56401E2, 7.26E1, 1.49201E2, 7.9E1, 1.51201E2);
        ctx.lineTo(8.8601E1, 1.57601E2);
        ctx.lineTo(8.9401E1, 1.58801E2);
        ctx.bezierCurveTo(8.9401E1, 1.58801E2, 1.01801E2, 1.69201E2, 1.02201E2, 1.76801E2);
        ctx.bezierCurveTo(1.02601E2, 1.84401E2, 8.7801E1, 2.32401E2, 7.82E1, 2.48401E2);
        ctx.bezierCurveTo(6.86E1, 2.64401E2, 5.9E1, 2.76801E2, 3.98E1, 2.74401E2);
        ctx.bezierCurveTo(3.98E1, 2.74401E2, 1.9E1, 2.70401E2, (-6.6), 2.74401E2);
        ctx.bezierCurveTo((-6.6), 2.74401E2, (-35.8), 2.72801E2, (-38.6), 2.64801E2);
        ctx.bezierCurveTo((-41.4), 2.56801E2, (-27.4), 2.41601E2, (-27.4), 2.41601E2);
        ctx.bezierCurveTo((-27.4), 2.41601E2, (-23), 2.33201E2, (-24.2), 2.18801E2);
        ctx.bezierCurveTo((-25.4), 2.04401E2, (-25), 1.76401E2, (-29.8), 1.73601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#e5668c';
        ctx.fillStyle = 'rgba(229,102,140,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#e5668c';
        ctx.fillStyle = 'rgba(229,102,140,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-7.8), 1.75601E2);
        ctx.bezierCurveTo(6E-1, 1.94001E2, (-29), 2.59201E2, (-29), 2.59201E2);
        ctx.bezierCurveTo((-31), 2.60801E2, (-16.34), 2.66846E2, (-6.2), 2.64401E2);
        ctx.bezierCurveTo(4.746E0, 2.61763E2, 4.5E1, 2.66001E2, 4.5E1, 2.66001E2);
        ctx.bezierCurveTo(6.86E1, 2.50401E2, 8.14E1, 2.06001E2, 8.14E1, 2.06001E2);
        ctx.bezierCurveTo(8.14E1, 2.06001E2, 9.1801E1, 1.82001E2, 7.42E1, 1.78801E2);
        ctx.bezierCurveTo(5.66E1, 1.75601E2, (-7.8), 1.75601E2, (-7.8), 1.75601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#b23259';
        ctx.fillStyle = 'rgba(178,50,89,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#b23259';
        ctx.fillStyle = 'rgba(178,50,89,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-9.831), 2.06497E2);
        ctx.bezierCurveTo((-6.505), 1.93707E2, (-4.921), 1.81906E2, (-7.8), 1.75601E2);
        ctx.bezierCurveTo((-7.8), 1.75601E2, 5.46E1, 1.82001E2, 6.58E1, 1.61201E2);
        ctx.bezierCurveTo(7.0041E1, 1.53326E2, 8.4801E1, 1.84001E2, 8.44E1, 1.93601E2);
        ctx.bezierCurveTo(8.44E1, 1.93601E2, 2.14E1, 2.08001E2, 6.6E0, 1.96801E2);
        ctx.lineTo((-9.831), 2.06497E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#a5264c';
        ctx.fillStyle = 'rgba(165,38,76,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#a5264c';
        ctx.fillStyle = 'rgba(165,38,76,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-5.4), 2.22801E2);
        ctx.bezierCurveTo((-5.4), 2.22801E2, (-3.4), 2.30001E2, (-5.8), 2.34001E2);
        ctx.bezierCurveTo((-5.8), 2.34001E2, (-7.4), 2.34801E2, (-8.6), 2.35201E2);
        ctx.bezierCurveTo((-8.6), 2.35201E2, (-7.4), 2.38801E2, (-1.4), 2.40401E2);
        ctx.bezierCurveTo((-1.4), 2.40401E2, 6E-1, 2.44801E2, 3E0, 2.45201E2);
        ctx.bezierCurveTo(5.4E0, 2.45601E2, 1.02E1, 2.51201E2, 1.42E1, 2.50001E2);
        ctx.bezierCurveTo(1.82E1, 2.48801E2, 2.94E1, 2.44801E2, 2.94E1, 2.44801E2);
        ctx.bezierCurveTo(2.94E1, 2.44801E2, 3.5E1, 2.41601E2, 4.38E1, 2.45201E2);
        ctx.bezierCurveTo(4.38E1, 2.45201E2, 4.6175E1, 2.44399E2, 4.66E1, 2.40401E2);
        ctx.bezierCurveTo(4.71E1, 2.35701E2, 5.02E1, 2.32001E2, 5.22E1, 2.30001E2);
        ctx.bezierCurveTo(5.42E1, 2.28001E2, 6.38E1, 2.15201E2, 6.26E1, 2.14801E2);
        ctx.bezierCurveTo(6.14E1, 2.14401E2, (-5.4), 2.22801E2, (-5.4), 2.22801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ff727f';
        ctx.fillStyle = 'rgba(255,114,127,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ff727f';
        ctx.fillStyle = 'rgba(255,114,127,1)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-9.8), 1.74401E2);
        ctx.bezierCurveTo((-9.8), 1.74401E2, (-12.6), 1.96801E2, (-9.4), 2.05201E2);
        ctx.bezierCurveTo((-6.2), 2.13601E2, (-7), 2.15601E2, (-7.8), 2.19601E2);
        ctx.bezierCurveTo((-8.6), 2.23601E2, (-4.2), 2.33601E2, 1.4E0, 2.39601E2);
        ctx.lineTo(1.34E1, 2.41201E2);
        ctx.bezierCurveTo(1.34E1, 2.41201E2, 2.86E1, 2.37601E2, 3.78E1, 2.40401E2);
        ctx.bezierCurveTo(3.78E1, 2.40401E2, 4.6794E1, 2.41744E2, 5.02E1, 2.26801E2);
        ctx.bezierCurveTo(5.02E1, 2.26801E2, 5.5E1, 2.20401E2, 6.22E1, 2.17601E2);
        ctx.bezierCurveTo(6.94E1, 2.14801E2, 7.66E1, 1.73201E2, 7.26E1, 1.65201E2);
        ctx.bezierCurveTo(6.86E1, 1.57201E2, 5.42E1, 1.52801E2, 3.82E1, 1.68401E2);
        ctx.bezierCurveTo(2.22E1, 1.84001E2, 2.02E1, 1.67201E2, (-9.8), 1.74401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-8.2), 2.49201E2);
        ctx.bezierCurveTo((-8.2), 2.49201E2, (-9), 2.47201E2, (-13.4), 2.46801E2);
        ctx.bezierCurveTo((-13.4), 2.46801E2, (-35.8), 2.43201E2, (-44.2), 2.30801E2);
        ctx.bezierCurveTo((-44.2), 2.30801E2, (-51), 2.25201E2, (-46.6), 2.36801E2);
        ctx.bezierCurveTo((-46.6), 2.36801E2, (-36.2), 2.57201E2, (-29.4), 2.60001E2);
        ctx.bezierCurveTo((-29.4), 2.60001E2, (-13), 2.64001E2, (-8.2), 2.49201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc3f4c';
        ctx.fillStyle = 'rgba(204,63,76,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc3f4c';
        ctx.fillStyle = 'rgba(204,63,76,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(7.1742E1, 1.85229E2);
        ctx.bezierCurveTo(7.2401E1, 1.77323E2, 7.4354E1, 1.68709E2, 7.26E1, 1.65201E2);
        ctx.bezierCurveTo(6.6154E1, 1.52307E2, 4.9181E1, 1.57695E2, 3.82E1, 1.68401E2);
        ctx.bezierCurveTo(2.22E1, 1.84001E2, 2.02E1, 1.67201E2, (-9.8), 1.74401E2);
        ctx.bezierCurveTo((-9.8), 1.74401E2, (-11.545), 1.88364E2, (-10.705), 1.98376E2);
        ctx.bezierCurveTo((-10.705), 1.98376E2, 2.66E1, 1.86801E2, 2.74E1, 1.92401E2);
        ctx.bezierCurveTo(2.74E1, 1.92401E2, 2.9E1, 1.89201E2, 3.82E1, 1.89201E2);
        ctx.bezierCurveTo(4.74E1, 1.89201E2, 7.0142E1, 1.88029E2, 7.1742E1, 1.85229E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a51926';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a51926';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.86E1, 1.75201E2);
        ctx.bezierCurveTo(2.86E1, 1.75201E2, 3.34E1, 1.80001E2, 2.98E1, 1.89601E2);
        ctx.bezierCurveTo(2.98E1, 1.89601E2, 1.54E1, 2.05601E2, 1.74E1, 2.19601E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-19.4), 2.60001E2);
        ctx.bezierCurveTo((-19.4), 2.60001E2, (-23.8), 2.47201E2, (-15), 2.54001E2);
        ctx.bezierCurveTo((-15), 2.54001E2, (-10.2), 2.56001E2, (-11.4), 2.57601E2);
        ctx.bezierCurveTo((-12.6), 2.59201E2, (-18.2), 2.63201E2, (-19.4), 2.60001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-14.36), 2.61201E2);
        ctx.bezierCurveTo((-14.36), 2.61201E2, (-17.88), 2.50961E2, (-10.84), 2.56401E2);
        ctx.bezierCurveTo((-10.84), 2.56401E2, (-6.419), 2.58849E2, (-7.96), 2.59281E2);
        ctx.bezierCurveTo((-12.52), 2.60561E2, (-7.96), 2.63121E2, (-14.36), 2.61201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-9.56), 2.61201E2);
        ctx.bezierCurveTo((-9.56), 2.61201E2, (-13.08), 2.50961E2, (-6.04), 2.56401E2);
        ctx.bezierCurveTo((-6.04), 2.56401E2, (-1.665), 2.58711E2, (-3.16), 2.59281E2);
        ctx.bezierCurveTo((-6.52), 2.60561E2, (-3.16), 2.63121E2, (-9.56), 2.61201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-2.96), 2.61401E2);
        ctx.bezierCurveTo((-2.96), 2.61401E2, (-6.48), 2.51161E2, 5.6E-1, 2.56601E2);
        ctx.bezierCurveTo(5.6E-1, 2.56601E2, 4.943E0, 2.58933E2, 3.441E0, 2.59481E2);
        ctx.bezierCurveTo(4.8E-1, 2.60561E2, 3.441E0, 2.63321E2, (-2.96), 2.61401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.52E0, 2.61321E2);
        ctx.bezierCurveTo(3.52E0, 2.61321E2, 0E0, 2.51081E2, 7.041E0, 2.56521E2);
        ctx.bezierCurveTo(7.041E0, 2.56521E2, 1.0881E1, 2.58121E2, 9.921E0, 2.59401E2);
        ctx.bezierCurveTo(8.961E0, 2.60681E2, 9.921E0, 2.63241E2, 3.52E0, 2.61321E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.02E1, 2.62001E2);
        ctx.bezierCurveTo(1.02E1, 2.62001E2, 5.4E0, 2.49601E2, 1.46E1, 2.56001E2);
        ctx.bezierCurveTo(1.46E1, 2.56001E2, 1.94E1, 2.58001E2, 1.82E1, 2.59601E2);
        ctx.bezierCurveTo(1.7E1, 2.61201E2, 1.82E1, 2.64401E2, 1.02E1, 2.62001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-18.2), 2.44801E2);
        ctx.bezierCurveTo((-18.2), 2.44801E2, (-5), 2.42001E2, 1E0, 2.45201E2);
        ctx.bezierCurveTo(1E0, 2.45201E2, 7E0, 2.46401E2, 8.2E0, 2.46001E2);
        ctx.bezierCurveTo(9.4E0, 2.45601E2, 1.26E1, 2.45201E2, 1.26E1, 2.45201E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.58E1, 2.53601E2);
        ctx.bezierCurveTo(1.58E1, 2.53601E2, 2.78E1, 2.40001E2, 3.98E1, 2.44401E2);
        ctx.bezierCurveTo(4.6816E1, 2.46974E2, 4.58E1, 2.43601E2, 4.66E1, 2.40801E2);
        ctx.bezierCurveTo(4.74E1, 2.38001E2, 4.76E1, 2.33801E2, 5.26E1, 2.30801E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.3E1, 2.37601E2);
        ctx.bezierCurveTo(3.3E1, 2.37601E2, 2.9E1, 2.26801E2, 2.62E1, 2.39601E2);
        ctx.bezierCurveTo(2.34E1, 2.52401E2, 2.02E1, 2.56001E2, 1.86E1, 2.58801E2);
        ctx.bezierCurveTo(1.86E1, 2.58801E2, 1.86E1, 2.64001E2, 2.7E1, 2.63601E2);
        ctx.bezierCurveTo(2.7E1, 2.63601E2, 3.78E1, 2.63201E2, 3.82E1, 2.60401E2);
        ctx.bezierCurveTo(3.86E1, 2.57601E2, 3.7E1, 2.46001E2, 3.3E1, 2.37601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.7E1, 2.44801E2);
        ctx.bezierCurveTo(4.7E1, 2.44801E2, 5.06E1, 2.42401E2, 5.3E1, 2.43601E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#a5264c';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.35E1, 2.28401E2);
        ctx.bezierCurveTo(5.35E1, 2.28401E2, 5.64E1, 2.23501E2, 6.12E1, 2.22701E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#b2b2b2';
        ctx.fillStyle = 'rgba(178,178,178,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#b2b2b2';
        ctx.fillStyle = 'rgba(178,178,178,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-25.8), 2.65201E2);
        ctx.bezierCurveTo((-25.8), 2.65201E2, (-7.8), 2.68401E2, (-3.4), 2.66801E2);
        ctx.bezierCurveTo((-3.4), 2.66801E2, 5.4E0, 2.66801E2, (-3), 2.68801E2);
        ctx.bezierCurveTo((-3), 2.68801E2, (-15.8), 2.68801E2, (-23.8), 2.67601E2);
        ctx.bezierCurveTo((-23.8), 2.67601E2, (-35.4), 2.62001E2, (-25.8), 2.65201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-11.8), 1.72001E2);
        ctx.bezierCurveTo((-11.8), 1.72001E2, 5.8E0, 1.72001E2, 7.8E0, 1.72801E2);
        ctx.bezierCurveTo(7.8E0, 1.72801E2, 1.5E1, 2.03601E2, 1.14E1, 2.11201E2);
        ctx.bezierCurveTo(1.14E1, 2.11201E2, 1.02E1, 2.14001E2, 7.4E0, 2.08401E2);
        ctx.bezierCurveTo(7.4E0, 2.08401E2, (-11), 1.75601E2, (-14.2), 1.73601E2);
        ctx.bezierCurveTo((-17.4), 1.71601E2, (-13), 1.72001E2, (-11.8), 1.72001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-88.9), 1.69301E2);
        ctx.bezierCurveTo((-88.9), 1.69301E2, (-80), 1.71001E2, (-67.4), 1.73601E2);
        ctx.bezierCurveTo((-67.4), 1.73601E2, (-62.6), 1.96001E2, (-59.4), 2.00801E2);
        ctx.bezierCurveTo((-56.2), 2.05601E2, (-59.8), 2.05601E2, (-63.4), 2.02801E2);
        ctx.bezierCurveTo((-67), 2.00001E2, (-81.8), 1.86001E2, (-83.8), 1.81601E2);
        ctx.bezierCurveTo((-85.8), 1.77201E2, (-88.9), 1.69301E2, (-88.9), 1.69301E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-67.039), 1.73818E2);
        ctx.bezierCurveTo((-67.039), 1.73818E2, (-61.239), 1.75366E2, (-60.23), 1.77581E2);
        ctx.bezierCurveTo((-59.222), 1.79795E2, (-61.432), 1.83092E2, (-61.432), 1.83092E2);
        ctx.bezierCurveTo((-61.432), 1.83092E2, (-62.432), 1.86397E2, (-63.634), 1.84235E2);
        ctx.bezierCurveTo((-64.836), 1.82072E2, (-67.708), 1.74412E2, (-67.039), 1.73818E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-67), 1.73601E2);
        ctx.bezierCurveTo((-67), 1.73601E2, (-63.4), 1.78801E2, (-59.8), 1.78801E2);
        ctx.bezierCurveTo((-56.2), 1.78801E2, (-55.818), 1.78388E2, (-53), 1.79001E2);
        ctx.bezierCurveTo((-48.4), 1.80001E2, (-48.8), 1.78001E2, (-42.2), 1.79201E2);
        ctx.bezierCurveTo((-39.56), 1.79681E2, (-37), 1.78801E2, (-34.2), 1.80001E2);
        ctx.bezierCurveTo((-31.4), 1.81201E2, (-28.2), 1.80401E2, (-27), 1.78401E2);
        ctx.bezierCurveTo((-25.8), 1.76401E2, (-21), 1.72201E2, (-21), 1.72201E2);
        ctx.bezierCurveTo((-21), 1.72201E2, (-33.8), 1.74001E2, (-36.6), 1.74801E2);
        ctx.bezierCurveTo((-36.6), 1.74801E2, (-59), 1.76001E2, (-67), 1.73601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-22.4), 1.73801E2);
        ctx.bezierCurveTo((-22.4), 1.73801E2, (-28.85), 1.77301E2, (-29.25), 1.79701E2);
        ctx.bezierCurveTo((-29.65), 1.82101E2, (-24), 1.85801E2, (-24), 1.85801E2);
        ctx.bezierCurveTo((-24), 1.85801E2, (-21.25), 1.90401E2, (-20.65), 1.88001E2);
        ctx.bezierCurveTo((-20.05), 1.85601E2, (-21.6), 1.74201E2, (-22.4), 1.73801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-59.885), 1.79265E2);
        ctx.bezierCurveTo((-59.885), 1.79265E2, (-52.878), 1.90453E2, (-52.661), 1.79242E2);
        ctx.bezierCurveTo((-52.661), 1.79242E2, (-52.104), 1.77984E2, (-53.864), 1.77962E2);
        ctx.bezierCurveTo((-59.939), 1.77886E2, (-58.418), 1.73784E2, (-59.885), 1.79265E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-52.707), 1.79514E2);
        ctx.bezierCurveTo((-52.707), 1.79514E2, (-44.786), 1.90701E2, (-45.422), 1.79421E2);
        ctx.bezierCurveTo((-45.422), 1.79421E2, (-45.415), 1.79089E2, (-47.168), 1.78936E2);
        ctx.bezierCurveTo((-51.915), 1.78522E2, (-51.57), 1.74004E2, (-52.707), 1.79514E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-45.494), 1.79522E2);
        ctx.bezierCurveTo((-45.494), 1.79522E2, (-37.534), 1.9015E2, (-38.203), 1.80484E2);
        ctx.bezierCurveTo((-38.203), 1.80484E2, (-38.084), 1.79251E2, (-39.738), 1.7895E2);
        ctx.bezierCurveTo((-43.63), 1.78244E2, (-43.841), 1.74995E2, (-45.494), 1.79522E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffcc';
        ctx.fillStyle = 'rgba(255,255,204,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 5E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-38.618), 1.79602E2);
        ctx.bezierCurveTo((-38.618), 1.79602E2, (-30.718), 1.91163E2, (-30.37), 1.81382E2);
        ctx.bezierCurveTo((-30.37), 1.81382E2, (-28.726), 1.80004E2, (-30.472), 1.79782E2);
        ctx.bezierCurveTo((-36.29), 1.79042E2, (-35.492), 1.74588E2, (-38.618), 1.79602E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#e5e5b2';
        ctx.fillStyle = 'rgba(229,229,178,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#e5e5b2';
        ctx.fillStyle = 'rgba(229,229,178,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-74.792), 1.83132E2);
        ctx.lineTo((-82.45), 1.81601E2);
        ctx.bezierCurveTo((-85.05), 1.76601E2, (-87.15), 1.70451E2, (-87.15), 1.70451E2);
        ctx.bezierCurveTo((-87.15), 1.70451E2, (-80.8), 1.71451E2, (-68.3), 1.74251E2);
        ctx.bezierCurveTo((-68.3), 1.74251E2, (-67.424), 1.77569E2, (-65.952), 1.83364E2);
        ctx.lineTo((-74.792), 1.83132E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#e5e5b2';
        ctx.fillStyle = 'rgba(229,229,178,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#e5e5b2';
        ctx.fillStyle = 'rgba(229,229,178,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-9.724), 1.7847E2);
        ctx.bezierCurveTo((-11.39), 1.75964E2, (-12.707), 1.74206E2, (-13.357), 1.738E2);
        ctx.bezierCurveTo((-16.37), 1.71917E2, (-12.227), 1.72294E2, (-11.098), 1.72294E2);
        ctx.bezierCurveTo((-11.098), 1.72294E2, 5.473E0, 1.72294E2, 7.356E0, 1.73047E2);
        ctx.bezierCurveTo(7.356E0, 1.73047E2, 7.88E0, 1.75289E2, 8.564E0, 1.7868E2);
        ctx.bezierCurveTo(8.564E0, 1.7868E2, (-1.524), 1.7667E2, (-9.724), 1.7847E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.388E1, 4.0321E1);
        ctx.bezierCurveTo(7.1601E1, 4.4281E1, 9.7121E1, 8.641E0, 9.8881E1, (-1.04));
        ctx.bezierCurveTo(1.00641E2, (-10.72), 9.0521E1, (-22.6), 9.0521E1, (-22.6));
        ctx.bezierCurveTo(9.1841E1, (-25.68), 8.7001E1, (-39.76), 8.1721E1, (-49));
        ctx.bezierCurveTo(7.6441E1, (-58.24), 6.054E1, (-57.266), 4.3E1, (-58.24));
        ctx.bezierCurveTo(2.716E1, (-59.12), 8.68E0, (-35.8), 7.36E0, (-34.04));
        ctx.bezierCurveTo(6.04E0, (-32.28), 1.22E1, 6.001E0, 1.352E1, 1.1721E1);
        ctx.bezierCurveTo(1.484E1, 1.7441E1, 1.22E1, 4.3841E1, 1.22E1, 4.3841E1);
        ctx.bezierCurveTo(4.644E1, 3.4741E1, 1.616E1, 3.6361E1, 4.388E1, 4.0321E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ea8e51';
        ctx.fillStyle = 'rgba(234,142,81,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ea8e51';
        ctx.fillStyle = 'rgba(234,142,81,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(8.088E0, (-33.392));
        ctx.bezierCurveTo(6.792E0, (-31.664), 1.284E1, 5.921E0, 1.4136E1, 1.1537E1);
        ctx.bezierCurveTo(1.5432E1, 1.7153E1, 1.284E1, 4.3073E1, 1.284E1, 4.3073E1);
        ctx.bezierCurveTo(4.5512E1, 3.4193E1, 1.6728E1, 3.5729E1, 4.3944E1, 3.9617E1);
        ctx.bezierCurveTo(7.1161E1, 4.3505E1, 9.6217E1, 8.513E0, 9.7945E1, (-0.992));
        ctx.bezierCurveTo(9.9673E1, (-10.496), 8.9737E1, (-22.16), 8.9737E1, (-22.16));
        ctx.bezierCurveTo(9.1033E1, (-25.184), 8.6281E1, (-39.008), 8.1097E1, (-48.08));
        ctx.bezierCurveTo(7.5913E1, (-57.152), 6.0302E1, (-56.195), 4.308E1, (-57.152));
        ctx.bezierCurveTo(2.7528E1, (-58.016), 9.384E0, (-35.12), 8.088E0, (-33.392));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#efaa7c';
        ctx.fillStyle = 'rgba(239,170,124,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#efaa7c';
        ctx.fillStyle = 'rgba(239,170,124,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(8.816E0, (-32.744));
        ctx.bezierCurveTo(7.544E0, (-31.048), 1.348E1, 5.841E0, 1.4752E1, 1.1353E1);
        ctx.bezierCurveTo(1.6024E1, 1.6865E1, 1.348E1, 4.2305E1, 1.348E1, 4.2305E1);
        ctx.bezierCurveTo(4.4884E1, 3.3145E1, 1.7296E1, 3.5097E1, 4.4008E1, 3.8913E1);
        ctx.bezierCurveTo(7.0721E1, 4.2729E1, 9.5313E1, 8.385E0, 9.7009E1, (-0.944));
        ctx.bezierCurveTo(9.8705E1, (-10.272), 8.8953E1, (-21.72), 8.8953E1, (-21.72));
        ctx.bezierCurveTo(9.0225E1, (-24.688), 8.5561E1, (-38.256), 8.0473E1, (-47.16));
        ctx.bezierCurveTo(7.5385E1, (-56.064), 6.0063E1, (-55.125), 4.316E1, (-56.064));
        ctx.bezierCurveTo(2.7896E1, (-56.912), 1.0088E1, (-34.44), 8.816E0, (-32.744));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f4c6a8';
        ctx.fillStyle = 'rgba(244,198,168,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f4c6a8';
        ctx.fillStyle = 'rgba(244,198,168,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.544E0, (-32.096));
        ctx.bezierCurveTo(8.296E0, (-30.432), 1.412E1, 5.761E0, 1.5368E1, 1.1169E1);
        ctx.bezierCurveTo(1.6616E1, 1.6577E1, 1.412E1, 4.1537E1, 1.412E1, 4.1537E1);
        ctx.bezierCurveTo(4.3556E1, 3.2497E1, 1.7864E1, 3.4465E1, 4.4072E1, 3.8209E1);
        ctx.bezierCurveTo(7.0281E1, 4.1953E1, 9.4409E1, 8.257E0, 9.6073E1, (-0.895));
        ctx.bezierCurveTo(9.7737E1, (-10.048), 8.8169E1, (-21.28), 8.8169E1, (-21.28));
        ctx.bezierCurveTo(8.9417E1, (-24.192), 8.4841E1, (-37.504), 7.9849E1, (-46.24));
        ctx.bezierCurveTo(7.4857E1, (-54.976), 5.9824E1, (-54.055), 4.324E1, (-54.976));
        ctx.bezierCurveTo(2.8264E1, (-55.808), 1.0792E1, (-33.76), 9.544E0, (-32.096));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f9e2d3';
        ctx.fillStyle = 'rgba(249,226,211,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f9e2d3';
        ctx.fillStyle = 'rgba(249,226,211,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.0272E1, (-31.448));
        ctx.bezierCurveTo(9.048E0, (-29.816), 1.476E1, 5.681E0, 1.5984E1, 1.0985E1);
        ctx.bezierCurveTo(1.7208E1, 1.6289E1, 1.476E1, 4.0769E1, 1.476E1, 4.0769E1);
        ctx.bezierCurveTo(4.2628E1, 3.1849E1, 1.8432E1, 3.3833E1, 4.4136E1, 3.7505E1);
        ctx.bezierCurveTo(6.9841E1, 4.1177E1, 9.3505E1, 8.129E0, 9.5137E1, (-0.848));
        ctx.bezierCurveTo(9.6769E1, (-9.824), 8.7385E1, (-20.84), 8.7385E1, (-20.84));
        ctx.bezierCurveTo(8.8609E1, (-23.696), 8.4121E1, (-36.752), 7.9225E1, (-45.32));
        ctx.bezierCurveTo(7.4329E1, (-53.888), 5.9585E1, (-52.985), 4.332E1, (-53.888));
        ctx.bezierCurveTo(2.8632E1, (-54.704), 1.1496E1, (-33.08), 1.0272E1, (-31.448));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.42E1, 3.68E1);
        ctx.bezierCurveTo(6.94E1, 4.04E1, 9.2601E1, 8E0, 9.4201E1, (-0.8));
        ctx.bezierCurveTo(9.5801E1, (-9.6), 8.6601E1, (-20.4), 8.6601E1, (-20.4));
        ctx.bezierCurveTo(8.7801E1, (-23.2), 8.34E1, (-36), 7.86E1, (-44.4));
        ctx.bezierCurveTo(7.38E1, (-52.8), 5.9346E1, (-51.914), 4.34E1, (-52.8));
        ctx.bezierCurveTo(2.9E1, (-53.6), 1.22E1, (-32.4), 1.1E1, (-30.8));
        ctx.bezierCurveTo(9.8E0, (-29.2), 1.54E1, 5.6E0, 1.66E1, 1.08E1);
        ctx.bezierCurveTo(1.78E1, 1.6E1, 1.54E1, 4E1, 1.54E1, 4E1);
        ctx.bezierCurveTo(4.09E1, 3.14E1, 1.9E1, 3.32E1, 4.42E1, 3.68E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.0601E1, 2.8E0);
        ctx.bezierCurveTo(9.0601E1, 2.8E0, 6.28E1, 1.04E1, 5.12E1, 8.8E0);
        ctx.bezierCurveTo(5.12E1, 8.8E0, 3.54E1, 2.2E0, 2.66E1, 2.4E1);
        ctx.bezierCurveTo(2.66E1, 2.4E1, 2.3E1, 3.12E1, 2.1E1, 3.32E1);
        ctx.bezierCurveTo(1.9E1, 3.52E1, 9.0601E1, 2.8E0, 9.0601E1, 2.8E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.4401E1, 6E-1);
        ctx.bezierCurveTo(9.4401E1, 6E-1, 6.54E1, 1.28E1, 5.54E1, 1.24E1);
        ctx.bezierCurveTo(5.54E1, 1.24E1, 3.9E1, 7.8E0, 3.06E1, 2.24E1);
        ctx.bezierCurveTo(3.06E1, 2.24E1, 2.22E1, 3.16E1, 1.9E1, 3.32E1);
        ctx.bezierCurveTo(1.9E1, 3.32E1, 1.86E1, 3.48E1, 2.5E1, 3.08E1);
        ctx.lineTo(3.54E1, 3.6E1);
        ctx.bezierCurveTo(3.54E1, 3.6E1, 5.02E1, 4.56E1, 5.98E1, 2.96E1);
        ctx.bezierCurveTo(5.98E1, 2.96E1, 6.38E1, 1.84E1, 6.38E1, 1.64E1);
        ctx.bezierCurveTo(6.38E1, 1.44E1, 8.5E1, 8.8E0, 8.6601E1, 8.4E0);
        ctx.bezierCurveTo(8.8201E1, 8E0, 9.4801E1, 3.8E0, 9.4401E1, 6E-1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.7E1, 3.6514E1);
        ctx.bezierCurveTo(4.0128E1, 3.6514E1, 3.1755E1, 3.2649E1, 3.1755E1, 2.64E1);
        ctx.bezierCurveTo(3.1755E1, 2.0152E1, 4.0128E1, 1.3887E1, 4.7E1, 1.3887E1);
        ctx.bezierCurveTo(5.3874E1, 1.3887E1, 5.9446E1, 1.8952E1, 5.9446E1, 2.52E1);
        ctx.bezierCurveTo(5.9446E1, 3.1449E1, 5.3874E1, 3.6514E1, 4.7E1, 3.6514E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#659900';
        ctx.fillStyle = 'rgba(101,153,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#659900';
        ctx.fillStyle = 'rgba(101,153,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.3377E1, 1.983E1);
        ctx.bezierCurveTo(3.8531E1, 2.0552E1, 3.3442E1, 2.2055E1, 3.3514E1, 2.1839E1);
        ctx.bezierCurveTo(3.5054E1, 1.722E1, 4.1415E1, 1.3887E1, 4.7E1, 1.3887E1);
        ctx.bezierCurveTo(5.1296E1, 1.3887E1, 5.5084E1, 1.5865E1, 5.732E1, 1.8875E1);
        ctx.bezierCurveTo(5.732E1, 1.8875E1, 5.2004E1, 1.8545E1, 4.3377E1, 1.983E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.54E1, 1.96E1);
        ctx.bezierCurveTo(5.54E1, 1.96E1, 5.1E1, 1.64E1, 5.1E1, 1.86E1);
        ctx.bezierCurveTo(5.1E1, 1.86E1, 5.46E1, 2.3E1, 5.54E1, 1.96E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.54E1, 2.7726E1);
        ctx.bezierCurveTo(4.2901E1, 2.7726E1, 4.0875E1, 2.57E1, 4.0875E1, 2.32E1);
        ctx.bezierCurveTo(4.0875E1, 2.0701E1, 4.2901E1, 1.8675E1, 4.54E1, 1.8675E1);
        ctx.bezierCurveTo(4.79E1, 1.8675E1, 4.9926E1, 2.0701E1, 4.9926E1, 2.32E1);
        ctx.bezierCurveTo(4.9926E1, 2.57E1, 4.79E1, 2.7726E1, 4.54E1, 2.7726E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-58.6), 1.44E1);
        ctx.bezierCurveTo((-58.6), 1.44E1, (-61.8), (-6.8), (-59.4), (-11.2));
        ctx.bezierCurveTo((-59.4), (-11.2), (-48.6), (-21.2), (-49), (-24.8));
        ctx.bezierCurveTo((-49), (-24.8), (-49.4), (-42.8), (-50.6), (-43.6));
        ctx.bezierCurveTo((-51.8), (-44.4), (-59.4), (-50.4), (-65.4), (-44));
        ctx.bezierCurveTo((-65.4), (-44), (-75.8), (-26), (-75), (-19.6));
        ctx.lineTo((-75), (-17.6));
        ctx.bezierCurveTo((-75), (-17.6), (-82.6), (-18), (-84.2), (-16));
        ctx.bezierCurveTo((-84.2), (-16), (-85.4), (-10.8), (-86.6), (-10.4));
        ctx.bezierCurveTo((-86.6), (-10.4), (-89.4), (-8), (-87.4), (-5.2));
        ctx.bezierCurveTo((-87.4), (-5.2), (-89.4), (-2.8), (-89), 1.2E0);
        ctx.lineTo((-81.4), 5.2E0);
        ctx.bezierCurveTo((-81.4), 5.2E0, (-79.4), 1.96E1, (-68.6), 2.48E1);
        ctx.bezierCurveTo((-63.764), 2.7129E1, (-60.6), 2.04E1, (-58.6), 1.44E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-59.6), 1.256E1);
        ctx.bezierCurveTo((-59.6), 1.256E1, (-62.48), (-6.52), (-60.32), (-10.48));
        ctx.bezierCurveTo((-60.32), (-10.48), (-50.6), (-19.48), (-50.96), (-22.72));
        ctx.bezierCurveTo((-50.96), (-22.72), (-51.32), (-38.92), (-52.4), (-39.64));
        ctx.bezierCurveTo((-53.48), (-40.36), (-60.32), (-45.76), (-65.72), (-40));
        ctx.bezierCurveTo((-65.72), (-40), (-75.08), (-23.8), (-74.36), (-18.04));
        ctx.lineTo((-74.36), (-16.24));
        ctx.bezierCurveTo((-74.36), (-16.24), (-81.2), (-16.6), (-82.64), (-14.8));
        ctx.bezierCurveTo((-82.64), (-14.8), (-83.72), (-10.12), (-84.8), (-9.76));
        ctx.bezierCurveTo((-84.8), (-9.76), (-87.32), (-7.6), (-85.52), (-5.08));
        ctx.bezierCurveTo((-85.52), (-5.08), (-87.32), (-2.92), (-86.96), 6.8E-1);
        ctx.lineTo((-80.12), 4.28E0);
        ctx.bezierCurveTo((-80.12), 4.28E0, (-78.32), 1.724E1, (-68.6), 2.192E1);
        ctx.bezierCurveTo((-64.248), 2.4015E1, (-61.4), 1.796E1, (-59.6), 1.256E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#eb955c';
        ctx.fillStyle = 'rgba(235,149,92,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#eb955c';
        ctx.fillStyle = 'rgba(235,149,92,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-51.05), (-42.61));
        ctx.bezierCurveTo((-52.14), (-43.47), (-59.63), (-49.24), (-65.48), (-43));
        ctx.bezierCurveTo((-65.48), (-43), (-75.62), (-25.45), (-74.84), (-19.21));
        ctx.lineTo((-74.84), (-17.26));
        ctx.bezierCurveTo((-74.84), (-17.26), (-82.25), (-17.65), (-83.81), (-15.7));
        ctx.bezierCurveTo((-83.81), (-15.7), (-84.98), (-10.63), (-86.15), (-10.24));
        ctx.bezierCurveTo((-86.15), (-10.24), (-88.88), (-7.9), (-86.93), (-5.17));
        ctx.bezierCurveTo((-86.93), (-5.17), (-88.88), (-2.83), (-88.49), 1.07E0);
        ctx.lineTo((-81.08), 4.97E0);
        ctx.bezierCurveTo((-81.08), 4.97E0, (-79.13), 1.901E1, (-68.6), 2.408E1);
        ctx.bezierCurveTo((-63.886), 2.635E1, (-60.8), 1.979E1, (-58.85), 1.394E1);
        ctx.bezierCurveTo((-58.85), 1.394E1, (-61.97), (-6.73), (-59.63), (-11.02));
        ctx.bezierCurveTo((-59.63), (-11.02), (-49.1), (-20.77), (-49.49), (-24.28));
        ctx.bezierCurveTo((-49.49), (-24.28), (-49.88), (-41.83), (-51.05), (-42.61));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f2b892';
        ctx.fillStyle = 'rgba(242,184,146,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f2b892';
        ctx.fillStyle = 'rgba(242,184,146,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-51.5), (-41.62));
        ctx.bezierCurveTo((-52.48), (-42.54), (-59.86), (-48.08), (-65.56), (-42));
        ctx.bezierCurveTo((-65.56), (-42), (-75.44), (-24.9), (-74.68), (-18.82));
        ctx.lineTo((-74.68), (-16.92));
        ctx.bezierCurveTo((-74.68), (-16.92), (-81.9), (-17.3), (-83.42), (-15.4));
        ctx.bezierCurveTo((-83.42), (-15.4), (-84.56), (-10.46), (-85.7), (-10.08));
        ctx.bezierCurveTo((-85.7), (-10.08), (-88.36), (-7.8), (-86.46), (-5.14));
        ctx.bezierCurveTo((-86.46), (-5.14), (-88.36), (-2.86), (-87.98), 9.4E-1);
        ctx.lineTo((-80.76), 4.74E0);
        ctx.bezierCurveTo((-80.76), 4.74E0, (-78.86), 1.842E1, (-68.6), 2.336E1);
        ctx.bezierCurveTo((-64.006), 2.5572E1, (-61), 1.918E1, (-59.1), 1.348E1);
        ctx.bezierCurveTo((-59.1), 1.348E1, (-62.14), (-6.66), (-59.86), (-10.84));
        ctx.bezierCurveTo((-59.86), (-10.84), (-49.6), (-20.34), (-49.98), (-23.76));
        ctx.bezierCurveTo((-49.98), (-23.76), (-50.36), (-40.86), (-51.5), (-41.62));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#f8dcc8';
        ctx.fillStyle = 'rgba(248,220,200,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#f8dcc8';
        ctx.fillStyle = 'rgba(248,220,200,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-51.95), (-40.63));
        ctx.bezierCurveTo((-52.82), (-41.61), (-60.09), (-46.92), (-65.64), (-41));
        ctx.bezierCurveTo((-65.64), (-41), (-75.26), (-24.35), (-74.52), (-18.43));
        ctx.lineTo((-74.52), (-16.58));
        ctx.bezierCurveTo((-74.52), (-16.58), (-81.55), (-16.95), (-83.03), (-15.1));
        ctx.bezierCurveTo((-83.03), (-15.1), (-84.14), (-10.29), (-85.25), (-9.92));
        ctx.bezierCurveTo((-85.25), (-9.92), (-87.84), (-7.7), (-85.99), (-5.11));
        ctx.bezierCurveTo((-85.99), (-5.11), (-87.84), (-2.89), (-87.47), 8.1E-1);
        ctx.lineTo((-80.44), 4.51E0);
        ctx.bezierCurveTo((-80.44), 4.51E0, (-78.59), 1.783E1, (-68.6), 2.264E1);
        ctx.bezierCurveTo((-64.127), 2.4794E1, (-61.2), 1.857E1, (-59.35), 1.302E1);
        ctx.bezierCurveTo((-59.35), 1.302E1, (-62.31), (-6.59), (-60.09), (-10.66));
        ctx.bezierCurveTo((-60.09), (-10.66), (-50.1), (-19.91), (-50.47), (-23.24));
        ctx.bezierCurveTo((-50.47), (-23.24), (-50.84), (-39.89), (-51.95), (-40.63));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-59.6), 1.246E1);
        ctx.bezierCurveTo((-59.6), 1.246E1, (-62.48), (-6.52), (-60.32), (-10.48));
        ctx.bezierCurveTo((-60.32), (-10.48), (-50.6), (-19.48), (-50.96), (-22.72));
        ctx.bezierCurveTo((-50.96), (-22.72), (-51.32), (-38.92), (-52.4), (-39.64));
        ctx.bezierCurveTo((-53.16), (-40.68), (-60.32), (-45.76), (-65.72), (-40));
        ctx.bezierCurveTo((-65.72), (-40), (-75.08), (-23.8), (-74.36), (-18.04));
        ctx.lineTo((-74.36), (-16.24));
        ctx.bezierCurveTo((-74.36), (-16.24), (-81.2), (-16.6), (-82.64), (-14.8));
        ctx.bezierCurveTo((-82.64), (-14.8), (-83.72), (-10.12), (-84.8), (-9.76));
        ctx.bezierCurveTo((-84.8), (-9.76), (-87.32), (-7.6), (-85.52), (-5.08));
        ctx.bezierCurveTo((-85.52), (-5.08), (-87.32), (-2.92), (-86.96), 6.8E-1);
        ctx.lineTo((-80.12), 4.28E0);
        ctx.bezierCurveTo((-80.12), 4.28E0, (-78.32), 1.724E1, (-68.6), 2.192E1);
        ctx.bezierCurveTo((-64.248), 2.4015E1, (-61.4), 1.786E1, (-59.6), 1.246E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-62.7), 6.2E0);
        ctx.bezierCurveTo((-62.7), 6.2E0, (-84.3), (-4), (-85.2), (-4.8));
        ctx.bezierCurveTo((-85.2), (-4.8), (-76.1), 3.4E0, (-75.3), 3.4E0);
        ctx.bezierCurveTo((-74.5), 3.4E0, (-62.7), 6.2E0, (-62.7), 6.2E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-79.8), 0E0);
        ctx.bezierCurveTo((-79.8), 0E0, (-61.4), 3.6E0, (-61.4), 8E0);
        ctx.bezierCurveTo((-61.4), 1.0912E1, (-61.643), 2.4331E1, (-67), 2.28E1);
        ctx.bezierCurveTo((-75.4), 2.04E1, (-71.8), 6E0, (-79.8), 0E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-71.4), 3.8E0);
        ctx.bezierCurveTo((-71.4), 3.8E0, (-62.422), 5.274E0, (-61.4), 8E0);
        ctx.bezierCurveTo((-60.8), 9.6E0, (-60.137), 1.7908E1, (-65.6), 1.9E1);
        ctx.bezierCurveTo((-70.152), 1.9911E1, (-72.382), 9.69E0, (-71.4), 3.8E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.4595E1, 4.6349E1);
        ctx.bezierCurveTo(1.4098E1, 4.4607E1, 1.5409E1, 4.4738E1, 1.72E1, 4.42E1);
        ctx.bezierCurveTo(1.92E1, 4.36E1, 3.14E1, 3.98E1, 3.22E1, 3.72E1);
        ctx.bezierCurveTo(3.3E1, 3.46E1, 4.62E1, 3.9E1, 4.62E1, 3.9E1);
        ctx.bezierCurveTo(4.8E1, 3.98E1, 5.24E1, 4.24E1, 5.24E1, 4.24E1);
        ctx.bezierCurveTo(5.72E1, 4.36E1, 6.38E1, 4.4E1, 6.38E1, 4.4E1);
        ctx.bezierCurveTo(6.62E1, 4.5E1, 6.96E1, 4.78E1, 6.96E1, 4.78E1);
        ctx.bezierCurveTo(8.42E1, 5.8E1, 9.6601E1, 5.08E1, 9.6601E1, 5.08E1);
        ctx.bezierCurveTo(1.16601E2, 4.42E1, 1.10601E2, 2.7E1, 1.10601E2, 2.7E1);
        ctx.bezierCurveTo(1.07601E2, 1.8E1, 1.10801E2, 1.46E1, 1.10801E2, 1.46E1);
        ctx.bezierCurveTo(1.11001E2, 1.08E1, 1.18201E2, 1.72E1, 1.18201E2, 1.72E1);
        ctx.bezierCurveTo(1.20801E2, 2.14E1, 1.21601E2, 2.64E1, 1.21601E2, 2.64E1);
        ctx.bezierCurveTo(1.29601E2, 3.76E1, 1.26201E2, 1.98E1, 1.26201E2, 1.98E1);
        ctx.bezierCurveTo(1.26401E2, 1.88E1, 1.23601E2, 1.52E1, 1.23601E2, 1.4E1);
        ctx.bezierCurveTo(1.23601E2, 1.28E1, 1.21801E2, 9.4E0, 1.21801E2, 9.4E0);
        ctx.bezierCurveTo(1.18801E2, 6E0, 1.21201E2, (-1), 1.21201E2, (-1));
        ctx.bezierCurveTo(1.23001E2, (-14.8), 1.20801E2, (-13), 1.20801E2, (-13));
        ctx.bezierCurveTo(1.19601E2, (-14.8), 1.10401E2, (-4.8), 1.10401E2, (-4.8));
        ctx.bezierCurveTo(1.08201E2, (-1.4), 1.02201E2, 2E-1, 1.02201E2, 2E-1);
        ctx.bezierCurveTo(9.9401E1, 2E0, 9.6001E1, 6E-1, 9.6001E1, 6E-1);
        ctx.bezierCurveTo(9.3401E1, 2E-1, 8.7801E1, 7.2E0, 8.7801E1, 7.2E0);
        ctx.bezierCurveTo(9.0601E1, 7E0, 9.3001E1, 1.14E1, 9.5401E1, 1.16E1);
        ctx.bezierCurveTo(9.7801E1, 1.18E1, 9.9601E1, 9.2E0, 1.01201E2, 8.6E0);
        ctx.bezierCurveTo(1.02801E2, 8E0, 1.05601E2, 1.38E1, 1.05601E2, 1.38E1);
        ctx.bezierCurveTo(1.06001E2, 1.64E1, 1.00401E2, 2.12E1, 1.00401E2, 2.12E1);
        ctx.bezierCurveTo(1.00001E2, 2.58E1, 9.8401E1, 2.42E1, 9.8401E1, 2.42E1);
        ctx.bezierCurveTo(9.5401E1, 2.36E1, 9.4201E1, 2.74E1, 9.3201E1, 3.2E1);
        ctx.bezierCurveTo(9.2201E1, 3.66E1, 8.8001E1, 3.7E1, 8.8001E1, 3.7E1);
        ctx.bezierCurveTo(8.6401E1, 4.44E1, 8.52E1, 4.14E1, 8.52E1, 4.14E1);
        ctx.bezierCurveTo(8.5E1, 3.58E1, 7.9E1, 4.16E1, 7.9E1, 4.16E1);
        ctx.bezierCurveTo(7.78E1, 4.36E1, 7.32E1, 4.14E1, 7.32E1, 4.14E1);
        ctx.bezierCurveTo(6.64E1, 3.94E1, 6.88E1, 3.74E1, 6.88E1, 3.74E1);
        ctx.bezierCurveTo(7.06E1, 3.52E1, 8.18E1, 3.74E1, 8.18E1, 3.74E1);
        ctx.bezierCurveTo(8.4E1, 3.58E1, 7.6E1, 3.18E1, 7.6E1, 3.18E1);
        ctx.bezierCurveTo(7.54E1, 3E1, 7.64E1, 2.56E1, 7.64E1, 2.56E1);
        ctx.bezierCurveTo(7.76E1, 2.24E1, 8.44E1, 1.68E1, 8.44E1, 1.68E1);
        ctx.bezierCurveTo(9.3801E1, 1.56E1, 9.1001E1, 1.4E1, 9.1001E1, 1.4E1);
        ctx.bezierCurveTo(8.4801E1, 8.8E0, 7.9E1, 1.64E1, 7.9E1, 1.64E1);
        ctx.bezierCurveTo(7.68E1, 2.26E1, 5.94E1, 3.76E1, 5.94E1, 3.76E1);
        ctx.bezierCurveTo(5.46E1, 4.1E1, 5.72E1, 3.42E1, 5.32E1, 3.76E1);
        ctx.bezierCurveTo(4.92E1, 4.1E1, 2.86E1, 3.2E1, 2.86E1, 3.2E1);
        ctx.bezierCurveTo(1.7038E1, 3.0807E1, 1.4306E1, 4.6549E1, 1.0777E1, 4.3429E1);
        ctx.bezierCurveTo(1.0777E1, 4.3429E1, 1.6195E1, 5.1949E1, 1.4595E1, 4.6349E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.09401E2, (-120));
        ctx.bezierCurveTo(2.09401E2, (-120), 1.83801E2, (-112), 1.81001E2, (-93.2));
        ctx.bezierCurveTo(1.81001E2, (-93.2), 1.78601E2, (-70.4), 1.99001E2, (-52.8));
        ctx.bezierCurveTo(1.99001E2, (-52.8), 1.99401E2, (-46.4), 2.01401E2, (-43.2));
        ctx.bezierCurveTo(2.01401E2, (-43.2), 1.99801E2, (-38.4), 2.18601E2, (-46));
        ctx.lineTo(2.45801E2, (-54.4));
        ctx.bezierCurveTo(2.45801E2, (-54.4), 2.52201E2, (-56.8), 2.57401E2, (-65.6));
        ctx.bezierCurveTo(2.62601E2, (-74.4), 2.77801E2, (-93.2), 2.74201E2, (-118.4));
        ctx.bezierCurveTo(2.74201E2, (-118.4), 2.75401E2, (-129.6), 2.69401E2, (-130));
        ctx.bezierCurveTo(2.69401E2, (-130), 2.61001E2, (-131.6), 2.53801E2, (-124));
        ctx.bezierCurveTo(2.53801E2, (-124), 2.47001E2, (-120.8), 2.44601E2, (-121.2));
        ctx.lineTo(2.09401E2, (-120));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.64022E2, (-120.99));
        ctx.bezierCurveTo(2.64022E2, (-120.99), 2.66122E2, (-129.92), 2.61282E2, (-125.08));
        ctx.bezierCurveTo(2.61282E2, (-125.08), 2.54242E2, (-119.36), 2.46761E2, (-119.36));
        ctx.bezierCurveTo(2.46761E2, (-119.36), 2.32241E2, (-117.16), 2.27841E2, (-103.96));
        ctx.bezierCurveTo(2.27841E2, (-103.96), 2.23881E2, (-77.12), 2.31801E2, (-71.4));
        ctx.bezierCurveTo(2.31801E2, (-71.4), 2.36641E2, (-63.92), 2.43681E2, (-70.52));
        ctx.bezierCurveTo(2.50722E2, (-77.12), 2.66222E2, (-107.35), 2.64022E2, (-120.99));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#323232';
        ctx.fillStyle = 'rgba(50,50,50,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#323232';
        ctx.fillStyle = 'rgba(50,50,50,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.63648E2, (-120.632));
        ctx.bezierCurveTo(2.63648E2, (-120.632), 2.65738E2, (-129.376), 2.60986E2, (-124.624));
        ctx.bezierCurveTo(2.60986E2, (-124.624), 2.54074E2, (-119.008), 2.46729E2, (-119.008));
        ctx.bezierCurveTo(2.46729E2, (-119.008), 2.32473E2, (-116.848), 2.28153E2, (-103.888));
        ctx.bezierCurveTo(2.28153E2, (-103.888), 2.24265E2, (-77.536), 2.32041E2, (-71.92));
        ctx.bezierCurveTo(2.32041E2, (-71.92), 2.36793E2, (-64.576), 2.43705E2, (-71.056));
        ctx.bezierCurveTo(2.50618E2, (-77.536), 2.65808E2, (-107.24), 2.63648E2, (-120.632));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#666666';
        ctx.fillStyle = 'rgba(102,102,102,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#666666';
        ctx.fillStyle = 'rgba(102,102,102,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.63274E2, (-120.274));
        ctx.bezierCurveTo(2.63274E2, (-120.274), 2.65354E2, (-128.832), 2.6069E2, (-124.168));
        ctx.bezierCurveTo(2.6069E2, (-124.168), 2.53906E2, (-118.656), 2.46697E2, (-118.656));
        ctx.bezierCurveTo(2.46697E2, (-118.656), 2.32705E2, (-116.536), 2.28465E2, (-103.816));
        ctx.bezierCurveTo(2.28465E2, (-103.816), 2.24649E2, (-77.952), 2.32281E2, (-72.44));
        ctx.bezierCurveTo(2.32281E2, (-72.44), 2.36945E2, (-65.232), 2.43729E2, (-71.592));
        ctx.bezierCurveTo(2.50514E2, (-77.952), 2.65394E2, (-107.13), 2.63274E2, (-120.274));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#999999';
        ctx.fillStyle = 'rgba(153,153,153,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#999999';
        ctx.fillStyle = 'rgba(153,153,153,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.629E2, (-119.916));
        ctx.bezierCurveTo(2.629E2, (-119.916), 2.6497E2, (-128.288), 2.60394E2, (-123.712));
        ctx.bezierCurveTo(2.60394E2, (-123.712), 2.53738E2, (-118.304), 2.46665E2, (-118.304));
        ctx.bezierCurveTo(2.46665E2, (-118.304), 2.32937E2, (-116.224), 2.28777E2, (-103.744));
        ctx.bezierCurveTo(2.28777E2, (-103.744), 2.25033E2, (-78.368), 2.32521E2, (-72.96));
        ctx.bezierCurveTo(2.32521E2, (-72.96), 2.37097E2, (-65.888), 2.43753E2, (-72.128));
        ctx.bezierCurveTo(2.5041E2, (-78.368), 2.6498E2, (-107.02), 2.629E2, (-119.916));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.62526E2, (-119.558));
        ctx.bezierCurveTo(2.62526E2, (-119.558), 2.64586E2, (-127.744), 2.60098E2, (-123.256));
        ctx.bezierCurveTo(2.60098E2, (-123.256), 2.53569E2, (-117.952), 2.46633E2, (-117.952));
        ctx.bezierCurveTo(2.46633E2, (-117.952), 2.33169E2, (-115.912), 2.29089E2, (-103.672));
        ctx.bezierCurveTo(2.29089E2, (-103.672), 2.25417E2, (-78.784), 2.32761E2, (-73.48));
        ctx.bezierCurveTo(2.32761E2, (-73.48), 2.37249E2, (-66.544), 2.43777E2, (-72.664));
        ctx.bezierCurveTo(2.50305E2, (-78.784), 2.64566E2, (-106.91), 2.62526E2, (-119.558));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.62151E2, (-119.2));
        ctx.bezierCurveTo(2.62151E2, (-119.2), 2.64201E2, (-127.2), 2.59801E2, (-122.8));
        ctx.bezierCurveTo(2.59801E2, (-122.8), 2.53401E2, (-117.6), 2.46601E2, (-117.6));
        ctx.bezierCurveTo(2.46601E2, (-117.6), 2.33401E2, (-115.6), 2.29401E2, (-103.6));
        ctx.bezierCurveTo(2.29401E2, (-103.6), 2.25801E2, (-79.2), 2.33001E2, (-74));
        ctx.bezierCurveTo(2.33001E2, (-74), 2.37401E2, (-67.2), 2.43801E2, (-73.2));
        ctx.bezierCurveTo(2.50201E2, (-79.2), 2.64151E2, (-106.8), 2.62151E2, (-119.2));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.06E1, 8.4E1);
        ctx.bezierCurveTo(5.06E1, 8.4E1, 3.02E1, 6.48E1, 2.22E1, 6.4E1);
        ctx.bezierCurveTo(2.22E1, 6.4E1, (-12.2), 6E1, (-27), 7.8E1);
        ctx.bezierCurveTo((-27), 7.8E1, (-9.4), 5.76E1, 1.82E1, 6.32E1);
        ctx.bezierCurveTo(1.82E1, 6.32E1, (-3.4), 5.88E1, (-15.8), 6.2E1);
        ctx.bezierCurveTo((-15.8), 6.2E1, (-32.6), 6.2E1, (-42.2), 7.6E1);
        ctx.lineTo((-45), 8.08E1);
        ctx.bezierCurveTo((-45), 8.08E1, (-41), 6.6E1, (-22.6), 6E1);
        ctx.bezierCurveTo((-22.6), 6E1, 2E-1, 5.52E1, 1.1E1, 6E1);
        ctx.bezierCurveTo(1.1E1, 6E1, (-10.6), 5.32E1, (-20.6), 5.52E1);
        ctx.bezierCurveTo((-20.6), 5.52E1, (-51), 5.28E1, (-63.8), 7.92E1);
        ctx.bezierCurveTo((-63.8), 7.92E1, (-59.8), 6.48E1, (-45), 5.76E1);
        ctx.bezierCurveTo((-45), 5.76E1, (-31.4), 4.88E1, (-11), 5.16E1);
        ctx.bezierCurveTo((-11), 5.16E1, 3.4E0, 5.48E1, 8.6E0, 5.72E1);
        ctx.bezierCurveTo(1.38E1, 5.96E1, 1.26E1, 5.68E1, 4.2E0, 5.2E1);
        ctx.bezierCurveTo(4.2E0, 5.2E1, (-1.4), 4.2E1, (-15.4), 4.24E1);
        ctx.bezierCurveTo((-15.4), 4.24E1, (-58.2), 4.6E1, (-68.6), 5.8E1);
        ctx.bezierCurveTo((-68.6), 5.8E1, (-55), 4.68E1, (-44.6), 4.4E1);
        ctx.bezierCurveTo((-44.6), 4.4E1, (-22.2), 3.6E1, (-13.8), 3.68E1);
        ctx.bezierCurveTo((-13.8), 3.68E1, 1.1E1, 3.78E1, 1.86E1, 3.38E1);
        ctx.bezierCurveTo(1.86E1, 3.38E1, 7.4E0, 3.88E1, 1.06E1, 4.2E1);
        ctx.bezierCurveTo(1.38E1, 4.52E1, 2.06E1, 5.28E1, 2.06E1, 5.4E1);
        ctx.bezierCurveTo(2.06E1, 5.52E1, 4.48E1, 7.73E1, 4.84E1, 8.17E1);
        ctx.lineTo(5.06E1, 8.4E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.89E2, 2.78E2);
        ctx.bezierCurveTo(1.89E2, 2.78E2, 1.735E2, 2.415E2, 1.61E2, 2.32E2);
        ctx.bezierCurveTo(1.61E2, 2.32E2, 1.87E2, 2.48E2, 1.905E2, 2.66E2);
        ctx.bezierCurveTo(1.905E2, 2.66E2, 1.905E2, 2.76E2, 1.89E2, 2.78E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.36E2, 2.855E2);
        ctx.bezierCurveTo(2.36E2, 2.855E2, 2.095E2, 2.305E2, 1.91E2, 2.065E2);
        ctx.bezierCurveTo(1.91E2, 2.065E2, 2.345E2, 2.44E2, 2.395E2, 2.705E2);
        ctx.lineTo(2.4E2, 2.76E2);
        ctx.lineTo(2.37E2, 2.735E2);
        ctx.bezierCurveTo(2.37E2, 2.735E2, 2.365E2, 2.825E2, 2.36E2, 2.855E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.925E2, 2.37E2);
        ctx.bezierCurveTo(2.925E2, 2.37E2, 2.3E2, 1.775E2, 2.285E2, 1.75E2);
        ctx.bezierCurveTo(2.285E2, 1.75E2, 2.89E2, 2.41E2, 2.92E2, 2.485E2);
        ctx.bezierCurveTo(2.92E2, 2.485E2, 2.9E2, 2.395E2, 2.925E2, 2.37E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.04E2, 2.805E2);
        ctx.bezierCurveTo(1.04E2, 2.805E2, 1.235E2, 2.285E2, 1.425E2, 2.51E2);
        ctx.bezierCurveTo(1.425E2, 2.51E2, 1.575E2, 2.61E2, 1.57E2, 2.64E2);
        ctx.bezierCurveTo(1.57E2, 2.64E2, 1.53E2, 2.575E2, 1.35E2, 2.58E2);
        ctx.bezierCurveTo(1.35E2, 2.58E2, 1.16E2, 2.55E2, 1.04E2, 2.805E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.945E2, 1.53E2);
        ctx.bezierCurveTo(2.945E2, 1.53E2, 2.495E2, 1.245E2, 2.42E2, 1.23E2);
        ctx.bezierCurveTo(2.30193E2, 1.20639E2, 2.915E2, 1.52E2, 2.965E2, 1.625E2);
        ctx.bezierCurveTo(2.965E2, 1.625E2, 2.985E2, 1.6E2, 2.945E2, 1.53E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.43801E2, 2.59601E2);
        ctx.bezierCurveTo(1.43801E2, 2.59601E2, 1.64201E2, 2.57601E2, 1.71001E2, 2.50801E2);
        ctx.lineTo(1.75401E2, 2.54401E2);
        ctx.lineTo(1.93001E2, 2.16001E2);
        ctx.lineTo(1.96601E2, 2.21201E2);
        ctx.bezierCurveTo(1.96601E2, 2.21201E2, 2.11001E2, 2.06401E2, 2.10201E2, 1.98401E2);
        ctx.bezierCurveTo(2.09401E2, 1.90401E2, 2.23001E2, 2.04401E2, 2.23001E2, 2.04401E2);
        ctx.bezierCurveTo(2.23001E2, 2.04401E2, 2.22201E2, 1.92801E2, 2.29401E2, 1.99601E2);
        ctx.bezierCurveTo(2.29401E2, 1.99601E2, 2.27001E2, 1.84001E2, 2.35401E2, 1.92001E2);
        ctx.bezierCurveTo(2.35401E2, 1.92001E2, 2.24864E2, 1.61844E2, 2.47401E2, 1.87601E2);
        ctx.bezierCurveTo(2.53001E2, 1.94001E2, 2.48601E2, 1.87201E2, 2.48601E2, 1.87201E2);
        ctx.bezierCurveTo(2.48601E2, 1.87201E2, 2.22601E2, 1.39201E2, 2.44201E2, 1.53601E2);
        ctx.bezierCurveTo(2.44201E2, 1.53601E2, 2.46201E2, 1.30801E2, 2.45001E2, 1.26401E2);
        ctx.bezierCurveTo(2.43801E2, 1.22001E2, 2.41801E2, 9.96E1, 2.37001E2, 9.44E1);
        ctx.bezierCurveTo(2.32201E2, 8.92E1, 2.37401E2, 8.76E1, 2.43001E2, 9.28E1);
        ctx.bezierCurveTo(2.43001E2, 9.28E1, 2.31801E2, 6.88E1, 2.45001E2, 8.08E1);
        ctx.bezierCurveTo(2.45001E2, 8.08E1, 2.41401E2, 6.56E1, 2.37001E2, 6.28E1);
        ctx.bezierCurveTo(2.37001E2, 6.28E1, 2.31401E2, 4.56E1, 2.46601E2, 5.64E1);
        ctx.bezierCurveTo(2.46601E2, 5.64E1, 2.42201E2, 4.4E1, 2.39001E2, 4.08E1);
        ctx.bezierCurveTo(2.39001E2, 4.08E1, 2.27401E2, 1.32E1, 2.34601E2, 1.8E1);
        ctx.lineTo(2.39001E2, 2.16E1);
        ctx.bezierCurveTo(2.39001E2, 2.16E1, 2.32201E2, 7.6E0, 2.38601E2, 1.2E1);
        ctx.bezierCurveTo(2.45001E2, 1.64E1, 2.45001E2, 1.6E1, 2.45001E2, 1.6E1);
        ctx.bezierCurveTo(2.45001E2, 1.6E1, 2.23801E2, (-17.2), 2.44201E2, 4E-1);
        ctx.bezierCurveTo(2.44201E2, 4E-1, 2.36042E2, (-13.518), 2.32601E2, (-20.4));
        ctx.bezierCurveTo(2.32601E2, (-20.4), 2.13801E2, (-40.8), 2.28201E2, (-34.4));
        ctx.lineTo(2.33001E2, (-32.8));
        ctx.bezierCurveTo(2.33001E2, (-32.8), 2.24201E2, (-42.8), 2.16201E2, (-44.4));
        ctx.bezierCurveTo(2.08201E2, (-46), 2.18601E2, (-52.4), 2.25001E2, (-50.4));
        ctx.bezierCurveTo(2.31401E2, (-48.4), 2.47001E2, (-40.8), 2.47001E2, (-40.8));
        ctx.bezierCurveTo(2.47001E2, (-40.8), 2.59801E2, (-22), 2.63801E2, (-21.6));
        ctx.bezierCurveTo(2.63801E2, (-21.6), 2.43801E2, (-29.2), 2.49801E2, (-21.2));
        ctx.bezierCurveTo(2.49801E2, (-21.2), 2.64201E2, (-7.2), 2.57001E2, (-7.6));
        ctx.bezierCurveTo(2.57001E2, (-7.6), 2.51001E2, (-0.4), 2.55801E2, 8.4E0);
        ctx.bezierCurveTo(2.55801E2, 8.4E0, 2.37342E2, (-9.991), 2.52201E2, 1.56E1);
        ctx.lineTo(2.59001E2, 3.2E1);
        ctx.bezierCurveTo(2.59001E2, 3.2E1, 2.34601E2, 7.2E0, 2.45801E2, 2.92E1);
        ctx.bezierCurveTo(2.45801E2, 2.92E1, 2.63001E2, 5.28E1, 2.65001E2, 5.32E1);
        ctx.bezierCurveTo(2.67001E2, 5.36E1, 2.71401E2, 6.24E1, 2.71401E2, 6.24E1);
        ctx.lineTo(2.67001E2, 6.04E1);
        ctx.lineTo(2.72201E2, 6.92E1);
        ctx.bezierCurveTo(2.72201E2, 6.92E1, 2.61001E2, 5.72E1, 2.67001E2, 7.04E1);
        ctx.lineTo(2.72601E2, 8.48E1);
        ctx.bezierCurveTo(2.72601E2, 8.48E1, 2.52201E2, 6.28E1, 2.65801E2, 9.24E1);
        ctx.bezierCurveTo(2.65801E2, 9.24E1, 2.49401E2, 8.72E1, 2.58201E2, 1.044E2);
        ctx.bezierCurveTo(2.58201E2, 1.044E2, 2.56601E2, 1.20401E2, 2.57001E2, 1.25601E2);
        ctx.bezierCurveTo(2.57401E2, 1.30801E2, 2.58601E2, 1.59201E2, 2.54201E2, 1.67201E2);
        ctx.bezierCurveTo(2.49801E2, 1.75201E2, 2.60201E2, 1.94401E2, 2.62201E2, 1.98401E2);
        ctx.bezierCurveTo(2.64201E2, 2.02401E2, 2.67801E2, 2.13201E2, 2.59001E2, 2.04001E2);
        ctx.bezierCurveTo(2.50201E2, 1.94801E2, 2.54601E2, 2.00401E2, 2.56601E2, 2.09201E2);
        ctx.bezierCurveTo(2.58601E2, 2.18001E2, 2.64601E2, 2.33601E2, 2.63801E2, 2.39201E2);
        ctx.bezierCurveTo(2.63801E2, 2.39201E2, 2.62601E2, 2.40401E2, 2.59401E2, 2.36801E2);
        ctx.bezierCurveTo(2.59401E2, 2.36801E2, 2.44601E2, 2.14001E2, 2.46201E2, 2.28401E2);
        ctx.bezierCurveTo(2.46201E2, 2.28401E2, 2.45001E2, 2.36401E2, 2.41801E2, 2.45201E2);
        ctx.bezierCurveTo(2.41801E2, 2.45201E2, 2.38601E2, 2.56001E2, 2.38601E2, 2.47201E2);
        ctx.bezierCurveTo(2.38601E2, 2.47201E2, 2.35401E2, 2.30401E2, 2.32601E2, 2.38001E2);
        ctx.bezierCurveTo(2.29801E2, 2.45601E2, 2.26201E2, 2.51601E2, 2.23401E2, 2.54001E2);
        ctx.bezierCurveTo(2.20601E2, 2.56401E2, 2.15401E2, 2.33601E2, 2.14201E2, 2.44001E2);
        ctx.bezierCurveTo(2.14201E2, 2.44001E2, 2.02201E2, 2.31601E2, 1.97401E2, 2.48001E2);
        ctx.lineTo(1.85801E2, 2.64401E2);
        ctx.bezierCurveTo(1.85801E2, 2.64401E2, 1.85401E2, 2.52001E2, 1.84201E2, 2.58001E2);
        ctx.bezierCurveTo(1.84201E2, 2.58001E2, 1.54201E2, 2.64001E2, 1.43801E2, 2.59601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.09401E2, (-97.2));
        ctx.bezierCurveTo(1.09401E2, (-97.2), 9.7801E1, (-105.2), 9.3801E1, (-104.8));
        ctx.bezierCurveTo(8.9801E1, (-104.4), 1.21401E2, (-113.6), 1.62601E2, (-86));
        ctx.bezierCurveTo(1.62601E2, (-86), 1.67401E2, (-83.2), 1.71001E2, (-83.6));
        ctx.bezierCurveTo(1.71001E2, (-83.6), 1.74201E2, (-81.2), 1.71401E2, (-77.6));
        ctx.bezierCurveTo(1.71401E2, (-77.6), 1.62601E2, (-68), 1.73801E2, (-56.8));
        ctx.bezierCurveTo(1.73801E2, (-56.8), 1.92201E2, (-50), 1.86601E2, (-58.8));
        ctx.bezierCurveTo(1.86601E2, (-58.8), 1.97401E2, (-54.8), 1.99801E2, (-50.8));
        ctx.bezierCurveTo(2.02201E2, (-46.8), 2.01001E2, (-50.8), 2.01001E2, (-50.8));
        ctx.bezierCurveTo(2.01001E2, (-50.8), 1.94601E2, (-58), 1.88601E2, (-63.2));
        ctx.bezierCurveTo(1.88601E2, (-63.2), 1.83401E2, (-65.2), 1.80601E2, (-73.6));
        ctx.bezierCurveTo(1.77801E2, (-82), 1.75401E2, (-92), 1.79801E2, (-95.2));
        ctx.bezierCurveTo(1.79801E2, (-95.2), 1.75801E2, (-90.8), 1.76601E2, (-94.8));
        ctx.bezierCurveTo(1.77401E2, (-98.8), 1.81001E2, (-102.4), 1.82601E2, (-102.8));
        ctx.bezierCurveTo(1.84201E2, (-103.2), 2.00601E2, (-119), 2.07401E2, (-119.4));
        ctx.bezierCurveTo(2.07401E2, (-119.4), 1.98201E2, (-118), 1.95201E2, (-119));
        ctx.bezierCurveTo(1.92201E2, (-120), 1.65601E2, (-131.4), 1.59601E2, (-132.6));
        ctx.bezierCurveTo(1.59601E2, (-132.6), 1.42801E2, (-139.2), 1.54801E2, (-137.2));
        ctx.bezierCurveTo(1.54801E2, (-137.2), 1.90601E2, (-133.4), 2.08801E2, (-120.2));
        ctx.bezierCurveTo(2.08801E2, (-120.2), 2.01601E2, (-128.6), 1.83201E2, (-135.6));
        ctx.bezierCurveTo(1.83201E2, (-135.6), 1.61001E2, (-148.2), 1.25801E2, (-143.2));
        ctx.bezierCurveTo(1.25801E2, (-143.2), 1.08001E2, (-140), 1.00201E2, (-138.2));
        ctx.bezierCurveTo(1.00201E2, (-138.2), 9.7601E1, (-138.8), 9.7001E1, (-139.2));
        ctx.bezierCurveTo(9.6401E1, (-139.6), 8.46E1, (-148.6), 5.7E1, (-141.6));
        ctx.bezierCurveTo(5.7E1, (-141.6), 4E1, (-137), 3.14E1, (-132.2));
        ctx.bezierCurveTo(3.14E1, (-132.2), 1.62E1, (-131), 1.26E1, (-127.8));
        ctx.bezierCurveTo(1.26E1, (-127.8), (-6), (-113.2), (-8), (-112.4));
        ctx.bezierCurveTo((-10), (-111.6), (-21.4), (-104), (-22.2), (-103.6));
        ctx.bezierCurveTo((-22.2), (-103.6), 2.4E0, (-110.2), 4.8E0, (-112.6));
        ctx.bezierCurveTo(7.2E0, (-115), 2.46E1, (-117.6), 2.7E1, (-116.2));
        ctx.bezierCurveTo(2.94E1, (-114.8), 3.78E1, (-115.4), 2.82E1, (-114.8));
        ctx.bezierCurveTo(2.82E1, (-114.8), 1.03801E2, (-100), 1.04601E2, (-98));
        ctx.bezierCurveTo(1.05401E2, (-96), 1.09401E2, (-97.2), 1.09401E2, (-97.2));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.80801E2, (-106.4));
        ctx.bezierCurveTo(1.80801E2, (-106.4), 1.70601E2, (-113.8), 1.68601E2, (-113.8));
        ctx.bezierCurveTo(1.66601E2, (-113.8), 1.54201E2, (-124), 1.50001E2, (-123.6));
        ctx.bezierCurveTo(1.45801E2, (-123.2), 1.33601E2, (-133.2), 1.06201E2, (-125));
        ctx.bezierCurveTo(1.06201E2, (-125), 1.05601E2, (-127), 1.09201E2, (-127.8));
        ctx.bezierCurveTo(1.09201E2, (-127.8), 1.15601E2, (-130), 1.16001E2, (-130.6));
        ctx.bezierCurveTo(1.16001E2, (-130.6), 1.36201E2, (-134.8), 1.43401E2, (-131.2));
        ctx.bezierCurveTo(1.43401E2, (-131.2), 1.52601E2, (-128.6), 1.58801E2, (-122.4));
        ctx.bezierCurveTo(1.58801E2, (-122.4), 1.70001E2, (-119.2), 1.73201E2, (-120.2));
        ctx.bezierCurveTo(1.73201E2, (-120.2), 1.82001E2, (-118), 1.82401E2, (-116.2));
        ctx.bezierCurveTo(1.82401E2, (-116.2), 1.88201E2, (-113.2), 1.86401E2, (-110.6));
        ctx.bezierCurveTo(1.86401E2, (-110.6), 1.86801E2, (-109), 1.80801E2, (-106.4));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.6833E2, (-108.509));
        ctx.bezierCurveTo(1.69137E2, (-107.877), 1.70156E2, (-107.779), 1.70761E2, (-106.97));
        ctx.bezierCurveTo(1.70995E2, (-106.656), 1.70706E2, (-106.33), 1.70391E2, (-106.233));
        ctx.bezierCurveTo(1.69348E2, (-105.916), 1.68292E2, (-106.486), 1.6715E2, (-105.898));
        ctx.bezierCurveTo(1.66748E2, (-105.691), 1.66106E2, (-105.873), 1.65553E2, (-106.022));
        ctx.bezierCurveTo(1.63921E2, (-106.463), 1.62092E2, (-106.488), 1.60401E2, (-105.8));
        ctx.bezierCurveTo(1.58416E2, (-106.929), 1.56056E2, (-106.345), 1.53975E2, (-107.346));
        ctx.bezierCurveTo(1.53917E2, (-107.373), 1.53695E2, (-107.027), 1.53621E2, (-107.054));
        ctx.bezierCurveTo(1.50575E2, (-108.199), 1.46832E2, (-107.916), 1.44401E2, (-110.2));
        ctx.bezierCurveTo(1.41973E2, (-110.612), 1.39616E2, (-111.074), 1.37188E2, (-111.754));
        ctx.bezierCurveTo(1.3537E2, (-112.263), 1.33961E2, (-113.252), 1.32341E2, (-114.084));
        ctx.bezierCurveTo(1.30964E2, (-114.792), 1.29507E2, (-115.314), 1.27973E2, (-115.686));
        ctx.bezierCurveTo(1.2611E2, (-116.138), 1.24279E2, (-116.026), 1.22386E2, (-116.546));
        ctx.bezierCurveTo(1.22293E2, (-116.571), 1.22101E2, (-116.227), 1.22019E2, (-116.254));
        ctx.bezierCurveTo(1.21695E2, (-116.362), 1.21405E2, (-116.945), 1.21234E2, (-116.892));
        ctx.bezierCurveTo(1.19553E2, (-116.37), 1.18065E2, (-117.342), 1.16401E2, (-117));
        ctx.bezierCurveTo(1.15223E2, (-118.224), 1.13495E2, (-117.979), 1.11949E2, (-118.421));
        ctx.bezierCurveTo(1.08985E2, (-119.269), 1.05831E2, (-117.999), 1.02801E2, (-119));
        ctx.bezierCurveTo(1.06914E2, (-120.842), 1.11601E2, (-119.61), 1.15663E2, (-121.679));
        ctx.bezierCurveTo(1.17991E2, (-122.865), 1.20653E2, (-121.763), 1.23223E2, (-122.523));
        ctx.bezierCurveTo(1.2371E2, (-122.667), 1.24401E2, (-122.869), 1.24801E2, (-122.2));
        ctx.bezierCurveTo(1.24935E2, (-122.335), 1.25117E2, (-122.574), 1.25175E2, (-122.546));
        ctx.bezierCurveTo(1.27625E2, (-121.389), 1.2994E2, (-120.115), 1.32422E2, (-119.049));
        ctx.bezierCurveTo(1.32763E2, (-118.903), 1.33295E2, (-119.135), 1.33547E2, (-118.933));
        ctx.bezierCurveTo(1.35067E2, (-117.717), 1.3701E2, (-117.82), 1.38401E2, (-116.6));
        ctx.bezierCurveTo(1.40099E2, (-117.102), 1.41892E2, (-116.722), 1.43621E2, (-117.346));
        ctx.bezierCurveTo(1.43698E2, (-117.373), 1.43932E2, (-117.032), 1.43965E2, (-117.054));
        ctx.bezierCurveTo(1.45095E2, (-117.802), 1.4625E2, (-117.531), 1.47142E2, (-117.227));
        ctx.bezierCurveTo(1.4748E2, (-117.112), 1.48143E2, (-116.865), 1.48448E2, (-116.791));
        ctx.bezierCurveTo(1.49574E2, (-116.515), 1.5043E2, (-116.035), 1.51609E2, (-115.852));
        ctx.bezierCurveTo(1.51723E2, (-115.834), 1.51908E2, (-116.174), 1.5198E2, (-116.146));
        ctx.bezierCurveTo(1.53103E2, (-115.708), 1.54145E2, (-115.764), 1.54801E2, (-114.6));
        ctx.bezierCurveTo(1.54936E2, (-114.735), 1.55101E2, (-114.973), 1.55183E2, (-114.946));
        ctx.bezierCurveTo(1.5621E2, (-114.608), 1.56859E2, (-113.853), 1.5796E2, (-113.612));
        ctx.bezierCurveTo(1.58445E2, (-113.506), 1.59057E2, (-112.88), 1.59633E2, (-112.704));
        ctx.bezierCurveTo(1.62025E2, (-111.973), 1.63868E2, (-110.444), 1.66062E2, (-109.549));
        ctx.bezierCurveTo(1.66821E2, (-109.239), 1.67697E2, (-109.005), 1.6833E2, (-108.509));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.1696E1, (-122.739));
        ctx.bezierCurveTo(8.9178E1, (-124.464), 8.681E1, (-125.57), 8.4368E1, (-127.356));
        ctx.bezierCurveTo(8.4187E1, (-127.489), 8.3827E1, (-127.319), 8.3625E1, (-127.441));
        ctx.bezierCurveTo(8.2618E1, (-128.05), 8.173E1, (-128.631), 8.0748E1, (-129.327));
        ctx.bezierCurveTo(8.0209E1, (-129.709), 7.9388E1, (-129.698), 7.888E1, (-129.956));
        ctx.bezierCurveTo(7.6336E1, (-131.248), 7.3707E1, (-131.806), 7.12E1, (-133));
        ctx.bezierCurveTo(7.1882E1, (-133.638), 7.3004E1, (-133.394), 7.36E1, (-134.2));
        ctx.bezierCurveTo(7.3795E1, (-133.92), 7.4033E1, (-133.636), 7.4386E1, (-133.827));
        ctx.bezierCurveTo(7.6064E1, (-134.731), 7.7914E1, (-134.884), 7.959E1, (-134.794));
        ctx.bezierCurveTo(8.1294E1, (-134.702), 8.3014E1, (-134.397), 8.4789E1, (-134.125));
        ctx.bezierCurveTo(8.5096E1, (-134.078), 8.5295E1, (-133.555), 8.5618E1, (-133.458));
        ctx.bezierCurveTo(8.7846E1, (-132.795), 9.0235E1, (-133.32), 9.2354E1, (-132.482));
        ctx.bezierCurveTo(9.3945E1, (-131.853), 9.5515E1, (-131.03), 9.6754E1, (-129.755));
        ctx.bezierCurveTo(9.7006E1, (-129.495), 9.6681E1, (-129.194), 9.6401E1, (-129));
        ctx.bezierCurveTo(9.6789E1, (-129.109), 9.7062E1, (-128.903), 9.7173E1, (-128.59));
        ctx.bezierCurveTo(9.7257E1, (-128.351), 9.7257E1, (-128.049), 9.7173E1, (-127.81));
        ctx.bezierCurveTo(9.7061E1, (-127.498), 9.6782E1, (-127.397), 9.6408E1, (-127.346));
        ctx.bezierCurveTo(9.5001E1, (-127.156), 9.6773E1, (-128.536), 9.6073E1, (-128.088));
        ctx.bezierCurveTo(9.48E1, (-127.274), 9.5546E1, (-125.868), 9.4801E1, (-124.6));
        ctx.bezierCurveTo(9.4521E1, (-124.794), 9.4291E1, (-125.012), 9.4401E1, (-125.4));
        ctx.bezierCurveTo(9.4635E1, (-124.878), 9.4033E1, (-124.588), 9.3865E1, (-124.272));
        ctx.bezierCurveTo(9.348E1, (-123.547), 9.2581E1, (-122.132), 9.1696E1, (-122.739));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.9198E1, (-115.391));
        ctx.bezierCurveTo(5.6044E1, (-116.185), 5.2994E1, (-116.07), 4.9978E1, (-117.346));
        ctx.bezierCurveTo(4.9911E1, (-117.374), 4.9688E1, (-117.027), 4.9624E1, (-117.054));
        ctx.bezierCurveTo(4.8258E1, (-117.648), 4.734E1, (-118.614), 4.6264E1, (-119.66));
        ctx.bezierCurveTo(4.5351E1, (-120.548), 4.3693E1, (-120.161), 4.2419E1, (-120.648));
        ctx.bezierCurveTo(4.2095E1, (-120.772), 4.1892E1, (-121.284), 4.1591E1, (-121.323));
        ctx.bezierCurveTo(4.0372E1, (-121.48), 3.9445E1, (-122.429), 3.84E1, (-123));
        ctx.bezierCurveTo(4.0736E1, (-123.795), 4.3147E1, (-123.764), 4.5609E1, (-124.148));
        ctx.bezierCurveTo(4.5722E1, (-124.166), 4.5867E1, (-123.845), 4.6E1, (-123.845));
        ctx.bezierCurveTo(4.6136E1, (-123.845), 4.6266E1, (-124.066), 4.64E1, (-124.2));
        ctx.bezierCurveTo(4.6595E1, (-123.92), 4.6897E1, (-123.594), 4.7154E1, (-123.848));
        ctx.bezierCurveTo(4.7702E1, (-124.388), 4.8258E1, (-124.198), 4.8798E1, (-124.158));
        ctx.bezierCurveTo(4.8942E1, (-124.148), 4.9067E1, (-123.845), 4.92E1, (-123.845));
        ctx.bezierCurveTo(4.9336E1, (-123.845), 4.9467E1, (-124.156), 4.96E1, (-124.156));
        ctx.bezierCurveTo(4.9736E1, (-124.155), 4.9867E1, (-123.845), 5E1, (-123.845));
        ctx.bezierCurveTo(5.0136E1, (-123.845), 5.0266E1, (-124.066), 5.04E1, (-124.2));
        ctx.bezierCurveTo(5.1092E1, (-123.418), 5.1977E1, (-123.972), 5.2799E1, (-123.793));
        ctx.bezierCurveTo(5.3837E1, (-123.566), 5.4104E1, (-122.418), 5.5178E1, (-122.12));
        ctx.bezierCurveTo(5.9893E1, (-120.816), 6.403E1, (-118.671), 6.8393E1, (-116.584));
        ctx.bezierCurveTo(6.87E1, (-116.437), 6.891E1, (-116.189), 6.88E1, (-115.8));
        ctx.bezierCurveTo(6.9067E1, (-115.8), 6.938E1, (-115.888), 6.957E1, (-115.756));
        ctx.bezierCurveTo(7.0628E1, (-115.024), 7.1669E1, (-114.476), 7.2366E1, (-113.378));
        ctx.bezierCurveTo(7.2582E1, (-113.039), 7.2253E1, (-112.632), 7.202E1, (-112.684));
        ctx.bezierCurveTo(6.7591E1, (-113.679), 6.3585E1, (-114.287), 5.9198E1, (-115.391));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.5338E1, (-71.179));
        ctx.bezierCurveTo(4.3746E1, (-72.398), 4.3162E1, (-74.429), 4.2034E1, (-76.221));
        ctx.bezierCurveTo(4.182E1, (-76.561), 4.2094E1, (-76.875), 4.2411E1, (-76.964));
        ctx.bezierCurveTo(4.2971E1, (-77.123), 4.3514E1, (-76.645), 4.3923E1, (-76.443));
        ctx.bezierCurveTo(4.5668E1, (-75.581), 4.7203E1, (-74.339), 4.92E1, (-74.2));
        ctx.bezierCurveTo(5.119E1, (-71.966), 5.545E1, (-71.581), 5.5457E1, (-68.2));
        ctx.bezierCurveTo(5.5458E1, (-67.341), 5.403E1, (-68.259), 5.36E1, (-67.4));
        ctx.bezierCurveTo(5.1149E1, (-68.403), 4.876E1, (-68.3), 4.638E1, (-69.767));
        ctx.bezierCurveTo(4.5763E1, (-70.148), 4.6093E1, (-70.601), 4.5338E1, (-71.179));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cc7226';
        ctx.fillStyle = 'rgba(204,114,38,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.78E1, (-123.756));
        ctx.bezierCurveTo(1.7935E1, (-123.755), 2.4966E1, (-123.522), 2.4949E1, (-123.408));
        ctx.bezierCurveTo(2.4904E1, (-123.099), 1.7174E1, (-122.05), 1.681E1, (-122.22));
        ctx.bezierCurveTo(1.6646E1, (-122.296), 9.134E0, (-119.866), 9E0, (-120));
        ctx.bezierCurveTo(9.268E0, (-120.135), 1.7534E1, (-123.756), 1.78E1, (-123.756));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.32E1, (-114));
        ctx.bezierCurveTo(3.32E1, (-114), 1.84E1, (-112.2), 1.4E1, (-111));
        ctx.bezierCurveTo(9.6E0, (-109.8), (-9), (-102.2), (-12), (-100.2));
        ctx.bezierCurveTo((-12), (-100.2), (-25.4), (-94.8), (-42.4), (-74.8));
        ctx.bezierCurveTo((-42.4), (-74.8), (-34.8), (-78.2), (-32.6), (-81));
        ctx.bezierCurveTo((-32.6), (-81), (-19), (-93.6), (-19.2), (-91));
        ctx.bezierCurveTo((-19.2), (-91), (-7), (-99.6), (-7.6), (-97.4));
        ctx.bezierCurveTo((-7.6), (-97.4), 1.68E1, (-108.6), 1.48E1, (-105.4));
        ctx.bezierCurveTo(1.48E1, (-105.4), 3.64E1, (-110), 3.54E1, (-108));
        ctx.bezierCurveTo(3.54E1, (-108), 5.42E1, (-103.6), 5.14E1, (-103.4));
        ctx.bezierCurveTo(5.14E1, (-103.4), 4.56E1, (-102.2), 5.2E1, (-98.6));
        ctx.bezierCurveTo(5.2E1, (-98.6), 4.86E1, (-94.2), 4.32E1, (-98.2));
        ctx.bezierCurveTo(3.78E1, (-102.2), 4.08E1, (-100), 3.58E1, (-99));
        ctx.bezierCurveTo(3.58E1, (-99), 3.32E1, (-98.2), 2.86E1, (-102.2));
        ctx.bezierCurveTo(2.86E1, (-102.2), 2.3E1, (-106.8), 1.42E1, (-103.2));
        ctx.bezierCurveTo(1.42E1, (-103.2), (-16.4), (-90.6), (-18.4), (-90));
        ctx.bezierCurveTo((-18.4), (-90), (-22), (-87.2), (-24.4), (-83.6));
        ctx.bezierCurveTo((-24.4), (-83.6), (-30.2), (-79.2), (-33.2), (-77.8));
        ctx.bezierCurveTo((-33.2), (-77.8), (-46), (-66.2), (-47.2), (-64.8));
        ctx.bezierCurveTo((-47.2), (-64.8), (-50.6), (-59.6), (-51.4), (-59.2));
        ctx.bezierCurveTo((-51.4), (-59.2), (-45), (-63), (-43), (-65));
        ctx.bezierCurveTo((-43), (-65), (-29), (-75), (-23.6), (-75.8));
        ctx.bezierCurveTo((-23.6), (-75.8), (-19.2), (-78.8), (-18.4), (-80.2));
        ctx.bezierCurveTo((-18.4), (-80.2), (-4), (-89.4), 2E-1, (-89.4));
        ctx.bezierCurveTo(2E-1, (-89.4), 9.4E0, (-84.2), 1.18E1, (-91.2));
        ctx.bezierCurveTo(1.18E1, (-91.2), 1.76E1, (-93), 2.32E1, (-91.8));
        ctx.bezierCurveTo(2.32E1, (-91.8), 2.64E1, (-94.4), 2.56E1, (-96.6));
        ctx.bezierCurveTo(2.56E1, (-96.6), 2.72E1, (-98.4), 2.82E1, (-94.6));
        ctx.bezierCurveTo(2.82E1, (-94.6), 3.16E1, (-91), 3.64E1, (-93));
        ctx.bezierCurveTo(3.64E1, (-93), 4.04E1, (-93.2), 3.84E1, (-90.8));
        ctx.bezierCurveTo(3.84E1, (-90.8), 3.4E1, (-87), 2.22E1, (-86.8));
        ctx.bezierCurveTo(2.22E1, (-86.8), 9.8E0, (-86.2), (-6.6), (-78.6));
        ctx.bezierCurveTo((-6.6), (-78.6), (-36.4), (-68.2), (-45.6), (-57.8));
        ctx.bezierCurveTo((-45.6), (-57.8), (-52), (-49), (-57.4), (-47.8));
        ctx.bezierCurveTo((-57.4), (-47.8), (-63.2), (-47), (-69.2), (-39.6));
        ctx.bezierCurveTo((-69.2), (-39.6), (-59.4), (-45.4), (-50.4), (-45.4));
        ctx.bezierCurveTo((-50.4), (-45.4), (-46.4), (-47.8), (-50.2), (-44.2));
        ctx.bezierCurveTo((-50.2), (-44.2), (-53.8), (-36.6), (-52.2), (-31.2));
        ctx.bezierCurveTo((-52.2), (-31.2), (-52.8), (-26), (-53.6), (-24.4));
        ctx.bezierCurveTo((-53.6), (-24.4), (-61.4), (-11.6), (-61.4), (-9.2));
        ctx.bezierCurveTo((-61.4), (-6.8), (-60.2), 3E0, (-59.8), 3.6E0);
        ctx.bezierCurveTo((-59.4), 4.2E0, (-60.8), 2E0, (-57), 4.4E0);
        ctx.bezierCurveTo((-53.2), 6.8E0, (-50.4), 8.4E0, (-49.6), 1.12E1);
        ctx.bezierCurveTo((-48.8), 1.4E1, (-51.6), 5.8E0, (-51.8), 4E0);
        ctx.bezierCurveTo((-52), 2.2E0, (-56.2), (-5), (-55.4), (-7.4));
        ctx.bezierCurveTo((-55.4), (-7.4), (-54.4), (-6.4), (-53.6), (-5));
        ctx.bezierCurveTo((-53.6), (-5), (-54.2), (-5.6), (-53.6), (-9.2));
        ctx.bezierCurveTo((-53.6), (-9.2), (-52.8), (-14.4), (-51.4), (-17.6));
        ctx.bezierCurveTo((-50), (-20.8), (-48), (-24.6), (-47.6), (-25.4));
        ctx.bezierCurveTo((-47.2), (-26.2), (-47.2), (-32), (-45.8), (-29.4));
        ctx.lineTo((-42.4), (-26.8));
        ctx.bezierCurveTo((-42.4), (-26.8), (-45.2), (-29.4), (-43), (-31.6));
        ctx.bezierCurveTo((-43), (-31.6), (-44), (-37.2), (-42.2), (-39.8));
        ctx.bezierCurveTo((-42.2), (-39.8), (-35.2), (-48.2), (-33.6), (-49.2));
        ctx.bezierCurveTo((-32), (-50.2), (-33.4), (-49.8), (-33.4), (-49.8));
        ctx.bezierCurveTo((-33.4), (-49.8), (-27.4), (-54), (-33.2), (-52.4));
        ctx.bezierCurveTo((-33.2), (-52.4), (-37.2), (-50.8), (-40.2), (-50.8));
        ctx.bezierCurveTo((-40.2), (-50.8), (-47.8), (-48.8), (-43.8), (-53));
        ctx.bezierCurveTo((-39.8), (-57.2), (-29.8), (-62.6), (-26), (-62.4));
        ctx.lineTo((-25.2), (-60.8));
        ctx.lineTo((-14), (-63.2));
        ctx.lineTo((-15.2), (-62.4));
        ctx.bezierCurveTo((-15.2), (-62.4), (-15.4), (-62.6), (-11.2), (-63));
        ctx.bezierCurveTo((-7), (-63.4), (-1.2), (-62), 2E-1, (-63.8));
        ctx.bezierCurveTo(1.6E0, (-65.6), 5E0, (-66.6), 4.6E0, (-65.2));
        ctx.bezierCurveTo(4.2E0, (-63.8), 4E0, (-61.8), 4E0, (-61.8));
        ctx.bezierCurveTo(4E0, (-61.8), 9E0, (-67.6), 8.4E0, (-65.4));
        ctx.bezierCurveTo(7.8E0, (-63.2), (-0.4), (-58), (-1.8), (-51.8));
        ctx.lineTo(8.6E0, (-60));
        ctx.lineTo(1.22E1, (-63));
        ctx.bezierCurveTo(1.22E1, (-63), 1.58E1, (-60.8), 1.6E1, (-62.4));
        ctx.bezierCurveTo(1.62E1, (-64), 2.08E1, (-69.8), 2.2E1, (-69.6));
        ctx.bezierCurveTo(2.32E1, (-69.4), 2.52E1, (-72.2), 2.5E1, (-69.6));
        ctx.bezierCurveTo(2.48E1, (-67), 3.24E1, (-61.6), 3.24E1, (-61.6));
        ctx.bezierCurveTo(3.24E1, (-61.6), 3.56E1, (-63.4), 3.7E1, (-62));
        ctx.bezierCurveTo(3.84E1, (-60.6), 4.26E1, (-81.8), 4.26E1, (-81.8));
        ctx.lineTo(6.76E1, (-92.4));
        ctx.lineTo(1.11201E2, (-95.8));
        ctx.lineTo(9.4201E1, (-102.6));
        ctx.lineTo(3.32E1, (-114));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.14E1, 8.5E1);
        ctx.bezierCurveTo(5.14E1, 8.5E1, 3.64E1, 6.82E1, 2.8E1, 6.56E1);
        ctx.bezierCurveTo(2.8E1, 6.56E1, 1.46E1, 5.88E1, (-10), 6.66E1);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.48E1, 6.42E1);
        ctx.bezierCurveTo(2.48E1, 6.42E1, (-0.4), 5.62E1, (-15.8), 6.04E1);
        ctx.bezierCurveTo((-15.8), 6.04E1, (-34.2), 6.24E1, (-42.6), 7.62E1);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.12E1, 6.3E1);
        ctx.bezierCurveTo(2.12E1, 6.3E1, 4.2E0, 5.58E1, (-10.6), 5.36E1);
        ctx.bezierCurveTo((-10.6), 5.36E1, (-27.2), 5.1E1, (-43.8), 5.82E1);
        ctx.bezierCurveTo((-43.8), 5.82E1, (-56), 6.42E1, (-61.4), 7.44E1);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#4c0000';
        ctx.lineWidth = 2E0;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.22E1, 6.34E1);
        ctx.bezierCurveTo(2.22E1, 6.34E1, 6.8E0, 5.24E1, 5.8E0, 5.1E1);
        ctx.bezierCurveTo(5.8E0, 5.1E1, (-1.2), 4E1, (-14.2), 3.96E1);
        ctx.bezierCurveTo((-14.2), 3.96E1, (-35.6), 4.04E1, (-52.8), 4.84E1);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.0895E1, 5.4407E1);
        ctx.bezierCurveTo(2.2437E1, 5.587E1, 4.94E1, 8.48E1, 4.94E1, 8.48E1);
        ctx.bezierCurveTo(8.46E1, 1.21401E2, 5.66E1, 8.72E1, 5.66E1, 8.72E1);
        ctx.bezierCurveTo(4.9E1, 8.24E1, 3.98E1, 6.36E1, 3.98E1, 6.36E1);
        ctx.bezierCurveTo(3.86E1, 6.08E1, 5.38E1, 7.08E1, 5.38E1, 7.08E1);
        ctx.bezierCurveTo(5.78E1, 7.16E1, 7.14E1, 9.08E1, 7.14E1, 9.08E1);
        ctx.bezierCurveTo(6.46E1, 8.84E1, 6.94E1, 9.56E1, 6.94E1, 9.56E1);
        ctx.bezierCurveTo(7.22E1, 9.76E1, 9.2601E1, 1.13201E2, 9.2601E1, 1.13201E2);
        ctx.bezierCurveTo(9.6201E1, 1.17201E2, 1.00201E2, 1.18801E2, 1.00201E2, 1.18801E2);
        ctx.bezierCurveTo(1.14201E2, 1.13601E2, 1.07801E2, 1.26801E2, 1.07801E2, 1.26801E2);
        ctx.bezierCurveTo(1.10201E2, 1.33601E2, 1.15801E2, 1.22001E2, 1.15801E2, 1.22001E2);
        ctx.bezierCurveTo(1.27001E2, 1.052E2, 1.10601E2, 1.07601E2, 1.10601E2, 1.07601E2);
        ctx.bezierCurveTo(8.06E1, 1.10401E2, 7.38E1, 9.44E1, 7.38E1, 9.44E1);
        ctx.bezierCurveTo(7.14E1, 9.2E1, 8.02E1, 9.44E1, 8.02E1, 9.44E1);
        ctx.bezierCurveTo(8.8601E1, 9.64E1, 7.3E1, 8.2E1, 7.3E1, 8.2E1);
        ctx.bezierCurveTo(7.54E1, 8.2E1, 8.46E1, 8.88E1, 8.46E1, 8.88E1);
        ctx.bezierCurveTo(9.5001E1, 9.8E1, 9.7001E1, 9.6E1, 9.7001E1, 9.6E1);
        ctx.bezierCurveTo(1.15001E2, 8.72E1, 1.25401E2, 9.48E1, 1.25401E2, 9.48E1);
        ctx.bezierCurveTo(1.27401E2, 9.64E1, 1.21801E2, 1.032E2, 1.23401E2, 1.08401E2);
        ctx.bezierCurveTo(1.25001E2, 1.13601E2, 1.29801E2, 1.26001E2, 1.29801E2, 1.26001E2);
        ctx.bezierCurveTo(1.27401E2, 1.27601E2, 1.27801E2, 1.38401E2, 1.27801E2, 1.38401E2);
        ctx.bezierCurveTo(1.44601E2, 1.61601E2, 1.35001E2, 1.59601E2, 1.35001E2, 1.59601E2);
        ctx.bezierCurveTo(1.19401E2, 1.59201E2, 1.34201E2, 1.66801E2, 1.34201E2, 1.66801E2);
        ctx.bezierCurveTo(1.37401E2, 1.68801E2, 1.46201E2, 1.76001E2, 1.46201E2, 1.76001E2);
        ctx.bezierCurveTo(1.43401E2, 1.74801E2, 1.41801E2, 1.80001E2, 1.41801E2, 1.80001E2);
        ctx.bezierCurveTo(1.46601E2, 1.84001E2, 1.43801E2, 1.88801E2, 1.43801E2, 1.88801E2);
        ctx.bezierCurveTo(1.37801E2, 1.90001E2, 1.36601E2, 1.94001E2, 1.36601E2, 1.94001E2);
        ctx.bezierCurveTo(1.43401E2, 2.02001E2, 1.33401E2, 2.02401E2, 1.33401E2, 2.02401E2);
        ctx.bezierCurveTo(1.37001E2, 2.06801E2, 1.32201E2, 2.18801E2, 1.32201E2, 2.18801E2);
        ctx.bezierCurveTo(1.27401E2, 2.18801E2, 1.21001E2, 2.24401E2, 1.21001E2, 2.24401E2);
        ctx.bezierCurveTo(1.23401E2, 2.29201E2, 1.13001E2, 2.34801E2, 1.13001E2, 2.34801E2);
        ctx.bezierCurveTo(1.04601E2, 2.36401E2, 1.07401E2, 2.43201E2, 1.07401E2, 2.43201E2);
        ctx.bezierCurveTo(9.9401E1, 2.49201E2, 9.7001E1, 2.65201E2, 9.7001E1, 2.65201E2);
        ctx.bezierCurveTo(9.6201E1, 2.75601E2, 9.3801E1, 2.78801E2, 9.9001E1, 2.76801E2);
        ctx.bezierCurveTo(1.04201E2, 2.74801E2, 1.03401E2, 2.62401E2, 1.03401E2, 2.62401E2);
        ctx.bezierCurveTo(9.8601E1, 2.46801E2, 1.41401E2, 2.30801E2, 1.41401E2, 2.30801E2);
        ctx.bezierCurveTo(1.45401E2, 2.29201E2, 1.46201E2, 2.24001E2, 1.46201E2, 2.24001E2);
        ctx.bezierCurveTo(1.48201E2, 2.24401E2, 1.57001E2, 2.32001E2, 1.57001E2, 2.32001E2);
        ctx.bezierCurveTo(1.64601E2, 2.43201E2, 1.65001E2, 2.34001E2, 1.65001E2, 2.34001E2);
        ctx.bezierCurveTo(1.66201E2, 2.30401E2, 1.64601E2, 2.24401E2, 1.64601E2, 2.24401E2);
        ctx.bezierCurveTo(1.70601E2, 2.02801E2, 1.56601E2, 1.96401E2, 1.56601E2, 1.96401E2);
        ctx.bezierCurveTo(1.46601E2, 1.62801E2, 1.60601E2, 1.71201E2, 1.60601E2, 1.71201E2);
        ctx.bezierCurveTo(1.63401E2, 1.76801E2, 1.74201E2, 1.82001E2, 1.74201E2, 1.82001E2);
        ctx.lineTo(1.77801E2, 1.79601E2);
        ctx.bezierCurveTo(1.76201E2, 1.74801E2, 1.84601E2, 1.68801E2, 1.84601E2, 1.68801E2);
        ctx.bezierCurveTo(1.87401E2, 1.75201E2, 1.93401E2, 1.67201E2, 1.93401E2, 1.67201E2);
        ctx.bezierCurveTo(1.97001E2, 1.42801E2, 2.09401E2, 1.57201E2, 2.09401E2, 1.57201E2);
        ctx.bezierCurveTo(2.13401E2, 1.58401E2, 2.14601E2, 1.51601E2, 2.14601E2, 1.51601E2);
        ctx.bezierCurveTo(2.18201E2, 1.41201E2, 2.14601E2, 1.27601E2, 2.14601E2, 1.27601E2);
        ctx.bezierCurveTo(2.18201E2, 1.27201E2, 2.27801E2, 1.33201E2, 2.27801E2, 1.33201E2);
        ctx.bezierCurveTo(2.30601E2, 1.29601E2, 2.21401E2, 1.12801E2, 2.25401E2, 1.15201E2);
        ctx.bezierCurveTo(2.29401E2, 1.17601E2, 2.33801E2, 1.19201E2, 2.33801E2, 1.19201E2);
        ctx.bezierCurveTo(2.34601E2, 1.17201E2, 2.24601E2, 1.04801E2, 2.24601E2, 1.04801E2);
        ctx.bezierCurveTo(2.20201E2, 1.02E2, 2.15001E2, 8.16E1, 2.15001E2, 8.16E1);
        ctx.bezierCurveTo(2.22201E2, 8.52E1, 2.12201E2, 7E1, 2.12201E2, 7E1);
        ctx.bezierCurveTo(2.12201E2, 6.68E1, 2.18201E2, 5.56E1, 2.18201E2, 5.56E1);
        ctx.bezierCurveTo(2.17401E2, 4.88E1, 2.18201E2, 4.92E1, 2.18201E2, 4.92E1);
        ctx.bezierCurveTo(2.21001E2, 5.04E1, 2.29001E2, 5.2E1, 2.22201E2, 4.56E1);
        ctx.bezierCurveTo(2.15401E2, 3.92E1, 2.23001E2, 3.44E1, 2.23001E2, 3.44E1);
        ctx.bezierCurveTo(2.27401E2, 3.16E1, 2.13801E2, 3.2E1, 2.13801E2, 3.2E1);
        ctx.bezierCurveTo(2.08601E2, 2.76E1, 2.09001E2, 2.36E1, 2.09001E2, 2.36E1);
        ctx.bezierCurveTo(2.17001E2, 2.56E1, 2.02601E2, 1.12E1, 2.00201E2, 7.6E0);
        ctx.bezierCurveTo(1.97801E2, 4E0, 2.07401E2, (-1.2), 2.07401E2, (-1.2));
        ctx.bezierCurveTo(2.20601E2, (-4.8), 2.09001E2, (-8), 2.09001E2, (-8));
        ctx.bezierCurveTo(1.89401E2, (-7.6), 2.00201E2, (-18.4), 2.00201E2, (-18.4));
        ctx.bezierCurveTo(2.06201E2, (-18), 2.04601E2, (-20.4), 2.04601E2, (-20.4));
        ctx.bezierCurveTo(1.99401E2, (-21.6), 1.89801E2, (-28), 1.89801E2, (-28));
        ctx.bezierCurveTo(1.85801E2, (-31.6), 1.89401E2, (-30.8), 1.89401E2, (-30.8));
        ctx.bezierCurveTo(2.06201E2, (-29.6), 1.77401E2, (-40.8), 1.77401E2, (-40.8));
        ctx.bezierCurveTo(1.85401E2, (-40.8), 1.67401E2, (-51.2), 1.67401E2, (-51.2));
        ctx.bezierCurveTo(1.65401E2, (-52.8), 1.62201E2, (-60.4), 1.62201E2, (-60.4));
        ctx.bezierCurveTo(1.56201E2, (-65.6), 1.51401E2, (-72.4), 1.51401E2, (-72.4));
        ctx.bezierCurveTo(1.51001E2, (-76.8), 1.46201E2, (-81.6), 1.46201E2, (-81.6));
        ctx.bezierCurveTo(1.34601E2, (-95.2), 1.29001E2, (-94.8), 1.29001E2, (-94.8));
        ctx.bezierCurveTo(1.14201E2, (-98.4), 1.09001E2, (-97.6), 1.09001E2, (-97.6));
        ctx.lineTo(5.62E1, (-93.2));
        ctx.bezierCurveTo(2.98E1, (-80.4), 3.76E1, (-59.4), 3.76E1, (-59.4));
        ctx.bezierCurveTo(4.4E1, (-51), 5.32E1, (-54.8), 5.32E1, (-54.8));
        ctx.bezierCurveTo(5.78E1, (-61), 6.94E1, (-58.8), 6.94E1, (-58.8));
        ctx.bezierCurveTo(8.9801E1, (-55.6), 8.7201E1, (-59.2), 8.7201E1, (-59.2));
        ctx.bezierCurveTo(8.4801E1, (-63.8), 6.86E1, (-70), 6.84E1, (-70.6));
        ctx.bezierCurveTo(6.82E1, (-71.2), 5.94E1, (-74.6), 5.94E1, (-74.6));
        ctx.bezierCurveTo(5.64E1, (-75.8), 5.2E1, (-85), 5.2E1, (-85));
        ctx.bezierCurveTo(4.88E1, (-88.4), 6.46E1, (-82.6), 6.46E1, (-82.6));
        ctx.bezierCurveTo(6.34E1, (-81.6), 7.08E1, (-77.6), 7.08E1, (-77.6));
        ctx.bezierCurveTo(8.8201E1, (-78.6), 9.8801E1, (-67.8), 9.8801E1, (-67.8));
        ctx.bezierCurveTo(1.09601E2, (-51.2), 1.09801E2, (-59.4), 1.09801E2, (-59.4));
        ctx.bezierCurveTo(1.12601E2, (-68.8), 1.00801E2, (-90), 1.00801E2, (-90));
        ctx.bezierCurveTo(1.01201E2, (-92), 1.09401E2, (-85.4), 1.09401E2, (-85.4));
        ctx.bezierCurveTo(1.10801E2, (-87.4), 1.11601E2, (-81.6), 1.11601E2, (-81.6));
        ctx.bezierCurveTo(1.11801E2, (-79.2), 1.15601E2, (-71.2), 1.15601E2, (-71.2));
        ctx.bezierCurveTo(1.18401E2, (-58.2), 1.22001E2, (-65.6), 1.22001E2, (-65.6));
        ctx.lineTo(1.26601E2, (-56.2));
        ctx.bezierCurveTo(1.28001E2, (-53.6), 1.22001E2, (-46), 1.22001E2, (-46));
        ctx.bezierCurveTo(1.21801E2, (-43.2), 1.22601E2, (-43.4), 1.17001E2, (-35.8));
        ctx.bezierCurveTo(1.11401E2, (-28.2), 1.14801E2, (-23.8), 1.14801E2, (-23.8));
        ctx.bezierCurveTo(1.13401E2, (-17.2), 1.22201E2, (-17.6), 1.22201E2, (-17.6));
        ctx.bezierCurveTo(1.24801E2, (-15.4), 1.28201E2, (-15.4), 1.28201E2, (-15.4));
        ctx.bezierCurveTo(1.30001E2, (-13.4), 1.32401E2, (-14), 1.32401E2, (-14));
        ctx.bezierCurveTo(1.34001E2, (-17.8), 1.40201E2, (-15.8), 1.40201E2, (-15.8));
        ctx.bezierCurveTo(1.41601E2, (-18.2), 1.49801E2, (-18.6), 1.49801E2, (-18.6));
        ctx.bezierCurveTo(1.50801E2, (-21.2), 1.51201E2, (-22.8), 1.54601E2, (-23.4));
        ctx.bezierCurveTo(1.58001E2, (-24), 1.33401E2, (-67), 1.33401E2, (-67));
        ctx.bezierCurveTo(1.39801E2, (-67.8), 1.31601E2, (-80.2), 1.31601E2, (-80.2));
        ctx.bezierCurveTo(1.29401E2, (-86.8), 1.40801E2, (-72.2), 1.43001E2, (-70.8));
        ctx.bezierCurveTo(1.45201E2, (-69.4), 1.46201E2, (-67.2), 1.44601E2, (-67.4));
        ctx.bezierCurveTo(1.43001E2, (-67.6), 1.41201E2, (-65.4), 1.42601E2, (-65.2));
        ctx.bezierCurveTo(1.44001E2, (-65), 1.57001E2, (-50), 1.60401E2, (-39.8));
        ctx.bezierCurveTo(1.63801E2, (-29.6), 1.69801E2, (-25.6), 1.76001E2, (-19.6));
        ctx.bezierCurveTo(1.82201E2, (-13.6), 1.81401E2, 1.06E1, 1.81401E2, 1.06E1);
        ctx.bezierCurveTo(1.81001E2, 1.94E1, 1.87001E2, 3E1, 1.87001E2, 3E1);
        ctx.bezierCurveTo(1.89001E2, 3.38E1, 1.84801E2, 5.2E1, 1.84801E2, 5.2E1);
        ctx.bezierCurveTo(1.82801E2, 5.42E1, 1.84201E2, 5.5E1, 1.84201E2, 5.5E1);
        ctx.bezierCurveTo(1.85201E2, 5.62E1, 1.92001E2, 6.94E1, 1.92001E2, 6.94E1);
        ctx.bezierCurveTo(1.90201E2, 6.92E1, 1.93801E2, 7.28E1, 1.93801E2, 7.28E1);
        ctx.bezierCurveTo(1.99001E2, 7.88E1, 1.92601E2, 7.58E1, 1.92601E2, 7.58E1);
        ctx.bezierCurveTo(1.86601E2, 7.42E1, 1.93601E2, 8.4E1, 1.93601E2, 8.4E1);
        ctx.bezierCurveTo(1.94801E2, 8.58E1, 1.85801E2, 8.12E1, 1.85801E2, 8.12E1);
        ctx.bezierCurveTo(1.76601E2, 8.06E1, 1.88201E2, 8.78E1, 1.88201E2, 8.78E1);
        ctx.bezierCurveTo(1.96801E2, 9.5E1, 1.85401E2, 9.06E1, 1.85401E2, 9.06E1);
        ctx.bezierCurveTo(1.80801E2, 8.88E1, 1.84001E2, 9.56E1, 1.84001E2, 9.56E1);
        ctx.bezierCurveTo(1.87201E2, 9.72E1, 2.04401E2, 1.042E2, 2.04401E2, 1.042E2);
        ctx.bezierCurveTo(2.04801E2, 1.08001E2, 2.01801E2, 1.13001E2, 2.01801E2, 1.13001E2);
        ctx.bezierCurveTo(2.02201E2, 1.17001E2, 2.00001E2, 1.20401E2, 2.00001E2, 1.20401E2);
        ctx.bezierCurveTo(1.98801E2, 1.28601E2, 1.98201E2, 1.29401E2, 1.98201E2, 1.29401E2);
        ctx.bezierCurveTo(1.94001E2, 1.29601E2, 1.86601E2, 1.43401E2, 1.86601E2, 1.43401E2);
        ctx.bezierCurveTo(1.84801E2, 1.46001E2, 1.74601E2, 1.58001E2, 1.74601E2, 1.58001E2);
        ctx.bezierCurveTo(1.72601E2, 1.65001E2, 1.54601E2, 1.57801E2, 1.54601E2, 1.57801E2);
        ctx.bezierCurveTo(1.48001E2, 1.61201E2, 1.50001E2, 1.57801E2, 1.50001E2, 1.57801E2);
        ctx.bezierCurveTo(1.49601E2, 1.55601E2, 1.54401E2, 1.49601E2, 1.54401E2, 1.49601E2);
        ctx.bezierCurveTo(1.61401E2, 1.47001E2, 1.58801E2, 1.36201E2, 1.58801E2, 1.36201E2);
        ctx.bezierCurveTo(1.62801E2, 1.34801E2, 1.51601E2, 1.32001E2, 1.51801E2, 1.30801E2);
        ctx.bezierCurveTo(1.52001E2, 1.29601E2, 1.57801E2, 1.28201E2, 1.57801E2, 1.28201E2);
        ctx.bezierCurveTo(1.65801E2, 1.26201E2, 1.61401E2, 1.23801E2, 1.61401E2, 1.23801E2);
        ctx.bezierCurveTo(1.60801E2, 1.19801E2, 1.63801E2, 1.14201E2, 1.63801E2, 1.14201E2);
        ctx.bezierCurveTo(1.75401E2, 1.13401E2, 1.63801E2, 9.72E1, 1.63801E2, 9.72E1);
        ctx.bezierCurveTo(1.53001E2, 8.96E1, 1.52001E2, 8.38E1, 1.52001E2, 8.38E1);
        ctx.bezierCurveTo(1.64601E2, 7.56E1, 1.56401E2, 6.32E1, 1.56601E2, 5.96E1);
        ctx.bezierCurveTo(1.56801E2, 5.6E1, 1.58001E2, 3.44E1, 1.58001E2, 3.44E1);
        ctx.bezierCurveTo(1.56001E2, 2.82E1, 1.53001E2, 1.46E1, 1.53001E2, 1.46E1);
        ctx.bezierCurveTo(1.55201E2, 9.4E0, 1.62601E2, (-3.2), 1.62601E2, (-3.2));
        ctx.bezierCurveTo(1.65401E2, (-7.4), 1.74201E2, (-12.2), 1.72001E2, (-15.2));
        ctx.bezierCurveTo(1.69801E2, (-18.2), 1.62001E2, (-16.4), 1.62001E2, (-16.4));
        ctx.bezierCurveTo(1.54201E2, (-17.8), 1.54801E2, (-12.6), 1.54801E2, (-12.6));
        ctx.bezierCurveTo(1.53201E2, (-11.6), 1.52401E2, (-6.6), 1.52401E2, (-6.6));
        ctx.bezierCurveTo(1.5168E2, 1.333E0, 1.42801E2, 7.6E0, 1.42801E2, 7.6E0);
        ctx.bezierCurveTo(1.31601E2, 1.38E1, 1.40801E2, 1.78E1, 1.40801E2, 1.78E1);
        ctx.bezierCurveTo(1.46801E2, 2.44E1, 1.37001E2, 2.46E1, 1.37001E2, 2.46E1);
        ctx.bezierCurveTo(1.26001E2, 2.28E1, 1.34201E2, 3.3E1, 1.34201E2, 3.3E1);
        ctx.bezierCurveTo(1.45001E2, 4.58E1, 1.42001E2, 4.86E1, 1.42001E2, 4.86E1);
        ctx.bezierCurveTo(1.31801E2, 4.96E1, 1.44401E2, 5.88E1, 1.44401E2, 5.88E1);
        ctx.bezierCurveTo(1.44401E2, 5.88E1, 1.43601E2, 5.68E1, 1.43801E2, 5.86E1);
        ctx.bezierCurveTo(1.44001E2, 6.04E1, 1.47001E2, 6.46E1, 1.47801E2, 6.66E1);
        ctx.bezierCurveTo(1.48601E2, 6.86E1, 1.44601E2, 6.88E1, 1.44601E2, 6.88E1);
        ctx.bezierCurveTo(1.45201E2, 7.84E1, 1.29801E2, 7.42E1, 1.29801E2, 7.42E1);
        ctx.bezierCurveTo(1.29801E2, 7.42E1, 1.29801E2, 7.42E1, 1.28201E2, 7.44E1);
        ctx.bezierCurveTo(1.26601E2, 7.46E1, 1.15401E2, 7.38E1, 1.09601E2, 7.16E1);
        ctx.bezierCurveTo(1.03801E2, 6.94E1, 9.7001E1, 6.94E1, 9.7001E1, 6.94E1);
        ctx.bezierCurveTo(9.7001E1, 6.94E1, 9.3001E1, 7.12E1, 8.54E1, 7.1E1);
        ctx.bezierCurveTo(7.78E1, 7.08E1, 6.98E1, 7.36E1, 6.98E1, 7.36E1);
        ctx.bezierCurveTo(6.54E1, 7.32E1, 7.4E1, 6.88E1, 7.42E1, 6.9E1);
        ctx.bezierCurveTo(7.44E1, 6.92E1, 8E1, 6.36E1, 7.2E1, 6.42E1);
        ctx.bezierCurveTo(5.0203E1, 6.5835E1, 3.94E1, 5.56E1, 3.94E1, 5.56E1);
        ctx.bezierCurveTo(3.74E1, 5.42E1, 3.48E1, 5.14E1, 3.48E1, 5.14E1);
        ctx.bezierCurveTo(2.48E1, 4.94E1, 3.62E1, 6.38E1, 3.62E1, 6.38E1);
        ctx.bezierCurveTo(3.74E1, 6.52E1, 3.6E1, 6.62E1, 3.6E1, 6.62E1);
        ctx.bezierCurveTo(3.52E1, 6.46E1, 2.74E1, 5.92E1, 2.74E1, 5.92E1);
        ctx.bezierCurveTo(2.4589E1, 5.8227E1, 2.3226E1, 5.6893E1, 2.0895E1, 5.4407E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#4c0000';
        ctx.fillStyle = 'rgba(76,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#4c0000';
        ctx.fillStyle = 'rgba(76,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-3), 4.28E1);
        ctx.bezierCurveTo((-3), 4.28E1, 8.6E0, 4.84E1, 1.12E1, 5.12E1);
        ctx.bezierCurveTo(1.38E1, 5.4E1, 2.78E1, 6.54E1, 2.78E1, 6.54E1);
        ctx.bezierCurveTo(2.78E1, 6.54E1, 2.24E1, 6.34E1, 1.98E1, 6.16E1);
        ctx.bezierCurveTo(1.72E1, 5.98E1, 6.4E0, 5.16E1, 6.4E0, 5.16E1);
        ctx.bezierCurveTo(6.4E0, 5.16E1, 2.6E0, 4.56E1, (-3), 4.28E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#99cc32';
        ctx.fillStyle = 'rgba(153,204,50,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-61.009), 1.1603E1);
        ctx.bezierCurveTo((-60.672), 1.1455E1, (-61.196), 8.743E0, (-61.4), 8.2E0);
        ctx.bezierCurveTo((-62.422), 5.474E0, (-71.4), 4E0, (-71.4), 4E0);
        ctx.bezierCurveTo((-71.627), 5.365E0, (-71.682), 6.961E0, (-71.576), 8.599E0);
        ctx.bezierCurveTo((-71.576), 8.599E0, (-66.708), 1.4118E1, (-61.009), 1.1603E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#659900';
        ctx.fillStyle = 'rgba(101,153,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#659900';
        ctx.fillStyle = 'rgba(101,153,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-61.009), 1.1403E1);
        ctx.bezierCurveTo((-61.458), 1.1561E1, (-61.024), 8.669E0, (-61.2), 8.2E0);
        ctx.bezierCurveTo((-62.222), 5.474E0, (-71.4), 3.9E0, (-71.4), 3.9E0);
        ctx.bezierCurveTo((-71.627), 5.265E0, (-71.682), 6.861E0, (-71.576), 8.499E0);
        ctx.bezierCurveTo((-71.576), 8.499E0, (-67.308), 1.3618E1, (-61.009), 1.1403E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-65.4), 1.1546E1);
        ctx.bezierCurveTo((-66.025), 1.1546E1, (-66.531), 1.0406E1, (-66.531), 9E0);
        ctx.bezierCurveTo((-66.531), 7.595E0, (-66.025), 6.455E0, (-65.4), 6.455E0);
        ctx.bezierCurveTo((-64.775), 6.455E0, (-64.268), 7.595E0, (-64.268), 9E0);
        ctx.bezierCurveTo((-64.268), 1.0406E1, (-64.775), 1.1546E1, (-65.4), 1.1546E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-65.4), 9E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-111), 1.09601E2);
        ctx.bezierCurveTo((-111), 1.09601E2, (-116.6), 1.19601E2, (-91.8), 1.13601E2);
        ctx.bezierCurveTo((-91.8), 1.13601E2, (-77.8), 1.12401E2, (-75.4), 1.10001E2);
        ctx.bezierCurveTo((-74.2), 1.10801E2, (-65.834), 1.13734E2, (-63), 1.14401E2);
        ctx.bezierCurveTo((-56.2), 1.16001E2, (-47.8), 1.06E2, (-47.8), 1.06E2);
        ctx.bezierCurveTo((-47.8), 1.06E2, (-43.2), 9.55E1, (-40.4), 9.55E1);
        ctx.bezierCurveTo((-37.6), 9.55E1, (-40.8), 9.71E1, (-40.8), 9.71E1);
        ctx.bezierCurveTo((-40.8), 9.71E1, (-47.4), 1.07201E2, (-47), 1.08801E2);
        ctx.bezierCurveTo((-47), 1.08801E2, (-52.2), 1.28801E2, (-68.2), 1.29601E2);
        ctx.bezierCurveTo((-68.2), 1.29601E2, (-84.35), 1.30551E2, (-83), 1.36401E2);
        ctx.bezierCurveTo((-83), 1.36401E2, (-74.2), 1.34001E2, (-71.8), 1.36401E2);
        ctx.bezierCurveTo((-71.8), 1.36401E2, (-61), 1.36001E2, (-69), 1.42401E2);
        ctx.lineTo((-75.8), 1.54001E2);
        ctx.bezierCurveTo((-75.8), 1.54001E2, (-75.66), 1.57919E2, (-85.8), 1.54401E2);
        ctx.bezierCurveTo((-95.6), 1.51001E2, (-105.9), 1.38101E2, (-105.9), 1.38101E2);
        ctx.bezierCurveTo((-105.9), 1.38101E2, (-121.85), 1.23551E2, (-111), 1.09601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#e59999';
        ctx.fillStyle = 'rgba(229,153,153,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#e59999';
        ctx.fillStyle = 'rgba(229,153,153,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-112.2), 1.13601E2);
        ctx.bezierCurveTo((-112.2), 1.13601E2, (-114.2), 1.23201E2, (-77.4), 1.12801E2);
        ctx.bezierCurveTo((-77.4), 1.12801E2, (-73), 1.12801E2, (-70.6), 1.13601E2);
        ctx.bezierCurveTo((-68.2), 1.14401E2, (-56.2), 1.17201E2, (-54.2), 1.16001E2);
        ctx.bezierCurveTo((-54.2), 1.16001E2, (-61.4), 1.29601E2, (-73), 1.28001E2);
        ctx.bezierCurveTo((-73), 1.28001E2, (-86.2), 1.29601E2, (-85.8), 1.34401E2);
        ctx.bezierCurveTo((-85.8), 1.34401E2, (-81.8), 1.41601E2, (-77), 1.44001E2);
        ctx.bezierCurveTo((-77), 1.44001E2, (-74.2), 1.46401E2, (-74.6), 1.49601E2);
        ctx.bezierCurveTo((-75), 1.52801E2, (-77.8), 1.54401E2, (-79.8), 1.55201E2);
        ctx.bezierCurveTo((-81.8), 1.56001E2, (-85), 1.52801E2, (-86.6), 1.52801E2);
        ctx.bezierCurveTo((-88.2), 1.52801E2, (-96.6), 1.46401E2, (-101), 1.41601E2);
        ctx.bezierCurveTo((-105.4), 1.36801E2, (-113.8), 1.24801E2, (-113.4), 1.22001E2);
        ctx.bezierCurveTo((-113), 1.19201E2, (-112.2), 1.13601E2, (-112.2), 1.13601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#b26565';
        ctx.fillStyle = 'rgba(178,101,101,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#b26565';
        ctx.fillStyle = 'rgba(178,101,101,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-109), 1.31051E2);
        ctx.bezierCurveTo((-106.4), 1.35001E2, (-103.2), 1.39201E2, (-101), 1.41601E2);
        ctx.bezierCurveTo((-96.6), 1.46401E2, (-88.2), 1.52801E2, (-86.6), 1.52801E2);
        ctx.bezierCurveTo((-85), 1.52801E2, (-81.8), 1.56001E2, (-79.8), 1.55201E2);
        ctx.bezierCurveTo((-77.8), 1.54401E2, (-75), 1.52801E2, (-74.6), 1.49601E2);
        ctx.bezierCurveTo((-74.2), 1.46401E2, (-77), 1.44001E2, (-77), 1.44001E2);
        ctx.bezierCurveTo((-80.066), 1.42468E2, (-82.806), 1.38976E2, (-84.385), 1.36653E2);
        ctx.bezierCurveTo((-84.385), 1.36653E2, (-84.2), 1.39201E2, (-89.4), 1.38401E2);
        ctx.bezierCurveTo((-94.6), 1.37601E2, (-99.8), 1.34801E2, (-101.4), 1.31601E2);
        ctx.bezierCurveTo((-103), 1.28401E2, (-105.4), 1.26001E2, (-103.8), 1.29601E2);
        ctx.bezierCurveTo((-102.2), 1.33201E2, (-99.8), 1.36801E2, (-98.2), 1.37201E2);
        ctx.bezierCurveTo((-96.6), 1.37601E2, (-97), 1.38801E2, (-99.4), 1.38401E2);
        ctx.bezierCurveTo((-101.8), 1.38001E2, (-104.6), 1.37601E2, (-109), 1.32401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-111.6), 1.10001E2);
        ctx.bezierCurveTo((-111.6), 1.10001E2, (-109.8), 9.64E1, (-108.6), 9.24E1);
        ctx.bezierCurveTo((-108.6), 9.24E1, (-109.4), 8.56E1, (-107), 8.14E1);
        ctx.bezierCurveTo((-104.6), 7.72E1, (-102.6), 7.1E1, (-99.6), 6.56E1);
        ctx.bezierCurveTo((-96.6), 6.02E1, (-96.4), 5.62E1, (-92.4), 5.46E1);
        ctx.bezierCurveTo((-88.4), 5.3E1, (-82.4), 4.44E1, (-79.6), 4.34E1);
        ctx.bezierCurveTo((-76.8), 4.24E1, (-77), 4.32E1, (-77), 4.32E1);
        ctx.bezierCurveTo((-77), 4.32E1, (-70.2), 2.84E1, (-56.6), 3.24E1);
        ctx.bezierCurveTo((-56.6), 3.24E1, (-72.8), 2.96E1, (-57), 2.02E1);
        ctx.bezierCurveTo((-57), 2.02E1, (-61.8), 2.13E1, (-58.5), 1.43E1);
        ctx.bezierCurveTo((-56.299), 9.632E0, (-56.8), 1.64E1, (-67.8), 2.82E1);
        ctx.bezierCurveTo((-67.8), 2.82E1, (-72.8), 3.68E1, (-78), 3.98E1);
        ctx.bezierCurveTo((-83.2), 4.28E1, (-95.2), 4.98E1, (-96.4), 5.36E1);
        ctx.bezierCurveTo((-97.6), 5.74E1, (-100.8), 6.32E1, (-102.8), 6.48E1);
        ctx.bezierCurveTo((-104.8), 6.64E1, (-107.6), 7.06E1, (-108), 7.4E1);
        ctx.bezierCurveTo((-108), 7.4E1, (-109.2), 7.8E1, (-110.6), 7.92E1);
        ctx.bezierCurveTo((-112), 8.04E1, (-112.2), 8.36E1, (-112.2), 8.56E1);
        ctx.bezierCurveTo((-112.2), 8.76E1, (-114.2), 9.04E1, (-114), 9.28E1);
        ctx.bezierCurveTo((-114), 9.28E1, (-113.2), 1.11801E2, (-113.6), 1.13801E2);
        ctx.lineTo((-111.6), 1.10001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-120.2), 1.14601E2);
        ctx.bezierCurveTo((-120.2), 1.14601E2, (-122.2), 1.13201E2, (-126.6), 1.19201E2);
        ctx.bezierCurveTo((-126.6), 1.19201E2, (-119.3), 1.52201E2, (-119.3), 1.53601E2);
        ctx.bezierCurveTo((-119.3), 1.53601E2, (-118.2), 1.51501E2, (-119.5), 1.44301E2);
        ctx.bezierCurveTo((-120.8), 1.37101E2, (-121.7), 1.24401E2, (-121.7), 1.24401E2);
        ctx.lineTo((-120.2), 1.14601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-98.6), 5.4E1);
        ctx.bezierCurveTo((-98.6), 5.4E1, (-116.2), 5.72E1, (-115.8), 8.64E1);
        ctx.lineTo((-116.6), 1.11201E2);
        ctx.bezierCurveTo((-116.6), 1.11201E2, (-117.8), 8.56E1, (-119), 8.4E1);
        ctx.bezierCurveTo((-120.2), 8.24E1, (-116.2), 7.12E1, (-119.4), 7.72E1);
        ctx.bezierCurveTo((-119.4), 7.72E1, (-133.4), 9.12E1, (-125.4), 1.12401E2);
        ctx.bezierCurveTo((-125.4), 1.12401E2, (-123.9), 1.15701E2, (-126.9), 1.11101E2);
        ctx.bezierCurveTo((-126.9), 1.11101E2, (-131.5), 9.85E1, (-130.4), 9.21E1);
        ctx.bezierCurveTo((-130.4), 9.21E1, (-130.2), 8.99E1, (-128.3), 8.71E1);
        ctx.bezierCurveTo((-128.3), 8.71E1, (-119.7), 7.54E1, (-117), 7.31E1);
        ctx.bezierCurveTo((-117), 7.31E1, (-115.2), 5.87E1, (-99.8), 5.35E1);
        ctx.bezierCurveTo((-99.8), 5.35E1, (-94.1), 5.12E1, (-98.6), 5.4E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.08E1, (-12.2));
        ctx.bezierCurveTo(4.146E1, (-12.554), 4.1451E1, (-13.524), 4.2031E1, (-13.697));
        ctx.bezierCurveTo(4.318E1, (-14.041), 4.3344E1, (-15.108), 4.3862E1, (-15.892));
        ctx.bezierCurveTo(4.4735E1, (-17.211), 4.4928E1, (-18.744), 4.551E1, (-20.235));
        ctx.bezierCurveTo(4.5782E1, (-20.935), 4.5809E1, (-21.89), 4.5496E1, (-22.55));
        ctx.bezierCurveTo(4.4322E1, (-25.031), 4.362E1, (-27.48), 4.2178E1, (-29.906));
        ctx.bezierCurveTo(4.191E1, (-30.356), 4.1648E1, (-31.15), 4.1447E1, (-31.748));
        ctx.bezierCurveTo(4.0984E1, (-33.132), 3.9727E1, (-34.123), 3.8867E1, (-35.443));
        ctx.bezierCurveTo(3.8579E1, (-35.884), 3.9104E1, (-36.809), 3.8388E1, (-36.893));
        ctx.bezierCurveTo(3.7491E1, (-36.998), 3.6042E1, (-37.578), 3.5809E1, (-36.552));
        ctx.bezierCurveTo(3.5221E1, (-33.965), 3.6232E1, (-31.442), 3.72E1, (-29));
        ctx.bezierCurveTo(3.6418E1, (-28.308), 3.6752E1, (-27.387), 3.6904E1, (-26.62));
        ctx.bezierCurveTo(3.7614E1, (-23.014), 3.6416E1, (-19.662), 3.5655E1, (-16.188));
        ctx.bezierCurveTo(3.5632E1, (-16.084), 3.5974E1, (-15.886), 3.5946E1, (-15.824));
        ctx.bezierCurveTo(3.4724E1, (-13.138), 3.3272E1, (-10.693), 3.1453E1, (-8.312));
        ctx.bezierCurveTo(3.0695E1, (-7.32), 2.9823E1, (-6.404), 2.9326E1, (-5.341));
        ctx.bezierCurveTo(2.8958E1, (-4.554), 2.855E1, (-3.588), 2.88E1, (-2.6));
        ctx.bezierCurveTo(2.5365E1, 1.8E-1, 2.3115E1, 4.025E0, 2.0504E1, 7.871E0);
        ctx.bezierCurveTo(2.0042E1, 8.551E0, 2.0333E1, 9.76E0, 2.0884E1, 1.0029E1);
        ctx.bezierCurveTo(2.1697E1, 1.0427E1, 2.2653E1, 9.403E0, 2.3123E1, 8.557E0);
        ctx.bezierCurveTo(2.3512E1, 7.859E0, 2.3865E1, 7.209E0, 2.4356E1, 6.566E0);
        ctx.bezierCurveTo(2.4489E1, 6.391E0, 2.431E1, 5.972E0, 2.4445E1, 5.851E0);
        ctx.bezierCurveTo(2.7078E1, 3.504E0, 2.8747E1, 5.68E-1, 3.12E1, (-1.8));
        ctx.bezierCurveTo(3.315E1, (-2.129), 3.4687E1, (-3.127), 3.6435E1, (-4.14));
        ctx.bezierCurveTo(3.6743E1, (-4.319), 3.7267E1, (-4.07), 3.7557E1, (-4.265));
        ctx.bezierCurveTo(3.931E1, (-5.442), 3.9308E1, (-7.478), 3.9414E1, (-9.388));
        ctx.bezierCurveTo(3.9464E1, (-10.272), 3.966E1, (-11.589), 4.08E1, (-12.2));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.1959E1, (-16.666));
        ctx.bezierCurveTo(3.2083E1, (-16.743), 3.1928E1, (-17.166), 3.2037E1, (-17.382));
        ctx.bezierCurveTo(3.2199E1, (-17.706), 3.2602E1, (-17.894), 3.2764E1, (-18.218));
        ctx.bezierCurveTo(3.2873E1, (-18.434), 3.271E1, (-18.814), 3.2846E1, (-18.956));
        ctx.bezierCurveTo(3.5179E1, (-21.403), 3.5436E1, (-24.427), 3.44E1, (-27.4));
        ctx.bezierCurveTo(3.5424E1, (-28.02), 3.5485E1, (-29.282), 3.506E1, (-30.129));
        ctx.bezierCurveTo(3.4207E1, (-31.829), 3.4014E1, (-33.755), 3.3039E1, (-35.298));
        ctx.bezierCurveTo(3.2237E1, (-36.567), 3.0659E1, (-37.811), 2.9288E1, (-36.508));
        ctx.bezierCurveTo(2.8867E1, (-36.108), 2.8546E1, (-35.321), 2.8824E1, (-34.609));
        ctx.bezierCurveTo(2.8888E1, (-34.446), 2.9173E1, (-34.3), 2.9146E1, (-34.218));
        ctx.bezierCurveTo(2.9039E1, (-33.894), 2.8493E1, (-33.67), 2.8487E1, (-33.398));
        ctx.bezierCurveTo(2.8457E1, (-31.902), 2.7503E1, (-30.391), 2.8133E1, (-29.062));
        ctx.bezierCurveTo(2.8905E1, (-27.433), 2.9724E1, (-25.576), 3.04E1, (-23.8));
        ctx.bezierCurveTo(2.9166E1, (-21.684), 3.0199E1, (-19.235), 2.8446E1, (-17.358));
        ctx.bezierCurveTo(2.831E1, (-17.212), 2.8319E1, (-16.826), 2.8441E1, (-16.624));
        ctx.bezierCurveTo(2.8733E1, (-16.138), 2.9139E1, (-15.732), 2.9625E1, (-15.44));
        ctx.bezierCurveTo(2.9827E1, (-15.319), 3.0175E1, (-15.317), 3.0375E1, (-15.441));
        ctx.bezierCurveTo(3.0953E1, (-15.803), 3.1351E1, (-16.29), 3.1959E1, (-16.666));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.4771E1, (-26.977));
        ctx.bezierCurveTo(9.616E1, (-25.185), 9.645E1, (-22.39), 9.4401E1, (-21));
        ctx.bezierCurveTo(9.4951E1, (-17.691), 9.8302E1, (-19.67), 1.00401E2, (-20.2));
        ctx.bezierCurveTo(1.00292E2, (-20.588), 1.00519E2, (-20.932), 1.00802E2, (-20.937));
        ctx.bezierCurveTo(1.01859E2, (-20.952), 1.02539E2, (-21.984), 1.03601E2, (-21.8));
        ctx.bezierCurveTo(1.04035E2, (-23.357), 1.05673E2, (-24.059), 1.06317E2, (-25.439));
        ctx.bezierCurveTo(1.08043E2, (-29.134), 1.07452E2, (-33.407), 1.04868E2, (-36.653));
        ctx.bezierCurveTo(1.04666E2, (-36.907), 1.04883E2, (-37.424), 1.04759E2, (-37.786));
        ctx.bezierCurveTo(1.04003E2, (-39.997), 1.01935E2, (-40.312), 1.00001E2, (-41));
        ctx.bezierCurveTo(9.8824E1, (-44.875), 9.8163E1, (-48.906), 9.6401E1, (-52.6));
        ctx.bezierCurveTo(9.4787E1, (-52.85), 9.4089E1, (-54.589), 9.2752E1, (-55.309));
        ctx.bezierCurveTo(9.1419E1, (-56.028), 9.0851E1, (-54.449), 9.0892E1, (-53.403));
        ctx.bezierCurveTo(9.0899E1, (-53.198), 9.1351E1, (-52.974), 9.1181E1, (-52.609));
        ctx.bezierCurveTo(9.1105E1, (-52.445), 9.0845E1, (-52.334), 9.0845E1, (-52.2));
        ctx.bezierCurveTo(9.0846E1, (-52.065), 9.1067E1, (-51.934), 9.1201E1, (-51.8));
        ctx.bezierCurveTo(9.0283E1, (-50.98), 8.886E1, (-50.503), 8.8565E1, (-49.358));
        ctx.bezierCurveTo(8.7611E1, (-45.648), 9.0184E1, (-42.523), 9.1852E1, (-39.322));
        ctx.bezierCurveTo(9.2443E1, (-38.187), 9.1707E1, (-36.916), 9.0947E1, (-35.708));
        ctx.bezierCurveTo(9.0509E1, (-35.013), 9.0617E1, (-33.886), 9.0893E1, (-33.03));
        ctx.bezierCurveTo(9.1645E1, (-30.699), 9.3236E1, (-28.96), 9.4771E1, (-26.977));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.7611E1, (-8.591));
        ctx.bezierCurveTo(5.6124E1, (-6.74), 5.2712E1, (-4.171), 5.5629E1, (-2.243));
        ctx.bezierCurveTo(5.5823E1, (-2.114), 5.6193E1, (-2.11), 5.6366E1, (-2.244));
        ctx.bezierCurveTo(5.8387E1, (-3.809), 6.039E1, (-4.712), 6.2826E1, (-5.294));
        ctx.bezierCurveTo(6.295E1, (-5.323), 6.3224E1, (-4.856), 6.3593E1, (-5.017));
        ctx.bezierCurveTo(6.5206E1, (-5.72), 6.7216E1, (-5.662), 6.84E1, (-7));
        ctx.bezierCurveTo(7.2167E1, (-6.776), 7.5732E1, (-7.892), 7.9123E1, (-9.2));
        ctx.bezierCurveTo(8.0284E1, (-9.648), 8.1554E1, (-10.207), 8.2755E1, (-10.709));
        ctx.bezierCurveTo(8.4131E1, (-11.285), 8.5335E1, (-12.213), 8.6447E1, (-13.354));
        ctx.bezierCurveTo(8.658E1, (-13.49), 8.6934E1, (-13.4), 8.7201E1, (-13.4));
        ctx.bezierCurveTo(8.7161E1, (-14.263), 8.8123E1, (-14.39), 8.837E1, (-15.012));
        ctx.bezierCurveTo(8.8462E1, (-15.244), 8.8312E1, (-15.64), 8.8445E1, (-15.742));
        ctx.bezierCurveTo(9.0583E1, (-17.372), 9.1503E1, (-19.39), 9.0334E1, (-21.767));
        ctx.bezierCurveTo(9.0049E1, (-22.345), 8.98E1, (-22.963), 8.9234E1, (-23.439));
        ctx.bezierCurveTo(8.8149E1, (-24.35), 8.7047E1, (-23.496), 8.6E1, (-23.8));
        ctx.bezierCurveTo(8.5841E1, (-23.172), 8.5112E1, (-23.344), 8.4726E1, (-23.146));
        ctx.bezierCurveTo(8.3867E1, (-22.707), 8.2534E1, (-23.292), 8.1675E1, (-22.854));
        ctx.bezierCurveTo(8.0313E1, (-22.159), 7.9072E1, (-21.99), 7.765E1, (-21.613));
        ctx.bezierCurveTo(7.7338E1, (-21.531), 7.656E1, (-21.627), 7.64E1, (-21));
        ctx.bezierCurveTo(7.6266E1, (-21.134), 7.6118E1, (-21.368), 7.6012E1, (-21.346));
        ctx.bezierCurveTo(7.4104E1, (-20.95), 7.2844E1, (-20.736), 7.1543E1, (-19.044));
        ctx.bezierCurveTo(7.144E1, (-18.911), 7.0998E1, (-19.09), 7.0839E1, (-18.955));
        ctx.bezierCurveTo(6.9882E1, (-18.147), 6.9477E1, (-16.913), 6.8376E1, (-16.241));
        ctx.bezierCurveTo(6.8175E1, (-16.118), 6.7823E1, (-16.286), 6.7629E1, (-16.157));
        ctx.bezierCurveTo(6.6983E1, (-15.726), 6.6616E1, (-15.085), 6.5974E1, (-14.638));
        ctx.bezierCurveTo(6.5645E1, (-14.409), 6.5245E1, (-14.734), 6.5277E1, (-14.99));
        ctx.bezierCurveTo(6.5522E1, (-16.937), 6.6175E1, (-18.724), 6.56E1, (-20.6));
        ctx.bezierCurveTo(6.7677E1, (-23.12), 7.0194E1, (-25.069), 7.2E1, (-27.8));
        ctx.bezierCurveTo(7.2015E1, (-29.966), 7.2707E1, (-32.112), 7.2594E1, (-34.189));
        ctx.bezierCurveTo(7.2584E1, (-34.382), 7.2296E1, (-35.115), 7.217E1, (-35.462));
        ctx.bezierCurveTo(7.1858E1, (-36.316), 7.2764E1, (-37.382), 7.192E1, (-38.106));
        ctx.bezierCurveTo(7.0516E1, (-39.309), 6.9224E1, (-38.433), 6.84E1, (-37));
        ctx.bezierCurveTo(6.6562E1, (-36.61), 6.4496E1, (-35.917), 6.2918E1, (-37.151));
        ctx.bezierCurveTo(6.1911E1, (-37.938), 6.1333E1, (-38.844), 6.0534E1, (-39.9));
        ctx.bezierCurveTo(5.9549E1, (-41.202), 5.9884E1, (-42.638), 5.9954E1, (-44.202));
        ctx.bezierCurveTo(5.996E1, (-44.33), 5.9645E1, (-44.466), 5.9645E1, (-44.6));
        ctx.bezierCurveTo(5.9646E1, (-44.735), 5.9866E1, (-44.866), 6E1, (-45));
        ctx.bezierCurveTo(5.9294E1, (-45.626), 5.9019E1, (-46.684), 5.8E1, (-47));
        ctx.bezierCurveTo(5.8305E1, (-48.092), 5.7629E1, (-48.976), 5.6758E1, (-49.278));
        ctx.bezierCurveTo(5.4763E1, (-49.969), 5.3086E1, (-48.057), 5.1194E1, (-47.984));
        ctx.bezierCurveTo(5.068E1, (-47.965), 5.0213E1, (-49.003), 4.9564E1, (-49.328));
        ctx.bezierCurveTo(4.9132E1, (-49.544), 4.8428E1, (-49.577), 4.8066E1, (-49.311));
        ctx.bezierCurveTo(4.7378E1, (-48.807), 4.6789E1, (-48.693), 4.6031E1, (-48.488));
        ctx.bezierCurveTo(4.4414E1, (-48.052), 4.3136E1, (-46.958), 4.1656E1, (-46.103));
        ctx.bezierCurveTo(4.0171E1, (-45.246), 3.9216E1, (-43.809), 3.8136E1, (-42.489));
        ctx.bezierCurveTo(3.7195E1, (-41.337), 3.7059E1, (-38.923), 3.8479E1, (-38.423));
        ctx.bezierCurveTo(4.0322E1, (-37.773), 4.1626E1, (-40.476), 4.3592E1, (-40.15));
        ctx.bezierCurveTo(4.3904E1, (-40.099), 4.411E1, (-39.788), 4.4E1, (-39.4));
        ctx.bezierCurveTo(4.4389E1, (-39.291), 4.4607E1, (-39.52), 4.48E1, (-39.8));
        ctx.bezierCurveTo(4.5658E1, (-38.781), 4.6822E1, (-38.444), 4.776E1, (-37.571));
        ctx.bezierCurveTo(4.873E1, (-36.667), 5.0476E1, (-37.085), 5.1491E1, (-36.088));
        ctx.bezierCurveTo(5.302E1, (-34.586), 5.2461E1, (-31.905), 5.44E1, (-30.6));
        ctx.bezierCurveTo(5.3814E1, (-29.287), 5.3207E1, (-28.01), 5.2872E1, (-26.583));
        ctx.bezierCurveTo(5.259E1, (-25.377), 5.3584E1, (-24.18), 5.4795E1, (-24.271));
        ctx.bezierCurveTo(5.6053E1, (-24.365), 5.6315E1, (-25.124), 5.68E1, (-26.2));
        ctx.bezierCurveTo(5.7067E1, (-25.933), 5.7536E1, (-25.636), 5.7495E1, (-25.42));
        ctx.bezierCurveTo(5.7038E1, (-23.033), 5.6011E1, (-21.04), 5.5553E1, (-18.609));
        ctx.bezierCurveTo(5.5494E1, (-18.292), 5.5189E1, (-18.09), 5.48E1, (-18.2));
        ctx.bezierCurveTo(5.4332E1, (-14.051), 5.028E1, (-11.657), 4.7735E1, (-8.492));
        ctx.bezierCurveTo(4.7332E1, (-7.99), 4.7328E1, (-6.741), 4.7737E1, (-6.338));
        ctx.bezierCurveTo(4.914E1, (-4.951), 5.11E1, (-6.497), 5.28E1, (-7));
        ctx.bezierCurveTo(5.3013E1, (-8.206), 5.3872E1, (-9.148), 5.5204E1, (-9.092));
        ctx.bezierCurveTo(5.546E1, (-9.082), 5.5695E1, (-9.624), 5.6019E1, (-9.754));
        ctx.bezierCurveTo(5.6367E1, (-9.892), 5.6869E1, (-9.668), 5.7155E1, (-9.866));
        ctx.bezierCurveTo(5.8884E1, (-11.061), 6.0292E1, (-12.167), 6.203E1, (-13.356));
        ctx.bezierCurveTo(6.2222E1, (-13.487), 6.2566E1, (-13.328), 6.2782E1, (-13.436));
        ctx.bezierCurveTo(6.3107E1, (-13.598), 6.3294E1, (-13.985), 6.3617E1, (-14.17));
        ctx.bezierCurveTo(6.3965E1, (-14.37), 6.4207E1, (-14.08), 6.44E1, (-13.8));
        ctx.bezierCurveTo(6.3754E1, (-13.451), 6.375E1, (-12.494), 6.3168E1, (-12.292));
        ctx.bezierCurveTo(6.2393E1, (-12.024), 6.1832E1, (-11.511), 6.1158E1, (-11.064));
        ctx.bezierCurveTo(6.0866E1, (-10.871), 6.0207E1, (-11.119), 6.0103E1, (-10.94));
        ctx.bezierCurveTo(5.9505E1, (-9.912), 5.8321E1, (-9.474), 5.7611E1, (-8.591));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.2E0, (-58));
        ctx.bezierCurveTo(2.2E0, (-58), (-7.038), (-60.872), (-18.2), (-35.2));
        ctx.bezierCurveTo((-18.2), (-35.2), (-20.6), (-30), (-23), (-28));
        ctx.bezierCurveTo((-25.4), (-26), (-36.6), (-22.4), (-38.6), (-18.4));
        ctx.lineTo((-49), (-2.4));
        ctx.bezierCurveTo((-49), (-2.4), (-34.2), (-18.4), (-31), (-20.8));
        ctx.bezierCurveTo((-31), (-20.8), (-23), (-29.2), (-26.2), (-22.4));
        ctx.bezierCurveTo((-26.2), (-22.4), (-40.2), (-11.6), (-39), (-2.4));
        ctx.bezierCurveTo((-39), (-2.4), (-44.6), 1.2E1, (-45.4), 1.4E1);
        ctx.bezierCurveTo((-45.4), 1.4E1, (-29.4), (-18), (-27), (-19.2));
        ctx.bezierCurveTo((-24.6), (-20.4), (-23.4), (-20.4), (-24.6), (-16.8));
        ctx.bezierCurveTo((-25.8), (-13.2), (-26.2), 3.2E0, (-29), 5.2E0);
        ctx.bezierCurveTo((-29), 5.2E0, (-21), (-15.2), (-21.8), (-18.4));
        ctx.bezierCurveTo((-21.8), (-18.4), (-18.6), (-22), (-16.2), (-16.8));
        ctx.lineTo((-17.4), (-0.8));
        ctx.lineTo((-13), 1.12E1);
        ctx.bezierCurveTo((-13), 1.12E1, (-15.4), 0E0, (-13.8), (-15.6));
        ctx.bezierCurveTo((-13.8), (-15.6), (-15.8), (-26), (-11.8), (-20.4));
        ctx.bezierCurveTo((-7.8), (-14.8), 1.8E0, (-8.8), 1.8E0, (-4));
        ctx.bezierCurveTo(1.8E0, (-4), (-3.4), (-21.6), (-12.6), (-26.4));
        ctx.lineTo((-16.6), (-20.4));
        ctx.lineTo((-17.8), (-22.4));
        ctx.bezierCurveTo((-17.8), (-22.4), (-21.4), (-23.2), (-17), (-30));
        ctx.bezierCurveTo((-12.6), (-36.8), (-13), (-37.6), (-13), (-37.6));
        ctx.bezierCurveTo((-13), (-37.6), (-6.6), (-30.4), (-5), (-30.4));
        ctx.bezierCurveTo((-5), (-30.4), 8.2E0, (-38), 9.4E0, (-13.6));
        ctx.bezierCurveTo(9.4E0, (-13.6), 1.62E1, (-28), 7E0, (-34.8));
        ctx.bezierCurveTo(7E0, (-34.8), (-7.8), (-36.8), (-6.6), (-42));
        ctx.lineTo(6E-1, (-54.4));
        ctx.bezierCurveTo(4.2E0, (-59.6), 2.6E0, (-56.8), 2.6E0, (-56.8));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-17.8), (-41.6));
        ctx.bezierCurveTo((-17.8), (-41.6), (-30.6), (-41.6), (-33.8), (-36.4));
        ctx.lineTo((-41), (-26.8));
        ctx.bezierCurveTo((-41), (-26.8), (-23.8), (-36.8), (-19.8), (-38));
        ctx.bezierCurveTo((-15.8), (-39.2), (-17.8), (-41.6), (-17.8), (-41.6));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-57.8), (-35.2));
        ctx.bezierCurveTo((-57.8), (-35.2), (-59.8), (-34), (-60.2), (-31.2));
        ctx.bezierCurveTo((-60.6), (-28.4), (-63), (-28), (-62.2), (-25.2));
        ctx.bezierCurveTo((-61.4), (-22.4), (-59.4), (-20), (-59.4), (-24));
        ctx.bezierCurveTo((-59.4), (-28), (-57.8), (-30), (-57), (-31.2));
        ctx.bezierCurveTo((-56.2), (-32.4), (-54.6), (-36.8), (-57.8), (-35.2));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-66.6), 2.6E1);
        ctx.bezierCurveTo((-66.6), 2.6E1, (-75), 2.2E1, (-78.2), 1.84E1);
        ctx.bezierCurveTo((-81.4), 1.48E1, (-80.948), 1.9966E1, (-85.8), 1.96E1);
        ctx.bezierCurveTo((-91.647), 1.9159E1, (-90.6), 3.2E0, (-90.6), 3.2E0);
        ctx.lineTo((-94.6), 1.08E1);
        ctx.bezierCurveTo((-94.6), 1.08E1, (-95.8), 2.52E1, (-87.8), 2.28E1);
        ctx.bezierCurveTo((-83.893), 2.1628E1, (-82.6), 2.32E1, (-84.2), 2.4E1);
        ctx.bezierCurveTo((-85.8), 2.48E1, (-78.6), 2.52E1, (-81.4), 2.68E1);
        ctx.bezierCurveTo((-84.2), 2.84E1, (-69.8), 2.32E1, (-72.2), 3.36E1);
        ctx.lineTo((-66.6), 2.6E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-79.2), 4.04E1);
        ctx.bezierCurveTo((-79.2), 4.04E1, (-94.6), 4.48E1, (-98.2), 3.52E1);
        ctx.bezierCurveTo((-98.2), 3.52E1, (-103), 3.76E1, (-100.8), 4.06E1);
        ctx.bezierCurveTo((-98.6), 4.36E1, (-97.4), 4.4E1, (-97.4), 4.4E1);
        ctx.bezierCurveTo((-97.4), 4.4E1, (-92), 4.52E1, (-92.6), 4.6E1);
        ctx.bezierCurveTo((-93.2), 4.68E1, (-95.6), 5.02E1, (-95.6), 5.02E1);
        ctx.bezierCurveTo((-95.6), 5.02E1, (-85.4), 4.42E1, (-79.2), 4.04E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.49201E2, 1.18601E2);
        ctx.bezierCurveTo(1.48774E2, 1.20735E2, 1.47103E2, 1.21536E2, 1.45201E2, 1.22201E2);
        ctx.bezierCurveTo(1.43284E2, 1.21243E2, 1.40686E2, 1.18137E2, 1.38801E2, 1.20201E2);
        ctx.bezierCurveTo(1.38327E2, 1.19721E2, 1.37548E2, 1.19661E2, 1.37204E2, 1.18999E2);
        ctx.bezierCurveTo(1.36739E2, 1.18101E2, 1.37011E2, 1.17055E2, 1.36669E2, 1.16257E2);
        ctx.bezierCurveTo(1.36124E2, 1.14985E2, 1.35415E2, 1.13619E2, 1.35601E2, 1.12201E2);
        ctx.bezierCurveTo(1.37407E2, 1.11489E2, 1.38002E2, 1.09583E2, 1.37528E2, 1.0782E2);
        ctx.bezierCurveTo(1.37459E2, 1.07563E2, 1.3703E2, 1.07366E2, 1.3723E2, 1.07017E2);
        ctx.bezierCurveTo(1.37416E2, 1.06694E2, 1.37734E2, 1.06467E2, 1.38001E2, 1.062E2);
        ctx.bezierCurveTo(1.37866E2, 1.06335E2, 1.37721E2, 1.06568E2, 1.3761E2, 1.06548E2);
        ctx.bezierCurveTo(1.37E2, 1.06442E2, 1.37124E2, 1.05805E2, 1.37254E2, 1.05418E2);
        ctx.bezierCurveTo(1.37839E2, 1.03672E2, 1.39853E2, 1.03408E2, 1.41201E2, 1.046E2);
        ctx.bezierCurveTo(1.41457E2, 1.04035E2, 1.41966E2, 1.04229E2, 1.42401E2, 1.042E2);
        ctx.bezierCurveTo(1.42351E2, 1.03621E2, 1.42759E2, 1.03094E2, 1.42957E2, 1.02674E2);
        ctx.bezierCurveTo(1.43475E2, 1.01576E2, 1.45104E2, 1.02682E2, 1.45901E2, 1.0207E2);
        ctx.bezierCurveTo(1.46977E2, 1.01245E2, 1.4804E2, 1.00546E2, 1.49118E2, 1.01149E2);
        ctx.bezierCurveTo(1.50927E2, 1.02162E2, 1.52636E2, 1.03374E2, 1.53835E2, 1.05115E2);
        ctx.bezierCurveTo(1.5441E2, 1.05949E2, 1.5465E2, 1.0723E2, 1.54592E2, 1.08188E2);
        ctx.bezierCurveTo(1.54554E2, 1.08835E2, 1.53173E2, 1.08483E2, 1.5283E2, 1.09412E2);
        ctx.bezierCurveTo(1.52185E2, 1.1116E2, 1.54016E2, 1.11679E2, 1.54772E2, 1.13017E2);
        ctx.bezierCurveTo(1.5497E2, 1.13366E2, 1.54706E2, 1.1367E2, 1.54391E2, 1.13768E2);
        ctx.bezierCurveTo(1.5398E2, 1.13896E2, 1.53196E2, 1.13707E2, 1.53334E2, 1.1416E2);
        ctx.bezierCurveTo(1.54306E2, 1.17353E2, 1.5155E2, 1.18031E2, 1.49201E2, 1.18601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.396E2, 1.38201E2);
        ctx.bezierCurveTo(1.39593E2, 1.36463E2, 1.37992E2, 1.34707E2, 1.39201E2, 1.33001E2);
        ctx.bezierCurveTo(1.39336E2, 1.33135E2, 1.39467E2, 1.33356E2, 1.39601E2, 1.33356E2);
        ctx.bezierCurveTo(1.39736E2, 1.33356E2, 1.39867E2, 1.33135E2, 1.40001E2, 1.33001E2);
        ctx.bezierCurveTo(1.41496E2, 1.35217E2, 1.45148E2, 1.36145E2, 1.45006E2, 1.38991E2);
        ctx.bezierCurveTo(1.44984E2, 1.39438E2, 1.43897E2, 1.40356E2, 1.44801E2, 1.41001E2);
        ctx.bezierCurveTo(1.42988E2, 1.42349E2, 1.42933E2, 1.44719E2, 1.42001E2, 1.46601E2);
        ctx.bezierCurveTo(1.40763E2, 1.46315E2, 1.39551E2, 1.45952E2, 1.38401E2, 1.45401E2);
        ctx.bezierCurveTo(1.38753E2, 1.43915E2, 1.38636E2, 1.42231E2, 1.39456E2, 1.40911E2);
        ctx.bezierCurveTo(1.3989E2, 1.40213E2, 1.39603E2, 1.39134E2, 1.396E2, 1.38201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-26.6), 1.29201E2);
        ctx.bezierCurveTo((-26.6), 1.29201E2, (-43.458), 1.39337E2, (-29.4), 1.24001E2);
        ctx.bezierCurveTo((-20.6), 1.14401E2, (-10.6), 1.08801E2, (-10.6), 1.08801E2);
        ctx.bezierCurveTo((-10.6), 1.08801E2, (-0.2), 1.044E2, 3.4E0, 1.032E2);
        ctx.bezierCurveTo(7E0, 1.02E2, 2.22E1, 9.68E1, 2.54E1, 9.64E1);
        ctx.bezierCurveTo(2.86E1, 9.6E1, 3.82E1, 9.2E1, 4.5E1, 9.6E1);
        ctx.bezierCurveTo(5.18E1, 1E2, 5.98E1, 1.044E2, 5.98E1, 1.044E2);
        ctx.bezierCurveTo(5.98E1, 1.044E2, 4.34E1, 9.6E1, 3.98E1, 9.84E1);
        ctx.bezierCurveTo(3.62E1, 1.008E2, 2.9E1, 1.004E2, 2.3E1, 1.036E2);
        ctx.bezierCurveTo(2.3E1, 1.036E2, 8.2E0, 1.08001E2, 5E0, 1.10001E2);
        ctx.bezierCurveTo(1.8E0, 1.12001E2, (-8.6), 1.23601E2, (-10.2), 1.22801E2);
        ctx.bezierCurveTo((-11.8), 1.22001E2, (-9.8), 1.21601E2, (-8.6), 1.18801E2);
        ctx.bezierCurveTo((-7.4), 1.16001E2, (-9.4), 1.14401E2, (-17.4), 1.20801E2);
        ctx.bezierCurveTo((-25.4), 1.27201E2, (-26.6), 1.29201E2, (-26.6), 1.29201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-19.195), 1.23234E2);
        ctx.bezierCurveTo((-19.195), 1.23234E2, (-17.785), 1.10194E2, (-9.307), 1.11859E2);
        ctx.bezierCurveTo((-9.307), 1.11859E2, (-1.081), 1.07689E2, 1.641E0, 1.05721E2);
        ctx.bezierCurveTo(1.641E0, 1.05721E2, 9.78E0, 1.04019E2, 1.109E1, 1.03402E2);
        ctx.bezierCurveTo(2.9569E1, 9.4702E1, 4.4288E1, 9.9221E1, 4.4835E1, 9.8101E1);
        ctx.bezierCurveTo(4.5381E1, 9.6982E1, 6.5006E1, 1.04099E2, 6.8615E1, 1.08185E2);
        ctx.bezierCurveTo(6.9006E1, 1.08628E2, 5.8384E1, 1.02588E2, 4.8686E1, 1.00697E2);
        ctx.bezierCurveTo(4.0413E1, 9.9083E1, 1.8811E1, 1.00944E2, 7.905E0, 1.0648E2);
        ctx.bezierCurveTo(4.932E0, 1.07989E2, (-4.013), 1.13773E2, (-6.544), 1.13662E2);
        ctx.bezierCurveTo((-9.075), 1.1355E2, (-19.195), 1.23234E2, (-19.195), 1.23234E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-23), 1.48801E2);
        ctx.bezierCurveTo((-23), 1.48801E2, (-38.2), 1.46401E2, (-21.4), 1.44801E2);
        ctx.bezierCurveTo((-21.4), 1.44801E2, (-3.4), 1.42801E2, 6E-1, 1.37601E2);
        ctx.bezierCurveTo(6E-1, 1.37601E2, 1.42E1, 1.28401E2, 1.7E1, 1.28001E2);
        ctx.bezierCurveTo(1.98E1, 1.27601E2, 4.98E1, 1.20401E2, 5.02E1, 1.18001E2);
        ctx.bezierCurveTo(5.06E1, 1.15601E2, 5.62E1, 1.15601E2, 5.78E1, 1.16401E2);
        ctx.bezierCurveTo(5.94E1, 1.17201E2, 5.86E1, 1.18401E2, 5.58E1, 1.19201E2);
        ctx.bezierCurveTo(5.3E1, 1.20001E2, 2.18E1, 1.36401E2, 1.54E1, 1.37601E2);
        ctx.bezierCurveTo(9E0, 1.38801E2, (-2.6), 1.46401E2, (-7.4), 1.47601E2);
        ctx.bezierCurveTo((-12.2), 1.48801E2, (-23), 1.48801E2, (-23), 1.48801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-3.48), 1.41403E2);
        ctx.bezierCurveTo((-3.48), 1.41403E2, (-12.062), 1.40574E2, (-3.461), 1.39755E2);
        ctx.bezierCurveTo((-3.461), 1.39755E2, 5.355E0, 1.36331E2, 7.403E0, 1.33668E2);
        ctx.bezierCurveTo(7.403E0, 1.33668E2, 1.4367E1, 1.28957E2, 1.58E1, 1.28753E2);
        ctx.bezierCurveTo(1.7234E1, 1.28548E2, 3.1194E1, 1.24861E2, 3.1399E1, 1.23633E2);
        ctx.bezierCurveTo(3.1604E1, 1.22404E2, 6.567E1, 1.09823E2, 7.009E1, 1.13013E2);
        ctx.bezierCurveTo(7.3001E1, 1.15114E2, 6.31E1, 1.13437E2, 5.3466E1, 1.17847E2);
        ctx.bezierCurveTo(5.2111E1, 1.18467E2, 1.8258E1, 1.33054E2, 1.4981E1, 1.33668E2);
        ctx.bezierCurveTo(1.1704E1, 1.34283E2, 5.765E0, 1.38174E2, 3.307E0, 1.38788E2);
        ctx.bezierCurveTo(8.5E-1, 1.39403E2, (-3.48), 1.41403E2, (-3.48), 1.41403E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-11.4), 1.43601E2);
        ctx.bezierCurveTo((-11.4), 1.43601E2, (-6.2), 1.43201E2, (-7.4), 1.44801E2);
        ctx.bezierCurveTo((-8.6), 1.46401E2, (-11), 1.45601E2, (-11), 1.45601E2);
        ctx.lineTo((-11.4), 1.43601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-18.6), 1.45201E2);
        ctx.bezierCurveTo((-18.6), 1.45201E2, (-13.4), 1.44801E2, (-14.6), 1.46401E2);
        ctx.bezierCurveTo((-15.8), 1.48001E2, (-18.2), 1.47201E2, (-18.2), 1.47201E2);
        ctx.lineTo((-18.6), 1.45201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-29), 1.46801E2);
        ctx.bezierCurveTo((-29), 1.46801E2, (-23.8), 1.46401E2, (-25), 1.48001E2);
        ctx.bezierCurveTo((-26.2), 1.49601E2, (-28.6), 1.48801E2, (-28.6), 1.48801E2);
        ctx.lineTo((-29), 1.46801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-36.6), 1.47601E2);
        ctx.bezierCurveTo((-36.6), 1.47601E2, (-31.4), 1.47201E2, (-32.6), 1.48801E2);
        ctx.bezierCurveTo((-33.8), 1.50401E2, (-36.2), 1.49601E2, (-36.2), 1.49601E2);
        ctx.lineTo((-36.6), 1.47601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.8E0, 1.08001E2);
        ctx.bezierCurveTo(1.8E0, 1.08001E2, 6.2E0, 1.08001E2, 5E0, 1.09601E2);
        ctx.bezierCurveTo(3.8E0, 1.11201E2, 6E-1, 1.10801E2, 6E-1, 1.10801E2);
        ctx.lineTo(1.8E0, 1.08001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-8.2), 1.13601E2);
        ctx.bezierCurveTo((-8.2), 1.13601E2, (-1.694), 1.1146E2, (-4.2), 1.14801E2);
        ctx.bezierCurveTo((-5.4), 1.16401E2, (-7.8), 1.15601E2, (-7.8), 1.15601E2);
        ctx.lineTo((-8.2), 1.13601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-19.4), 1.18401E2);
        ctx.bezierCurveTo((-19.4), 1.18401E2, (-14.2), 1.18001E2, (-15.4), 1.19601E2);
        ctx.bezierCurveTo((-16.6), 1.21201E2, (-19), 1.20401E2, (-19), 1.20401E2);
        ctx.lineTo((-19.4), 1.18401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-27), 1.24401E2);
        ctx.bezierCurveTo((-27), 1.24401E2, (-21.8), 1.24001E2, (-23), 1.25601E2);
        ctx.bezierCurveTo((-24.2), 1.27201E2, (-26.6), 1.26401E2, (-26.6), 1.26401E2);
        ctx.lineTo((-27), 1.24401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-33.8), 1.29201E2);
        ctx.bezierCurveTo((-33.8), 1.29201E2, (-28.6), 1.28801E2, (-29.8), 1.30401E2);
        ctx.bezierCurveTo((-31), 1.32001E2, (-33.4), 1.31201E2, (-33.4), 1.31201E2);
        ctx.lineTo((-33.8), 1.29201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.282E0, 1.35598E2);
        ctx.bezierCurveTo(5.282E0, 1.35598E2, 1.2203E1, 1.35066E2, 1.0606E1, 1.37195E2);
        ctx.bezierCurveTo(9.009E0, 1.39325E2, 5.814E0, 1.3826E2, 5.814E0, 1.3826E2);
        ctx.lineTo(5.282E0, 1.35598E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.5682E1, 1.30798E2);
        ctx.bezierCurveTo(1.5682E1, 1.30798E2, 2.2603E1, 1.30266E2, 2.1006E1, 1.32395E2);
        ctx.bezierCurveTo(1.9409E1, 1.34525E2, 1.6214E1, 1.3346E2, 1.6214E1, 1.3346E2);
        ctx.lineTo(1.5682E1, 1.30798E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.6482E1, 1.26398E2);
        ctx.bezierCurveTo(2.6482E1, 1.26398E2, 3.3403E1, 1.25866E2, 3.1806E1, 1.27995E2);
        ctx.bezierCurveTo(3.0209E1, 1.30125E2, 2.7014E1, 1.2906E2, 2.7014E1, 1.2906E2);
        ctx.lineTo(2.6482E1, 1.26398E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.6882E1, 1.21598E2);
        ctx.bezierCurveTo(3.6882E1, 1.21598E2, 4.3803E1, 1.21066E2, 4.2206E1, 1.23195E2);
        ctx.bezierCurveTo(4.0609E1, 1.25325E2, 3.7414E1, 1.2426E2, 3.7414E1, 1.2426E2);
        ctx.lineTo(3.6882E1, 1.21598E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(9.282E0, 1.03598E2);
        ctx.bezierCurveTo(9.282E0, 1.03598E2, 1.6203E1, 1.03066E2, 1.4606E1, 1.05195E2);
        ctx.bezierCurveTo(1.3009E1, 1.07325E2, 9.014E0, 1.0706E2, 9.014E0, 1.0706E2);
        ctx.lineTo(9.282E0, 1.03598E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.9282E1, 1.00398E2);
        ctx.bezierCurveTo(1.9282E1, 1.00398E2, 2.6203E1, 9.9866E1, 2.4606E1, 1.01995E2);
        ctx.bezierCurveTo(2.3009E1, 1.04125E2, 1.8614E1, 1.0386E2, 1.8614E1, 1.0386E2);
        ctx.lineTo(1.9282E1, 1.00398E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-3.4), 1.40401E2);
        ctx.bezierCurveTo((-3.4), 1.40401E2, 1.8E0, 1.40001E2, 6E-1, 1.41601E2);
        ctx.bezierCurveTo((-0.6), 1.43201E2, (-3), 1.42401E2, (-3), 1.42401E2);
        ctx.lineTo((-3.4), 1.40401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-76.6), 4.12E1);
        ctx.bezierCurveTo((-76.6), 4.12E1, (-81), 5E1, (-81.4), 5.32E1);
        ctx.bezierCurveTo((-81.4), 5.32E1, (-80.6), 4.44E1, (-79.4), 4.24E1);
        ctx.bezierCurveTo((-78.2), 4.04E1, (-76.6), 4.12E1, (-76.6), 4.12E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#992600';
        ctx.fillStyle = 'rgba(153,38,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-95), 5.52E1);
        ctx.bezierCurveTo((-95), 5.52E1, (-98.2), 6.96E1, (-97.8), 7.24E1);
        ctx.bezierCurveTo((-97.8), 7.24E1, (-99), 6.08E1, (-98.6), 5.96E1);
        ctx.bezierCurveTo((-98.2), 5.84E1, (-95), 5.52E1, (-95), 5.52E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-74.2), (-19.4));
        ctx.lineTo((-74.4), (-16.2));
        ctx.lineTo((-76.6), (-16));
        ctx.bezierCurveTo((-76.6), (-16), (-62.4), (-3.4), (-61.8), 4.2E0);
        ctx.bezierCurveTo((-61.8), 4.2E0, (-61), (-4), (-74.2), (-19.4));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-70.216), (-18.135));
        ctx.bezierCurveTo((-70.647), (-18.551), (-70.428), (-19.296), (-70.836), (-19.556));
        ctx.bezierCurveTo((-71.645), (-20.072), (-69.538), (-20.129), (-69.766), (-20.845));
        ctx.bezierCurveTo((-70.149), (-22.051), (-69.962), (-22.072), (-70.084), (-23.348));
        ctx.bezierCurveTo((-70.141), (-23.946), (-69.553), (-25.486), (-69.168), (-25.926));
        ctx.bezierCurveTo((-67.722), (-27.578), (-69.046), (-30.51), (-67.406), (-32.061));
        ctx.bezierCurveTo((-67.102), (-32.35), (-66.726), (-32.902), (-66.441), (-33.32));
        ctx.bezierCurveTo((-65.782), (-34.283), (-64.598), (-34.771), (-63.648), (-35.599));
        ctx.bezierCurveTo((-63.33), (-35.875), (-63.531), (-36.702), (-62.962), (-36.61));
        ctx.bezierCurveTo((-62.248), (-36.495), (-61.007), (-36.625), (-61.052), (-35.784));
        ctx.bezierCurveTo((-61.165), (-33.664), (-62.494), (-31.944), (-63.774), (-30.276));
        ctx.bezierCurveTo((-63.323), (-29.572), (-63.781), (-28.937), (-64.065), (-28.38));
        ctx.bezierCurveTo((-65.4), (-25.76), (-65.211), (-22.919), (-65.385), (-20.079));
        ctx.bezierCurveTo((-65.39), (-19.994), (-65.697), (-19.916), (-65.689), (-19.863));
        ctx.bezierCurveTo((-65.336), (-17.528), (-64.752), (-15.329), (-63.873), (-13.1));
        ctx.bezierCurveTo((-63.507), (-12.17), (-63.036), (-11.275), (-62.886), (-10.348));
        ctx.bezierCurveTo((-62.775), (-9.662), (-62.672), (-8.829), (-63.08), (-8.124));
        ctx.bezierCurveTo((-61.045), (-5.234), (-62.354), (-2.583), (-61.185), 9.48E-1);
        ctx.bezierCurveTo((-60.978), 1.573E0, (-59.286), 3.487E0, (-59.749), 3.326E0);
        ctx.bezierCurveTo((-62.262), 2.455E0, (-62.374), 2.057E0, (-62.551), 1.304E0);
        ctx.bezierCurveTo((-62.697), 6.81E-1, (-63.027), (-0.696), (-63.264), (-1.298));
        ctx.bezierCurveTo((-63.328), (-1.462), (-63.499), (-3.346), (-63.577), (-3.468));
        ctx.bezierCurveTo((-65.09), (-5.85), (-63.732), (-5.674), (-65.102), (-8.032));
        ctx.bezierCurveTo((-66.53), (-8.712), (-67.496), (-9.816), (-68.619), (-10.978));
        ctx.bezierCurveTo((-68.817), (-11.182), (-67.674), (-11.906), (-67.855), (-12.119));
        ctx.bezierCurveTo((-68.947), (-13.408), (-70.1), (-14.175), (-69.764), (-15.668));
        ctx.bezierCurveTo((-69.609), (-16.358), (-69.472), (-17.415), (-70.216), (-18.135));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-73.8), (-16.4));
        ctx.bezierCurveTo((-73.8), (-16.4), (-73.4), (-9.6), (-71), (-8));
        ctx.bezierCurveTo((-68.6), (-6.4), (-69.8), (-7.2), (-73), (-8.4));
        ctx.bezierCurveTo((-76.2), (-9.6), (-75), (-10.4), (-75), (-10.4));
        ctx.bezierCurveTo((-75), (-10.4), (-77.8), (-10), (-75.4), (-8));
        ctx.bezierCurveTo((-73), (-6), (-69.4), (-3.6), (-71), (-3.6));
        ctx.bezierCurveTo((-72.6), (-3.6), (-80.2), (-7.6), (-80.2), (-10.4));
        ctx.bezierCurveTo((-80.2), (-13.2), (-81.2), (-17.3), (-81.2), (-17.3));
        ctx.bezierCurveTo((-81.2), (-17.3), (-80.1), (-18.1), (-75.3), (-18));
        ctx.bezierCurveTo((-75.3), (-18), (-73.9), (-17.3), (-73.8), (-16.4));
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-74.6), 2.2E0);
        ctx.bezierCurveTo((-74.6), 2.2E0, (-83.12), (-0.591), (-101.6), 2.8E0);
        ctx.bezierCurveTo((-101.6), 2.8E0, (-92.569), 7.22E-1, (-73.8), 3E0);
        ctx.bezierCurveTo((-63.5), 4.25E0, (-74.6), 2.2E0, (-74.6), 2.2E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-72.502), 2.129E0);
        ctx.bezierCurveTo((-72.502), 2.129E0, (-80.748), (-1.389), (-99.453), 3.92E-1);
        ctx.bezierCurveTo((-99.453), 3.92E-1, (-90.275), (-0.897), (-71.774), 2.995E0);
        ctx.bezierCurveTo((-61.62), 5.131E0, (-72.502), 2.129E0, (-72.502), 2.129E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-70.714), 2.222E0);
        ctx.bezierCurveTo((-70.714), 2.222E0, (-78.676), (-1.899), (-97.461), (-1.514));
        ctx.bezierCurveTo((-97.461), (-1.514), (-88.213), (-2.118), (-70.052), 3.14E0);
        ctx.bezierCurveTo((-60.086), 6.025E0, (-70.714), 2.222E0, (-70.714), 2.222E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-69.444), 2.445E0);
        ctx.bezierCurveTo((-69.444), 2.445E0, (-76.268), (-1.862), (-93.142), (-2.96));
        ctx.bezierCurveTo((-93.142), (-2.96), (-84.803), (-2.79), (-68.922), 3.319E0);
        ctx.bezierCurveTo((-60.206), 6.672E0, (-69.444), 2.445E0, (-69.444), 2.445E0);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.584E1, 1.2961E1);
        ctx.bezierCurveTo(4.584E1, 1.2961E1, 4.491E1, 1.3605E1, 4.5124E1, 1.2424E1);
        ctx.bezierCurveTo(4.5339E1, 1.1243E1, 7.3547E1, (-1.927), 7.7161E1, (-1.677));
        ctx.bezierCurveTo(7.7161E1, (-1.677), 4.6913E1, 1.1529E1, 4.584E1, 1.2961E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.2446E1, 1.36E1);
        ctx.bezierCurveTo(4.2446E1, 1.36E1, 4.157E1, 1.4315E1, 4.1691E1, 1.3121E1);
        ctx.bezierCurveTo(4.1812E1, 1.1927E1, 6.8899E1, (-3.418), 7.2521E1, (-3.452));
        ctx.bezierCurveTo(7.2521E1, (-3.452), 4.3404E1, 1.2089E1, 4.2446E1, 1.36E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.916E1, 1.4975E1);
        ctx.bezierCurveTo(3.916E1, 1.4975E1, 3.8332E1, 1.5747E1, 3.8374E1, 1.4547E1);
        ctx.bezierCurveTo(3.8416E1, 1.3348E1, 5.8233E1, (-2.149), 6.8045E1, (-4.023));
        ctx.bezierCurveTo(6.8045E1, (-4.023), 5.0015E1, 4.104E0, 3.916E1, 1.4975E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.6284E1, 1.6838E1);
        ctx.bezierCurveTo(3.6284E1, 1.6838E1, 3.5539E1, 1.7532E1, 3.5577E1, 1.6453E1);
        ctx.bezierCurveTo(3.5615E1, 1.5373E1, 5.3449E1, 1.426E0, 6.228E1, (-0.26));
        ctx.bezierCurveTo(6.228E1, (-0.26), 4.6054E1, 7.054E0, 3.6284E1, 1.6838E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.6E0, 1.64801E2);
        ctx.bezierCurveTo(4.6E0, 1.64801E2, (-10.6), 1.62401E2, 6.2E0, 1.60801E2);
        ctx.bezierCurveTo(6.2E0, 1.60801E2, 2.42E1, 1.58801E2, 2.82E1, 1.53601E2);
        ctx.bezierCurveTo(2.82E1, 1.53601E2, 4.18E1, 1.44401E2, 4.46E1, 1.44001E2);
        ctx.bezierCurveTo(4.74E1, 1.43601E2, 6.38E1, 1.40001E2, 6.42E1, 1.37601E2);
        ctx.bezierCurveTo(6.46E1, 1.35201E2, 7.06E1, 1.32801E2, 7.22E1, 1.33601E2);
        ctx.bezierCurveTo(7.38E1, 1.34401E2, 7.38E1, 1.43601E2, 7.1E1, 1.44401E2);
        ctx.bezierCurveTo(6.82E1, 1.45201E2, 4.94E1, 1.52401E2, 4.3E1, 1.53601E2);
        ctx.bezierCurveTo(3.66E1, 1.54801E2, 2.5E1, 1.62401E2, 2.02E1, 1.63601E2);
        ctx.bezierCurveTo(1.54E1, 1.64801E2, 4.6E0, 1.64801E2, 4.6E0, 1.64801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(7.76E1, 1.27401E2);
        ctx.bezierCurveTo(7.76E1, 1.27401E2, 7.46E1, 1.29001E2, 7.34E1, 1.31601E2);
        ctx.bezierCurveTo(7.34E1, 1.31601E2, 6.7E1, 1.42201E2, 5.28E1, 1.45401E2);
        ctx.bezierCurveTo(5.28E1, 1.45401E2, 2.98E1, 1.54401E2, 2.2E1, 1.56401E2);
        ctx.bezierCurveTo(2.2E1, 1.56401E2, 8.6E0, 1.61401E2, 1.2E0, 1.60601E2);
        ctx.bezierCurveTo(1.2E0, 1.60601E2, (-5.8), 1.60801E2, 4E-1, 1.62401E2);
        ctx.bezierCurveTo(4E-1, 1.62401E2, 2.06E1, 1.60401E2, 2.4E1, 1.58601E2);
        ctx.bezierCurveTo(2.4E1, 1.58601E2, 3.96E1, 1.53401E2, 4.26E1, 1.50801E2);
        ctx.bezierCurveTo(4.56E1, 1.48201E2, 6.38E1, 1.43201E2, 6.6E1, 1.41201E2);
        ctx.bezierCurveTo(6.82E1, 1.39201E2, 7.8E1, 1.30801E2, 7.76E1, 1.27401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.8882E1, 1.58911E2);
        ctx.bezierCurveTo(1.8882E1, 1.58911E2, 2.4111E1, 1.58685E2, 2.2958E1, 1.60234E2);
        ctx.bezierCurveTo(2.1805E1, 1.61784E2, 1.9357E1, 1.6091E2, 1.9357E1, 1.6091E2);
        ctx.lineTo(1.8882E1, 1.58911E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.168E1, 1.60263E2);
        ctx.bezierCurveTo(1.168E1, 1.60263E2, 1.6908E1, 1.60037E2, 1.5756E1, 1.61586E2);
        ctx.bezierCurveTo(1.4603E1, 1.63136E2, 1.2155E1, 1.62263E2, 1.2155E1, 1.62263E2);
        ctx.lineTo(1.168E1, 1.60263E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.251E0, 1.61511E2);
        ctx.bezierCurveTo(1.251E0, 1.61511E2, 6.48E0, 1.61284E2, 5.327E0, 1.62834E2);
        ctx.bezierCurveTo(4.174E0, 1.64383E2, 1.726E0, 1.6351E2, 1.726E0, 1.6351E2);
        ctx.lineTo(1.251E0, 1.61511E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-6.383), 1.62055E2);
        ctx.bezierCurveTo((-6.383), 1.62055E2, (-1.154), 1.61829E2, (-2.307), 1.63378E2);
        ctx.bezierCurveTo((-3.46), 1.64928E2, (-5.908), 1.64054E2, (-5.908), 1.64054E2);
        ctx.lineTo((-6.383), 1.62055E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.5415E1, 1.51513E2);
        ctx.bezierCurveTo(3.5415E1, 1.51513E2, 4.2375E1, 1.51212E2, 4.084E1, 1.53274E2);
        ctx.bezierCurveTo(3.9306E1, 1.55336E2, 3.6047E1, 1.54174E2, 3.6047E1, 1.54174E2);
        ctx.lineTo(3.5415E1, 1.51513E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.573E1, 1.47088E2);
        ctx.bezierCurveTo(4.573E1, 1.47088E2, 5.1689E1, 1.43787E2, 5.1155E1, 1.48849E2);
        ctx.bezierCurveTo(5.0885E1, 1.51405E2, 4.6362E1, 1.49749E2, 4.6362E1, 1.49749E2);
        ctx.lineTo(4.573E1, 1.47088E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.4862E1, 1.44274E2);
        ctx.bezierCurveTo(5.4862E1, 1.44274E2, 6.2021E1, 1.40573E2, 6.0287E1, 1.46035E2);
        ctx.bezierCurveTo(5.9509E1, 1.48485E2, 5.5493E1, 1.46935E2, 5.5493E1, 1.46935E2);
        ctx.lineTo(5.4862E1, 1.44274E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(6.4376E1, 1.39449E2);
        ctx.bezierCurveTo(6.4376E1, 1.39449E2, 6.8735E1, 1.34548E2, 6.9801E1, 1.4121E2);
        ctx.bezierCurveTo(7.0207E1, 1.43748E2, 6.5008E1, 1.4211E2, 6.5008E1, 1.4211E2);
        ctx.lineTo(6.4376E1, 1.39449E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.6834E1, 1.55997E2);
        ctx.bezierCurveTo(2.6834E1, 1.55997E2, 3.2062E1, 1.5577E2, 3.091E1, 1.5732E2);
        ctx.bezierCurveTo(2.9757E1, 1.58869E2, 2.7308E1, 1.57996E2, 2.7308E1, 1.57996E2);
        ctx.lineTo(2.6834E1, 1.55997E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(6.2434E1, 3.4603E1);
        ctx.bezierCurveTo(6.2434E1, 3.4603E1, 6.1708E1, 3.5268E1, 6.1707E1, 3.4197E1);
        ctx.bezierCurveTo(6.1707E1, 3.3127E1, 7.9191E1, 1.9863E1, 8.8034E1, 1.8479E1);
        ctx.bezierCurveTo(8.8034E1, 1.8479E1, 7.1935E1, 2.5208E1, 6.2434E1, 3.4603E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(6.54E1, 9.84E1);
        ctx.bezierCurveTo(6.54E1, 9.84E1, 8.7401E1, 1.20801E2, 9.6601E1, 1.24401E2);
        ctx.bezierCurveTo(9.6601E1, 1.24401E2, 1.05801E2, 1.35601E2, 1.01801E2, 1.61601E2);
        ctx.bezierCurveTo(1.01801E2, 1.61601E2, 9.8601E1, 1.69201E2, 9.5401E1, 1.48401E2);
        ctx.bezierCurveTo(9.5401E1, 1.48401E2, 9.8601E1, 1.23201E2, 8.7401E1, 1.39201E2);
        ctx.bezierCurveTo(8.7401E1, 1.39201E2, 7.9E1, 1.29301E2, 8.54E1, 1.29601E2);
        ctx.bezierCurveTo(8.54E1, 1.29601E2, 8.8601E1, 1.31601E2, 8.9001E1, 1.30001E2);
        ctx.bezierCurveTo(8.9401E1, 1.28401E2, 8.14E1, 1.14801E2, 6.42E1, 1.004E2);
        ctx.bezierCurveTo(4.7E1, 8.6E1, 6.54E1, 9.84E1, 6.54E1, 9.84E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(7E0, 1.37201E2);
        ctx.bezierCurveTo(7E0, 1.37201E2, 6.8E0, 1.35401E2, 8.6E0, 1.36201E2);
        ctx.bezierCurveTo(1.04E1, 1.37001E2, 1.04601E2, 1.43201E2, 1.36201E2, 1.67201E2);
        ctx.bezierCurveTo(1.36201E2, 1.67201E2, 9.1001E1, 1.44001E2, 7E0, 1.37201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.74E1, 1.32801E2);
        ctx.bezierCurveTo(1.74E1, 1.32801E2, 1.72E1, 1.31001E2, 1.9E1, 1.31801E2);
        ctx.bezierCurveTo(2.08E1, 1.32601E2, 1.57401E2, 1.31601E2, 1.81001E2, 1.64001E2);
        ctx.bezierCurveTo(1.81001E2, 1.64001E2, 1.59001E2, 1.38801E2, 1.74E1, 1.32801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.9E1, 1.28801E2);
        ctx.bezierCurveTo(2.9E1, 1.28801E2, 2.88E1, 1.27001E2, 3.06E1, 1.27801E2);
        ctx.bezierCurveTo(3.24E1, 1.28601E2, 2.05801E2, 1.15601E2, 2.29401E2, 1.48001E2);
        ctx.bezierCurveTo(2.29401E2, 1.48001E2, 2.19801E2, 1.22401E2, 2.9E1, 1.28801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.9E1, 1.24001E2);
        ctx.bezierCurveTo(3.9E1, 1.24001E2, 3.88E1, 1.22201E2, 4.06E1, 1.23001E2);
        ctx.bezierCurveTo(4.24E1, 1.23801E2, 1.64601E2, 8.52E1, 1.88201E2, 1.17601E2);
        ctx.bezierCurveTo(1.88201E2, 1.17601E2, 1.74801E2, 9.3E1, 3.9E1, 1.24001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-19), 1.46801E2);
        ctx.bezierCurveTo((-19), 1.46801E2, (-19.2), 1.45001E2, (-17.4), 1.45801E2);
        ctx.bezierCurveTo((-15.6), 1.46601E2, 2.2E0, 1.48801E2, 4.2E0, 1.87601E2);
        ctx.bezierCurveTo(4.2E0, 1.87601E2, (-3), 1.45601E2, (-19), 1.46801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-27.8), 1.48401E2);
        ctx.bezierCurveTo((-27.8), 1.48401E2, (-28), 1.46601E2, (-26.2), 1.47401E2);
        ctx.bezierCurveTo((-24.4), 1.48201E2, (-10.2), 1.43601E2, (-13), 1.82401E2);
        ctx.bezierCurveTo((-13), 1.82401E2, (-11.8), 1.47201E2, (-27.8), 1.48401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-35.8), 1.48801E2);
        ctx.bezierCurveTo((-35.8), 1.48801E2, (-36), 1.47001E2, (-34.2), 1.47801E2);
        ctx.bezierCurveTo((-32.4), 1.48601E2, (-17), 1.49201E2, (-29.4), 1.71601E2);
        ctx.bezierCurveTo((-29.4), 1.71601E2, (-19.8), 1.47601E2, (-35.8), 1.48801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.1526E1, 1.04465E2);
        ctx.bezierCurveTo(1.1526E1, 1.04465E2, 1.1082E1, 1.06464E2, 1.2631E1, 1.05247E2);
        ctx.bezierCurveTo(2.8699E1, 9.2622E1, 6.1141E1, 3.372E1, 1.16826E2, 2.8086E1);
        ctx.bezierCurveTo(1.16826E2, 2.8086E1, 7.8518E1, 1.5976E1, 1.1526E1, 1.04465E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.2726E1, 1.02665E2);
        ctx.bezierCurveTo(2.2726E1, 1.02665E2, 2.1363E1, 1.01472E2, 2.3231E1, 1.00847E2);
        ctx.bezierCurveTo(2.5099E1, 1.00222E2, 1.37541E2, 2.772E1, 1.76826E2, 3.5686E1);
        ctx.bezierCurveTo(1.76826E2, 3.5686E1, 1.49719E2, 2.8176E1, 2.2726E1, 1.02665E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.885E0, 1.08767E2);
        ctx.bezierCurveTo(1.885E0, 1.08767E2, 1.376E0, 1.10366E2, 3.087E0, 1.0939E2);
        ctx.bezierCurveTo(1.2062E1, 1.0427E2, 1.5677E1, 4.7059E1, 5.9254E1, 4.5804E1);
        ctx.bezierCurveTo(5.9254E1, 4.5804E1, 2.6843E1, 3.109E1, 1.885E0, 1.08767E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-18.038), 1.19793E2);
        ctx.bezierCurveTo((-18.038), 1.19793E2, (-19.115), 1.21079E2, (-17.162), 1.20825E2);
        ctx.bezierCurveTo((-6.916), 1.19493E2, 1.4489E1, 7.8222E1, 5.8928E1, 8.3301E1);
        ctx.bezierCurveTo(5.8928E1, 8.3301E1, 2.6962E1, 6.8955E1, (-18.038), 1.19793E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-6.8), 1.13667E2);
        ctx.bezierCurveTo((-6.8), 1.13667E2, (-7.611), 1.15136E2, (-5.742), 1.14511E2);
        ctx.bezierCurveTo(4.057E0, 1.11237E2, 1.7141E1, 6.6625E1, 6.1729E1, 6.3078E1);
        ctx.bezierCurveTo(6.1729E1, 6.3078E1, 2.7603E1, 5.5135E1, (-6.8), 1.13667E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-25.078), 1.24912E2);
        ctx.bezierCurveTo((-25.078), 1.24912E2, (-25.951), 1.25954E2, (-24.369), 1.25748E2);
        ctx.bezierCurveTo((-16.07), 1.24669E2, 1.268E0, 9.124E1, 3.7264E1, 9.5354E1);
        ctx.bezierCurveTo(3.7264E1, 9.5354E1, 1.1371E1, 8.3734E1, (-25.078), 1.24912E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-32.677), 1.30821E2);
        ctx.bezierCurveTo((-32.677), 1.30821E2, (-33.682), 1.31866E2, (-32.091), 1.31748E2);
        ctx.bezierCurveTo((-27.923), 1.31439E2, 2.715E0, 9.836E1, 2.1183E1, 1.13862E2);
        ctx.bezierCurveTo(2.1183E1, 1.13862E2, 9.168E0, 9.5139E1, (-32.677), 1.30821E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.6855E1, 9.8898E1);
        ctx.bezierCurveTo(3.6855E1, 9.8898E1, 3.5654E1, 9.7543E1, 3.7586E1, 9.7158E1);
        ctx.bezierCurveTo(3.9518E1, 9.6774E1, 1.60221E2, 3.9061E1, 1.98184E2, 5.1927E1);
        ctx.bezierCurveTo(1.98184E2, 5.1927E1, 1.72243E2, 4.1053E1, 3.6855E1, 9.8898E1);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.4E0, 1.63201E2);
        ctx.bezierCurveTo(3.4E0, 1.63201E2, 3.2E0, 1.61401E2, 5E0, 1.62201E2);
        ctx.bezierCurveTo(6.8E0, 1.63001E2, 2.22E1, 1.63601E2, 9.8E0, 1.86001E2);
        ctx.bezierCurveTo(9.8E0, 1.86001E2, 1.94E1, 1.62001E2, 3.4E0, 1.63201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.38E1, 1.61601E2);
        ctx.bezierCurveTo(1.38E1, 1.61601E2, 1.36E1, 1.59801E2, 1.54E1, 1.60601E2);
        ctx.bezierCurveTo(1.72E1, 1.61401E2, 3.5E1, 1.63601E2, 3.7E1, 2.02401E2);
        ctx.bezierCurveTo(3.7E1, 2.02401E2, 2.98E1, 1.60401E2, 1.38E1, 1.61601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.06E1, 1.60001E2);
        ctx.bezierCurveTo(2.06E1, 1.60001E2, 2.04E1, 1.58201E2, 2.22E1, 1.59001E2);
        ctx.bezierCurveTo(2.4E1, 1.59801E2, 4.86E1, 1.63201E2, 7.22E1, 1.95601E2);
        ctx.bezierCurveTo(7.22E1, 1.95601E2, 3.66E1, 1.58801E2, 2.06E1, 1.60001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.8225E1, 1.57972E2);
        ctx.bezierCurveTo(2.8225E1, 1.57972E2, 2.7788E1, 1.56214E2, 2.9678E1, 1.56768E2);
        ctx.bezierCurveTo(3.1568E1, 1.57322E2, 5.2002E1, 1.55423E2, 9.0099E1, 1.89599E2);
        ctx.bezierCurveTo(9.0099E1, 1.89599E2, 4.3924E1, 1.54656E2, 2.8225E1, 1.57972E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.8625E1, 1.53572E2);
        ctx.bezierCurveTo(3.8625E1, 1.53572E2, 3.8188E1, 1.51814E2, 4.0078E1, 1.52368E2);
        ctx.bezierCurveTo(4.1968E1, 1.52922E2, 7.6802E1, 1.57423E2, 1.28499E2, 1.92399E2);
        ctx.bezierCurveTo(1.28499E2, 1.92399E2, 5.4324E1, 1.50256E2, 3.8625E1, 1.53572E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-1.8), 1.42001E2);
        ctx.bezierCurveTo((-1.8), 1.42001E2, (-2), 1.40201E2, (-0.2), 1.41001E2);
        ctx.bezierCurveTo(1.6E0, 1.41801E2, 5.5E1, 1.44401E2, 8.54E1, 1.71201E2);
        ctx.bezierCurveTo(8.54E1, 1.71201E2, 5.0499E1, 1.46426E2, (-1.8), 1.42001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-11.8), 1.46001E2);
        ctx.bezierCurveTo((-11.8), 1.46001E2, (-12), 1.44201E2, (-10.2), 1.45001E2);
        ctx.bezierCurveTo((-8.4), 1.45801E2, 1.62E1, 1.49201E2, 3.98E1, 1.81601E2);
        ctx.bezierCurveTo(3.98E1, 1.81601E2, 4.2E0, 1.44801E2, (-11.8), 1.46001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.9503E1, 1.48962E2);
        ctx.bezierCurveTo(4.9503E1, 1.48962E2, 4.8938E1, 1.47241E2, 5.0864E1, 1.47655E2);
        ctx.bezierCurveTo(5.279E1, 1.48068E2, 8.786E1, 1.50004E2, 1.41981E2, 1.81098E2);
        ctx.bezierCurveTo(1.41981E2, 1.81098E2, 6.4317E1, 1.46704E2, 4.9503E1, 1.48962E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(5.7903E1, 1.46562E2);
        ctx.bezierCurveTo(5.7903E1, 1.46562E2, 5.7338E1, 1.44841E2, 5.9264E1, 1.45255E2);
        ctx.bezierCurveTo(6.119E1, 1.45668E2, 9.626E1, 1.47604E2, 1.50381E2, 1.78698E2);
        ctx.bezierCurveTo(1.50381E2, 1.78698E2, 7.3317E1, 1.43904E2, 5.7903E1, 1.46562E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#ffffff';
        ctx.fillStyle = 'rgba(255,255,255,1)';
        ctx.strokeStyle = '#000000';
        ctx.lineWidth = 1E-1;
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(6.7503E1, 1.41562E2);
        ctx.bezierCurveTo(6.7503E1, 1.41562E2, 6.6938E1, 1.39841E2, 6.8864E1, 1.40255E2);
        ctx.bezierCurveTo(7.079E1, 1.40668E2, 1.1386E2, 1.45004E2, 2.03582E2, 1.79298E2);
        ctx.bezierCurveTo(2.03582E2, 1.79298E2, 8.2917E1, 1.38904E2, 6.7503E1, 1.41562E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-43.8), 1.48401E2);
        ctx.bezierCurveTo((-43.8), 1.48401E2, (-38.6), 1.48001E2, (-39.8), 1.49601E2);
        ctx.bezierCurveTo((-41), 1.51201E2, (-43.4), 1.50401E2, (-43.4), 1.50401E2);
        ctx.lineTo((-43.8), 1.48401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-13), 1.62401E2);
        ctx.bezierCurveTo((-13), 1.62401E2, (-7.8), 1.62001E2, (-9), 1.63601E2);
        ctx.bezierCurveTo((-10.2), 1.65201E2, (-12.6), 1.64401E2, (-12.6), 1.64401E2);
        ctx.lineTo((-13), 1.62401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-21.8), 1.62001E2);
        ctx.bezierCurveTo((-21.8), 1.62001E2, (-16.6), 1.61601E2, (-17.8), 1.63201E2);
        ctx.bezierCurveTo((-19), 1.64801E2, (-21.4), 1.64001E2, (-21.4), 1.64001E2);
        ctx.lineTo((-21.8), 1.62001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-117.169), 1.50182E2);
        ctx.bezierCurveTo((-117.169), 1.50182E2, (-112.124), 1.51505E2, (-113.782), 1.52624E2);
        ctx.bezierCurveTo((-115.439), 1.53744E2, (-117.446), 1.52202E2, (-117.446), 1.52202E2);
        ctx.lineTo((-117.169), 1.50182E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-115.169), 1.40582E2);
        ctx.bezierCurveTo((-115.169), 1.40582E2, (-110.124), 1.41905E2, (-111.782), 1.43024E2);
        ctx.bezierCurveTo((-113.439), 1.44144E2, (-115.446), 1.42602E2, (-115.446), 1.42602E2);
        ctx.lineTo((-115.169), 1.40582E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#000000';
        ctx.fillStyle = 'rgba(0,0,0,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-122.369), 1.36182E2);
        ctx.bezierCurveTo((-122.369), 1.36182E2, (-117.324), 1.37505E2, (-118.982), 1.38624E2);
        ctx.bezierCurveTo((-120.639), 1.39744E2, (-122.646), 1.38202E2, (-122.646), 1.38202E2);
        ctx.lineTo((-122.369), 1.36182E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-42.6), 2.11201E2);
        ctx.bezierCurveTo((-42.6), 2.11201E2, (-44.2), 2.11201E2, (-48.2), 2.13201E2);
        ctx.bezierCurveTo((-50.2), 2.13201E2, (-61.4), 2.16801E2, (-67), 2.26801E2);
        ctx.bezierCurveTo((-67), 2.26801E2, (-54.6), 2.17201E2, (-42.6), 2.11201E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.5116E1, 3.03847E2);
        ctx.bezierCurveTo(4.5257E1, 3.04105E2, 4.5312E1, 3.04525E2, 4.5604E1, 3.04542E2);
        ctx.bezierCurveTo(4.6262E1, 3.04582E2, 4.7495E1, 3.04883E2, 4.737E1, 3.04247E2);
        ctx.bezierCurveTo(4.6522E1, 2.99941E2, 4.5648E1, 2.95004E2, 4.1515E1, 2.93197E2);
        ctx.bezierCurveTo(4.0876E1, 2.92918E2, 3.9434E1, 2.93331E2, 3.936E1, 2.94215E2);
        ctx.bezierCurveTo(3.9233E1, 2.95739E2, 3.9116E1, 2.97088E2, 3.9425E1, 2.98554E2);
        ctx.bezierCurveTo(3.9725E1, 2.99975E2, 4.1883E1, 2.99985E2, 4.28E1, 2.98601E2);
        ctx.bezierCurveTo(4.3736E1, 3.00273E2, 4.4168E1, 3.02116E2, 4.5116E1, 3.03847E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.4038E1, 3.08581E2);
        ctx.bezierCurveTo(3.4786E1, 3.09994E2, 3.4659E1, 3.11853E2, 3.6074E1, 3.12416E2);
        ctx.bezierCurveTo(3.6814E1, 3.1271E2, 3.8664E1, 3.11735E2, 3.8246E1, 3.10661E2);
        ctx.bezierCurveTo(3.7444E1, 3.086E2, 3.7056E1, 3.06361E2, 3.5667E1, 3.0455E2);
        ctx.bezierCurveTo(3.5467E1, 3.04288E2, 3.5707E1, 3.03755E2, 3.5547E1, 3.03427E2);
        ctx.bezierCurveTo(3.4953E1, 3.02207E2, 3.3808E1, 3.01472E2, 3.24E1, 3.01801E2);
        ctx.bezierCurveTo(3.1285E1, 3.04004E2, 3.2433E1, 3.06133E2, 3.3955E1, 3.07842E2);
        ctx.bezierCurveTo(3.4091E1, 3.07994E2, 3.3925E1, 3.0837E2, 3.4038E1, 3.08581E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-5.564), 3.03391E2);
        ctx.bezierCurveTo((-5.672), 3.03014E2, (-5.71), 3.02551E2, (-5.545), 3.0223E2);
        ctx.bezierCurveTo((-5.014), 3.01197E2, (-4.221), 3.00075E2, (-4.558), 2.99053E2);
        ctx.bezierCurveTo((-4.906), 2.97997E2, (-6.022), 2.98179E2, (-6.672), 2.98748E2);
        ctx.bezierCurveTo((-7.807), 2.99742E2, (-7.856), 3.01568E2, (-8.547), 3.02927E2);
        ctx.bezierCurveTo((-8.743), 3.03313E2, (-8.692), 3.03886E2, (-9.133), 3.04277E2);
        ctx.bezierCurveTo((-9.607), 3.04698E2, (-10.047), 3.06222E2, (-9.951), 3.06793E2);
        ctx.bezierCurveTo((-9.898), 3.07106E2, (-10.081), 3.17014E2, (-9.859), 3.16751E2);
        ctx.bezierCurveTo((-9.24), 3.16018E2, (-6.19), 3.06284E2, (-6.121), 3.05392E2);
        ctx.bezierCurveTo((-6.064), 3.04661E2, (-5.332), 3.04196E2, (-5.564), 3.03391E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-31.202), 2.96599E2);
        ctx.bezierCurveTo((-28.568), 2.941E2, (-25.778), 2.91139E2, (-26.22), 2.87427E2);
        ctx.bezierCurveTo((-26.336), 2.86451E2, (-28.111), 2.86978E2, (-28.298), 2.87824E2);
        ctx.bezierCurveTo((-29.1), 2.91449E2, (-31.139), 2.9411E2, (-33.707), 2.96502E2);
        ctx.bezierCurveTo((-35.903), 2.98549E2, (-37.765), 3.04893E2, (-38), 3.05401E2);
        ctx.bezierCurveTo((-34.303), 3.00145E2, (-32.046), 2.97399E2, (-31.202), 2.96599E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-44.776), 2.90635E2);
        ctx.bezierCurveTo((-44.253), 2.90265E2, (-44.555), 2.89774E2, (-44.338), 2.89442E2);
        ctx.bezierCurveTo((-43.385), 2.87984E2, (-42.084), 2.86738E2, (-42.066), 2.85E2);
        ctx.bezierCurveTo((-42.063), 2.84723E2, (-42.441), 2.84414E2, (-42.776), 2.84638E2);
        ctx.bezierCurveTo((-43.053), 2.84822E2, (-43.395), 2.84952E2, (-43.503), 2.85082E2);
        ctx.bezierCurveTo((-45.533), 2.87531E2, (-46.933), 2.90202E2, (-48.376), 2.93014E2);
        ctx.bezierCurveTo((-48.559), 2.93371E2, (-49.703), 2.97862E2, (-49.39), 2.97973E2);
        ctx.bezierCurveTo((-49.151), 2.98058E2, (-47.431), 2.93877E2, (-47.221), 2.93763E2);
        ctx.bezierCurveTo((-45.958), 2.93077E2, (-45.946), 2.91462E2, (-44.776), 2.90635E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-28.043), 3.10179E2);
        ctx.bezierCurveTo((-27.599), 3.0931E2, (-26.023), 3.08108E2, (-26.136), 3.07219E2);
        ctx.bezierCurveTo((-26.254), 3.06291E2, (-25.786), 3.04848E2, (-26.698), 3.05536E2);
        ctx.bezierCurveTo((-27.955), 3.06484E2, (-31.404), 3.07833E2, (-31.674), 3.13641E2);
        ctx.bezierCurveTo((-31.7), 3.14212E2, (-28.726), 3.11519E2, (-28.043), 3.10179E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-13.6), 2.93001E2);
        ctx.bezierCurveTo((-13.2), 2.92333E2, (-12.492), 2.92806E2, (-12.033), 2.92543E2);
        ctx.bezierCurveTo((-11.385), 2.92171E2, (-10.774), 2.91613E2, (-10.482), 2.90964E2);
        ctx.bezierCurveTo((-9.512), 2.88815E2, (-7.743), 2.86995E2, (-7.6), 2.84601E2);
        ctx.bezierCurveTo((-9.091), 2.83196E2, (-9.77), 2.85236E2, (-10.4), 2.86201E2);
        ctx.bezierCurveTo((-11.723), 2.84554E2, (-12.722), 2.86428E2, (-14.022), 2.86947E2);
        ctx.bezierCurveTo((-14.092), 2.86975E2, (-14.305), 2.86628E2, (-14.38), 2.86655E2);
        ctx.bezierCurveTo((-15.557), 2.87095E2, (-16.237), 2.88176E2, (-17.235), 2.88957E2);
        ctx.bezierCurveTo((-17.406), 2.89091E2, (-17.811), 2.88911E2, (-17.958), 2.89047E2);
        ctx.bezierCurveTo((-18.61), 2.8965E2, (-19.583), 2.89975E2, (-19.863), 2.90657E2);
        ctx.bezierCurveTo((-20.973), 2.93364E2, (-24.113), 2.95459E2, (-26), 3.03001E2);
        ctx.bezierCurveTo((-25.619), 3.0391E2, (-21.488), 2.96359E2, (-21.001), 2.95661E2);
        ctx.bezierCurveTo((-20.165), 2.94465E2, (-20.047), 2.97322E2, (-18.771), 2.96656E2);
        ctx.bezierCurveTo((-18.72), 2.96629E2, (-18.534), 2.96867E2, (-18.4), 2.97001E2);
        ctx.bezierCurveTo((-18.206), 2.96721E2, (-17.988), 2.96492E2, (-17.6), 2.96601E2);
        ctx.bezierCurveTo((-17.6), 2.96201E2, (-17.734), 2.95645E2, (-17.533), 2.95486E2);
        ctx.bezierCurveTo((-16.296), 2.94509E2, (-16.38), 2.93441E2, (-15.6), 2.92201E2);
        ctx.bezierCurveTo((-15.142), 2.9299E2, (-14.081), 2.92271E2, (-13.6), 2.93001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(4.62E1, 3.47401E2);
        ctx.bezierCurveTo(4.62E1, 3.47401E2, 5.36E1, 3.27001E2, 4.92E1, 3.15801E2);
        ctx.bezierCurveTo(4.92E1, 3.15801E2, 6.06E1, 3.37401E2, 5.6E1, 3.48601E2);
        ctx.bezierCurveTo(5.6E1, 3.48601E2, 5.56E1, 3.38201E2, 5.16E1, 3.33201E2);
        ctx.bezierCurveTo(5.16E1, 3.33201E2, 4.76E1, 3.46001E2, 4.62E1, 3.47401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.14E1, 3.44801E2);
        ctx.bezierCurveTo(3.14E1, 3.44801E2, 3.68E1, 3.36001E2, 2.88E1, 3.17601E2);
        ctx.bezierCurveTo(2.88E1, 3.17601E2, 2.8E1, 3.38001E2, 2.12E1, 3.49001E2);
        ctx.bezierCurveTo(2.12E1, 3.49001E2, 3.54E1, 3.28801E2, 3.14E1, 3.44801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.14E1, 3.42801E2);
        ctx.bezierCurveTo(2.14E1, 3.42801E2, 2.12E1, 3.22801E2, 2.16E1, 3.19801E2);
        ctx.bezierCurveTo(2.16E1, 3.19801E2, 1.78E1, 3.36401E2, 7.6E0, 3.46001E2);
        ctx.bezierCurveTo(7.6E0, 3.46001E2, 2.2E1, 3.34001E2, 2.14E1, 3.42801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(1.18E1, 3.10801E2);
        ctx.bezierCurveTo(1.18E1, 3.10801E2, 1.78E1, 3.24401E2, 7.8E0, 3.42801E2);
        ctx.bezierCurveTo(7.8E0, 3.42801E2, 1.42E1, 3.30601E2, 9.4E0, 3.23601E2);
        ctx.bezierCurveTo(9.4E0, 3.23601E2, 1.2E1, 3.20201E2, 1.18E1, 3.10801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-7.4), 3.42401E2);
        ctx.bezierCurveTo((-7.4), 3.42401E2, (-8.4), 3.26801E2, (-6.6), 3.24601E2);
        ctx.bezierCurveTo((-6.6), 3.24601E2, (-6.4), 3.18201E2, (-6.8), 3.17201E2);
        ctx.bezierCurveTo((-6.8), 3.17201E2, (-2.8), 3.11001E2, (-2.6), 3.18401E2);
        ctx.bezierCurveTo((-2.6), 3.18401E2, (-1.2), 3.26201E2, 1.6E0, 3.30801E2);
        ctx.bezierCurveTo(1.6E0, 3.30801E2, 5.2E0, 3.36201E2, 5E0, 3.42601E2);
        ctx.bezierCurveTo(5E0, 3.42601E2, (-5), 3.12401E2, (-7.4), 3.42401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-11), 3.14801E2);
        ctx.bezierCurveTo((-11), 3.14801E2, (-17.6), 3.25601E2, (-19.4), 3.44601E2);
        ctx.bezierCurveTo((-19.4), 3.44601E2, (-20.8), 3.38401E2, (-17), 3.24001E2);
        ctx.bezierCurveTo((-17), 3.24001E2, (-12.8), 3.08601E2, (-11), 3.14801E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-32.8), 3.34601E2);
        ctx.bezierCurveTo((-32.8), 3.34601E2, (-27.8), 3.29201E2, (-26.4), 3.24201E2);
        ctx.bezierCurveTo((-26.4), 3.24201E2, (-22.8), 3.08401E2, (-29.2), 3.17001E2);
        ctx.bezierCurveTo((-29.2), 3.17001E2, (-29), 3.25001E2, (-37.2), 3.32401E2);
        ctx.bezierCurveTo((-37.2), 3.32401E2, (-32.4), 3.30001E2, (-32.8), 3.34601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-38.6), 3.29601E2);
        ctx.bezierCurveTo((-38.6), 3.29601E2, (-35.2), 3.12201E2, (-34.4), 3.11401E2);
        ctx.bezierCurveTo((-34.4), 3.11401E2, (-32.6), 3.08001E2, (-35.4), 3.11201E2);
        ctx.bezierCurveTo((-35.4), 3.11201E2, (-44.2), 3.30401E2, (-48.2), 3.37001E2);
        ctx.bezierCurveTo((-48.2), 3.37001E2, (-40.2), 3.27801E2, (-38.6), 3.29601E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-44.4), 3.13001E2);
        ctx.bezierCurveTo((-44.4), 3.13001E2, (-32.8), 2.90601E2, (-54.6), 3.16401E2);
        ctx.bezierCurveTo((-54.6), 3.16401E2, (-43.6), 3.06601E2, (-44.4), 3.13001E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-59.8), 2.98401E2);
        ctx.bezierCurveTo((-59.8), 2.98401E2, (-55), 2.79601E2, (-52.4), 2.79801E2);
        ctx.bezierCurveTo((-52.4), 2.79801E2, (-44.2), 2.70801E2, (-50.8), 2.81401E2);
        ctx.bezierCurveTo((-50.8), 2.81401E2, (-56.8), 2.91001E2, (-56.2), 3.00801E2);
        ctx.bezierCurveTo((-56.2), 3.00801E2, (-56.8), 2.91201E2, (-59.8), 2.98401E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.705E2, 2.87E2);
        ctx.bezierCurveTo(2.705E2, 2.87E2, 2.585E2, 2.77E2, 2.56E2, 2.735E2);
        ctx.bezierCurveTo(2.56E2, 2.735E2, 2.695E2, 2.92E2, 2.695E2, 2.99E2);
        ctx.bezierCurveTo(2.695E2, 2.99E2, 2.72E2, 2.915E2, 2.705E2, 2.87E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.76E2, 2.65E2);
        ctx.bezierCurveTo(2.76E2, 2.65E2, 2.55E2, 2.5E2, 2.515E2, 2.425E2);
        ctx.bezierCurveTo(2.515E2, 2.425E2, 2.78E2, 2.72E2, 2.78E2, 2.765E2);
        ctx.bezierCurveTo(2.78E2, 2.765E2, 2.785E2, 2.675E2, 2.76E2, 2.65E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.93E2, 1.11E2);
        ctx.bezierCurveTo(2.93E2, 1.11E2, 2.81E2, 1.03E2, 2.795E2, 1.05E2);
        ctx.bezierCurveTo(2.795E2, 1.05E2, 2.9E2, 1.115E2, 2.925E2, 1.2E2);
        ctx.bezierCurveTo(2.925E2, 1.2E2, 2.91E2, 1.11E2, 2.93E2, 1.11E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = '#cccccc';
        ctx.fillStyle = 'rgba(204,204,204,1)';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(3.015E2, 1.915E2);
        ctx.lineTo(2.84E2, 1.795E2);
        ctx.bezierCurveTo(2.84E2, 1.795E2, 3.03E2, 1.965E2, 3.035E2, 2.005E2);
        ctx.lineTo(3.015E2, 1.915E2);
        ctx.closePath();
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-89.25), 1.69E2);
        ctx.lineTo((-67.25), 1.7375E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-39), 3.31E2);
        ctx.bezierCurveTo((-39), 3.31E2, (-39.5), 3.275E2, (-48.5), 3.38E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo((-33.5), 3.36E2);
        ctx.bezierCurveTo((-33.5), 3.36E2, (-31.5), 3.295E2, (-38), 3.34E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.save();
        ctx.fillStyle = 'rgba(0,0,0,0)';
        ctx.strokeStyle = '#000000';
        ctx.font = '10px sans-serif';
        ctx.beginPath();
        ctx.moveTo(2.05E1, 3.445E2);
        ctx.bezierCurveTo(2.05E1, 3.445E2, 2.2E1, 3.335E2, 1.05E1, 3.465E2);
        ctx.fill();
        ctx.stroke();
        ctx.restore();
        ctx.restore();
        ctx.restore();
        ctx.restore();

    }

    function transform(ctx) {
        // case 1
        ctx.fillStyle = "rgba(255, 0, 0, 0.5)";
        ctx.setTransform(1,1,0,1,0,0);
        ctx.fillRect(0,0,100,100);
        ctx.resetTransform();

        // case 2
        ctx.fillStyle = "red";
        ctx.fillRect(0, 0, 50, 50);
        ctx.resetTransform();

        // case 3
        ctx.fillStyle = "rgba(0, 0, 255, 0.5)";
        ctx.beginPath();
        ctx.moveTo(0, 0);
        ctx.lineTo(100, 0);
        ctx.transform(2, 0, 0, 2, 0, 0);
        ctx.lineTo(100, 100);
        ctx.transform(2, 0, 0, 1, 0, 0);
        ctx.lineTo(100, 100);
        ctx.closePath();
        ctx.fill();
        ctx.resetTransform();
    }

    function pattern(ctx) {
      // Create a pattern
      const patternCanvas = document.createElement('canvas');
      const patternContext = patternCanvas.getContext('2d');

      // Give the pattern a width and height of 50
      patternCanvas.width = 50;
      patternCanvas.height = 50;

      // Give the pattern a background color and draw an arc
      patternContext.fillStyle = '#fec';
      patternContext.fillRect(0, 0, patternCanvas.width, patternCanvas.height);
      patternContext.arc(0, 0, 50, 0, .5 * Math.PI);
      patternContext.stroke();

      const pattern = ctx.createPattern(patternCanvas, 'repeat');
      ctx.fillStyle = pattern;
      ctx.fillRect(0, 0, 50, 50);

      var img = new Image();
      img.src = 'pattern.png';
      img.onload = function() {
        var pattern = ctx.createPattern(img, 'repeat');
        ctx.fillStyle = pattern;
        ctx.fillRect(50, 50, 300, 300);
      };

    }

    function makePath(ctx, arg) {
      if (ctx.createPath) {
        return ctx.createPath(arg);
      } else {
        return new Path2D(arg);
      }
    }

    function path2D(ctx) {
      const path1 = makePath(
        ctx,
        `M 230 80
        A 45 45, 0, 1, 0, 275 125
        L 275 80 Z`
      );

      ctx.save();
      ctx.strokeStyle = "red";
      ctx.stroke(path1);
      ctx.fillStyle = "grey";
      ctx.fill(path1);

      ctx.translate(10, 25);
      ctx.lineWidth = 10;
      ctx.stroke(path1);

      ctx.rotate(Math.PI / 4);
      ctx.scale(1.5, 1.5);
      ctx.translate(10, 25);

      ctx.strokeStyle = "blue";
      ctx.stroke(path1);
      ctx.restore();

      ctx.save();
      // Stroke and fill the same path.
      ctx.beginPath();
      ctx.rect(10, 10, 40, 20);
      ctx.save();
      ctx.strokeStyle = "red";
      ctx.stroke();
      ctx.restore();
      ctx.save();
      ctx.fillStyle = "green";
      ctx.fill();
      ctx.restore();
      ctx.restore();

      // Scaling path versus scaling the context.
      const path2 = makePath(
        ctx,
        `M -10 -10
     L 10 -10
     L 10 10
     L -10 10
     Z`
      );


      ctx.save();
      ctx.translate(25, 100);
      ctx.scale(2, 1);
      ctx.strokeStyle = "red";
      ctx.moveTo(-10, -10);
      ctx.lineTo(10, -10);
      ctx.lineTo(10, 10);
      ctx.lineTo(-10, 10);
      ctx.closePath();
      ctx.fillStyle = "grey";
      ctx.fill();
      ctx.scale(1 / 2, 1); // Reset scale so that stroke is not scaled.
      ctx.stroke();
      ctx.restore();

      ctx.save();
      ctx.translate(100, 100);
      ctx.scale(2, 1);
      ctx.fillStyle = "grey";
      ctx.fill(path2);
      ctx.strokeStyle = "red";

      let scaledPath = makePath(ctx);
      scaledPath.addPath(path2, new DOMMatrix([
        2, 0,
        0, 1,
        0,
        0,
      ]));

      ctx.scale(1 / 2, 1); // Reset scale so that stroke is not scaled.
      ctx.stroke(scaledPath);
      ctx.restore();
    }

    function clip(ctx) {
      // Draw a line with clipped areas removed.
      var scaleX = 1.5,
        scaleY = 1.2;

      ctx.rotate(Math.PI / 10);
      ctx.scale(scaleX, scaleY);
      ctx.translate(200, 25);

      // Draw unclipped line
      ctx.beginPath();
      ctx.moveTo(5, 10);
      ctx.lineTo(195, 200);
      ctx.stroke();

      ctx.save();

      // Remove clipped areas
      ctx.beginPath();
      ctx.rect(20, 30, 30, 10);
      ctx.rect(0, 0, 300, 300);
      ctx.stroke();
      ctx.clip("evenodd");

      // Draw line.
      ctx.beginPath();
      ctx.moveTo(10, 10);
      ctx.lineTo(200, 200);
      ctx.stroke();

      ctx.restore();

      // Draw unclipped line
      ctx.beginPath();
      ctx.moveTo(15, 10);
      ctx.lineTo(205, 200);
      ctx.stroke();
    }

    function roundRect(ctx) {
      ctx.beginPath();
      ctx.roundRect(150, 20, 100, 50, 10);
      ctx.stroke();

      ctx.beginPath();
      ctx.roundRect(150, 150, 100, 50, 50);
      ctx.stroke();

      ctx.beginPath();
      ctx.roundRect(150, 300, 50, 50, 50);
      ctx.stroke();

      ctx.beginPath();
      ctx.roundRect(300, 20, 100, 50, 10);
      ctx.fill();

      ctx.beginPath();
      ctx.roundRect(300, 150, 100, 50, [10, 20, 30, 50]);
      ctx.stroke();

      ctx.beginPath();
      ctx.roundRect(300, 300, 50, 50, [10, 30]);
      ctx.stroke();

      ctx.beginPath();
      ctx.roundRect(300, 400, 50, 50, [30]);
      ctx.stroke();
    }

    const tests = [
      tiger,
      arc,
      arcTo$1,
      arcTo,
      arcToScaled,
      clip,
      emptyArc,
      ellipse,
      ellipse2,
      fillStyle,
      globalAlpha,
      gradient,
      image,
      linecap,
      linewidth,
      scaledLine,
      rgba,
      rotate,
      saveAndRestore,
      setLineDash,
      text,
      transform,
      pattern,
      path2D,
      roundRect,
    ];

    for (let fn of tests) {
      let name = fn.name;
      // Container
      const container = document.createElement("div");
      container.className = "example";
      container.id = "example-" + name;
      container.innerHTML = `<h2>${name}</h2><div class="canvas"></div><div class="svg"></div>`;
      // Canvas
      const canvas = document.createElement("canvas");
      container.querySelector(".canvas").appendChild(canvas);
      // SVGCanvas
      const svgcanvas = new SVGCanvasElement();
      container.querySelector(".svg").appendChild(svgcanvas.getElement());
      document.querySelector("body").appendChild(container);
      // Render
      for (let c of [canvas, svgcanvas]) {
        c.width = 500;
        c.height = 500;
        const ctx = c.getContext("2d");
        fn(ctx);
      }
    }

})();
